@@ -19,11 +19,14 @@
 #include <sstream>
 
 #include "FogMap.h"
+#include "SightMap.h"
 
 #include "playerlist.h"
 #include "xmlhelper.h"
 #include "GameScenarioOptions.h"
 
+std::string FogMap::d_tag = "fogmap";
+
 using namespace std;
 
 //#define debug(x) {std::cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<std::endl<<flush;}
@@ -95,7 +98,7 @@ bool FogMap::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("fogmap");
+    retval &= helper->openTag(FogMap::d_tag);
     retval &= helper->saveData("width", d_width);
     retval &= helper->saveData("height", d_height);
 
@@ -152,6 +155,29 @@ void FogMap::alterFogRectangle(Vector<int> pt, int height, int width, FogType ne
     }
 }
 
+bool FogMap::isCompletelyObscuredFogTile(Vector<int> pos)
+{
+  bool foggyTile;
+  for (int i = pos.x - 1; i <= pos.x + 1; i++)
+    for (int j = pos.y - 1; j <= pos.y + 1; j++)
+      {
+	foggyTile = false;
+	if (i == pos.x && j == pos.y)
+	  continue;
+	if (i < 0 || j < 0 || 
+	    i >= FogMap::getWidth() || j >= FogMap::getHeight())
+	  foggyTile = true;
+	else
+	  {
+	    Vector<int> pos = Vector<int>(i, j);
+	    foggyTile = FogMap::isFogged(pos);
+	  }
+	if (foggyTile == false)
+	  return false;
+      }
+  return true;
+}
+
 bool FogMap::isLoneFogTile(Vector<int> pos)
 {
   bool west_open = false;
@@ -209,4 +235,9 @@ bool FogMap::isFogged(Vector <int> pos)
 
   return false;
 }
+	
+void FogMap::alterFog(SightMap *sightmap)
+{
+  return alterFogRectangle(sightmap->pos, sightmap->h, sightmap->w, OPEN);
+}
 // End of file
