@@ -3,6 +3,7 @@
 // Copyright (C) 2003, 2005, 2006 Andrea Paternesi
 // Copyright (C) 2006, 2007, 2008 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
+// Copyright (C) 2008 Janek Kozicki
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -41,7 +42,10 @@
 #include "shieldsetlist.h"
 #include "citysetlist.h"
 #include "GraphicsCache.h"
+#include "MapBackpack.h"
 
+std::string GameMap::d_tag = "map";
+std::string GameMap::d_itemstack_tag = "itemstack";
 using namespace std;
 
 //#include <iostream>
@@ -104,6 +108,47 @@ GameMap::GameMap(std::string TilesetName, std::string ShieldsetName,
 
 }
 
+void GameMap::processStyles(std::string styles, int chars_per_style)
+{
+  int c = chars_per_style;
+    int offset = 0;
+    for (int j = 0; j < s_height; j++)
+    {
+        // remove newline and carriage return lines
+        char test = styles[j*s_width*c + offset];
+        while (test == '\n' || test == '\r')
+        {
+            offset++;
+            test = styles[j*s_width*c + offset];
+        }
+
+        for (int i = 0; i < s_width; i++)
+        {
+	    char hexstr[15];
+            //due to the circumstances, styles is a long stream of
+            //hex digit pairs, so read it character for character
+	    hexstr[0] = '0';
+	    hexstr[1] = 'x';
+	    memcpy (&hexstr[2], &styles[j*s_width*c + (i * c) + offset], c);
+	    hexstr[2 + c + 1 - 1] = '\0';
+
+	    unsigned long int val = 0;
+	    char *end = NULL;
+	    val = strtoul (hexstr, &end, 16);
+	    Uint32 id = (Uint32) val;
+	    TileStyle *style = d_tileSet->getTileStyle(id);
+	    if (!style)
+	      style = d_tileSet->getTileStyle(0);
+	    d_map[j*s_width + i]->setTileStyle(style);
+        }
+    }
+}
+    
+int GameMap::determineCharsPerStyle(std::string styles)
+{
+  return styles.length() / (s_width * s_height);
+}
+
 GameMap::GameMap(XML_Helper* helper)
 {
     std::string types;
@@ -151,40 +196,13 @@ GameMap::GameMap(XML_Helper* helper)
         }
     }
 
-    offset = 0;
-    for (int j = 0; j < s_height; j++)
-    {
-        // remove newline and carriage return lines
-        char test = styles[j*s_width*2 + offset];
-        while (test == '\n' || test == '\r')
-        {
-            offset++;
-            test = styles[j*s_width*2 + offset];
-        }
-
-        for (int i = 0; i < s_width; i++)
-        {
-	    char hexstr[5];
-            //due to the circumstances, styles is a long stream of
-            //hex digit pairs, so read it character for character
-	    hexstr[0] = '0';
-	    hexstr[1] = 'x';
-	    hexstr[2] = styles[j*s_width*2 + (i * 2) + offset];  
-	    hexstr[3] = styles[j*s_width*2 + (i * 2) + offset + 1];
-	    hexstr[4] = '\0';
-
-	    unsigned long int val = 0;
-	    char *end = NULL;
-	    val = strtoul (hexstr, &end, 16);
-	    Uint32 id = (Uint32) val;
-	    TileStyle *style = d_tileSet->getTileStyle(id);
-	    d_map[j*s_width + i]->setTileStyle(style);
-        }
-    }
+    int chars_per_style = determineCharsPerStyle(styles);
+    processStyles(styles, chars_per_style);
 
     //add some callbacks for item loading
-    helper->registerTag("itemstack", sigc::mem_fun(this, &GameMap::loadItems));
-    helper->registerTag("item", sigc::mem_fun(this, &GameMap::loadItems));
+    helper->registerTag(GameMap::d_itemstack_tag, 
+			sigc::mem_fun(this, &GameMap::loadItems));
+    helper->registerTag(Item::d_tag, sigc::mem_fun(this, &GameMap::loadItems));
 }
 
 
@@ -262,13 +280,20 @@ bool GameMap::save(XML_Helper* helper) const
 
     std::stringstream styles;
     styles <<endl;
+	    
+    int largest_style_id = d_tileSet->getLargestTileStyleId();
     for (int i = 0; i < s_height; i++)
     {
         for (int j = 0; j < s_width; j++)
 	  {
 	    char *hexstr = NULL;
 	    TileStyle *style = getTile(j, i)->getTileStyle();
-	    asprintf (&hexstr, "%02x", style->getId());
+	    if (largest_style_id < 256)
+	      asprintf (&hexstr, "%02x", style->getId());
+	    else if (largest_style_id < 4096)
+	      asprintf (&hexstr, "%03x", style->getId());
+	    else if (largest_style_id < 65536)
+	      asprintf (&hexstr, "%04x", style->getId());
             styles << hexstr;
 	    free (hexstr);
 	  }
@@ -276,7 +301,7 @@ bool GameMap::save(XML_Helper* helper) const
     }
 
 
-    retval &= helper->openTag("map");
+    retval &= helper->openTag(GameMap::d_tag);
     retval &= helper->saveData("width", s_width);
     retval &= helper->saveData("height", s_height);
     retval &= helper->saveData("tileset", d_tileSet->getSubDir());
@@ -287,21 +312,9 @@ bool GameMap::save(XML_Helper* helper) const
 
     // last, save all items lying around somewhere
     for (int i = 0; i < s_width; i++)
-        for (int j = 0; j < s_height; j++)
-            if (!getTile(i,j)->getItems().empty())
-            {
-                retval &= helper->openTag("itemstack");
-                retval &= helper->saveData("x", i);
-                retval &= helper->saveData("y", j);
-                
-                std::list<Item*> items = getTile(i,j)->getItems();
-                
-                std::list<Item*>::const_iterator it;
-                for (it = items.begin(); it != items.end(); it++)
-                    (*it)->save(helper);
-
-                retval &= helper->closeTag();
-            }
+      for (int j = 0; j < s_height; j++)
+	if (!getTile(i,j)->getBackpack()->empty())
+	  retval &= getTile(i,j)->getBackpack()->save(helper);
      
     retval &= helper->closeTag();
     return retval;
@@ -312,16 +325,16 @@ bool GameMap::loadItems(std::string tag, XML_Helper* helper)
     static int x = 0;
     static int y = 0;
     
-    if (tag == "itemstack")
+    if (tag == GameMap::d_itemstack_tag)
     {
         helper->getData(x, "x");
         helper->getData(y, "y");
     }
 
-    if (tag == "item")
+    if (tag == Item::d_tag)
     {
         Item* item = new Item(helper);
-        getTile(x, y)->addItem(item);
+        getTile(x, y)->getBackpack()->addToBackpack(item);
     }
 
     return true;
@@ -331,6 +344,7 @@ void GameMap::setTile(int x, int y, Maptile *tile)
 {
     delete d_map[y*s_width + x];
     d_map[y*s_width + x] = tile;
+    applyTileStyle (y, x);
 }
 
 Maptile* GameMap::getTile(int x, int y) const
@@ -414,6 +428,8 @@ Stack* GameMap::addArmyAtPos(Vector<int> pos, Army *a)
                     continue;
                   if (!land && getTile(x, y)->getType() != Tile::WATER)
                     continue;
+                  if (land && getTile(x, y)->getType() == Tile::VOID)
+		    continue;
                   if (land && getTile(x, y)->getType() == Tile::MOUNTAIN &&
 		      (a->getStat(Army::MOVE_BONUS) & Tile::MOUNTAIN) == 0)
                     continue;
@@ -447,7 +463,13 @@ Stack* GameMap::addArmyAtPos(Vector<int> pos, Army *a)
     }
 
   if (added_army)
-    return s;
+    {
+      s->setDefending(false);
+      s->setParked(false);
+      if (s->countGroupedArmies() == 0)
+	s->ungroup();
+      return s;
+    }
   else
     return NULL;
 }
@@ -525,6 +547,11 @@ bool GameMap::isBlockedAvenue(int x, int y, int destx, int desty)
       if (from->getMaptileType() == Tile::MOUNTAIN &&
 	  Roadlist::getInstance()->getObjectAt(x, y) == NULL)
         return true;
+
+      if (from->getMaptileType() == Tile::VOID)
+	return true;
+      if (to->getMaptileType() == Tile::VOID)
+	return true;
     }
  return false;
 }
@@ -579,21 +606,14 @@ Vector<int> GameMap::findPlantedStandard(Player *p)
       {
         for (int y = 0; y < getHeight(); y++)
           {
-            std::list<Item*> items = getTile(x, y)->getItems();
-            for (std::list<Item*>::iterator it = items.begin(); 
-                 it != items.end(); it++)
-              {
-                if ((*it)->isPlantable() && (*it)->getPlantableOwner() == p &&
-		    (*it)->getPlanted() == true)
-                  {
-                    pos.x = x;
-                    pos.y = y;
-                    found = true;
-                    break;
-                  }
-              }
-            if (found)
-              break;
+	    MapBackpack *backpack = getTile(x, y)->getBackpack();
+	    found = backpack->getPlantedItem(p) != NULL;
+	    if (found)
+	      {
+		pos.x = x;
+		pos.y = y;
+		break;
+	      }
           }
       }
   return pos;
@@ -612,7 +632,7 @@ TileStyle *GameMap::calculatePreferredStyle(int i, int j)
 	  continue;
 	if ((j+l) >= s_width || (j+l) < 0)
 	  continue;
-	box[k+1][l+1] = (getTile(j+l, i+k)->getType() == mtile->getType());
+	box[k+1][l+1] = are_those_tiles_similar(getTile(j+l, i+k)->getMaptileType(), mtile->getMaptileType(), false);
       }
   if (box[0][0] && box[0][1] && box[0][2] &&
       box[1][0] && box[1][1] && box[1][2] &&
@@ -763,6 +783,28 @@ void GameMap::close_circles (int minx, int miny, int maxx, int maxy)
     }
 }
 
+bool GameMap::are_those_tiles_similar(Tile::Type outer_tile,Tile::Type inner_tile, bool checking_loneliness)
+{
+    if(checking_loneliness || inner_tile == Tile::HILLS)
+    {
+        if( (outer_tile == Tile::MOUNTAIN && inner_tile == Tile::HILLS) ||
+            (inner_tile == Tile::MOUNTAIN && outer_tile == Tile::HILLS))
+            // Mountains and hills are similar, MapGenerator::surroundMountains()
+            // makes sure that mountains are surrounded by hills. So a hill tile
+            // with only a mountain neighbour is not a lone tile
+            //
+            // There never should be a lone mountain in grass (not surrounded by hills).
+            // Mountain surrounded by hills is perfectly correct.
+            return true;
+        return outer_tile == inner_tile;
+    } 
+    else 
+    { // to pick correct tile picture for a mountain we treat hills as a tile
+      // different than mountain.
+        return outer_tile == inner_tile;
+    }
+}
+
 int GameMap::tile_is_connected_to_other_like_tiles (Tile::Type tile, int i, int j)
 {
   int box[3][3];
@@ -774,7 +816,7 @@ int GameMap::tile_is_connected_to_other_like_tiles (Tile::Type tile, int i, int
 	  continue;
 	if ((j+l) >= s_width || (j+l) < 0)
 	  continue;
-	box[k+1][l+1] = (getTile(j+l, i+k)->getMaptileType() == tile);
+	box[k+1][l+1] = are_those_tiles_similar(getTile(j+l, i+k)->getMaptileType(), tile, true);
       }
   if (box[0][0] && box[0][1] && box[1][0] && box[1][1])
     return 1;
@@ -822,10 +864,11 @@ void GameMap::applyTileStyles (int minx, int miny, int maxx, int maxy,
 
   if (smooth_terrain)
     {
-      demote_lone_tile(0, 0, s_height, s_width, Tile::FOREST, Tile::GRASS);
-      demote_lone_tile(0, 0, s_height, s_width, Tile::MOUNTAIN, Tile::HILLS);
-      demote_lone_tile(0, 0, s_height, s_width, Tile::HILLS, Tile::GRASS);
-      demote_lone_tile(0, 0, s_height, s_width, Tile::WATER, Tile::SWAMP);
+      demote_lone_tile(minx, miny, maxx, maxy, Tile::FOREST, Tile::GRASS);
+      demote_lone_tile(minx, miny, maxx, maxy, Tile::MOUNTAIN, Tile::HILLS);
+      demote_lone_tile(minx, miny, maxx, maxy, Tile::HILLS, Tile::GRASS);
+      demote_lone_tile(minx, miny, maxx, maxy, Tile::WATER, Tile::SWAMP);
+      surroundMountains(minx, miny, maxx, maxy);
     }
 
   for (int i = minx; i < maxx; i++)
@@ -836,16 +879,7 @@ void GameMap::applyTileStyles (int minx, int miny, int maxx, int maxy,
 	    continue;
 	  if (j < 0 || j >= s_width)
 	    continue;
-	  Maptile *mtile = getTile(j, i);
-	  Tileset *tileset = getTileset();
-	  TileStyle *style = calculatePreferredStyle(i, j);
-	  if (!style)
-	    style = tileset->getRandomTileStyle(mtile->getType(), 
-						TileStyle::LONE);
-	  if (!style)
-	    style = tileset->getRandomTileStyle(mtile->getType(), 
-						TileStyle::INNERMIDDLECENTER);
-	  mtile->setTileStyle(style);
+	  applyTileStyle(i, j);
 	}
     }
   close_circles(minx, miny, maxx, maxy);
@@ -858,10 +892,51 @@ std::vector<Vector<int> > GameMap::getItems()
     for (int i = 0; i < s_width; i++)
       {
 	if (d_map[j*s_width + i])
-	  if (d_map[j*s_width + i]->getItems().empty() == false)
+	  if (d_map[j*s_width + i]->getBackpack()->empty() == false)
 	    items.push_back(Vector<int>(i, j));
 
       }
   return items;
 }
 
+#define offmap(bx,by) (by<0)||(by>=s_height)||(bx<0)||(bx>=s_width)
+void GameMap::surroundMountains(int minx, int miny, int maxx, int maxy)
+{
+  for(int j = miny; j < maxy; j++)
+    for(int i = minx; i < maxx; i++)
+      if(getTile(j, i)->getMaptileType() == Tile::MOUNTAIN)
+	for(int J = -1; J <= +1; ++J)
+	  for(int I = -1; I <= +1; ++I)
+	    if((!(offmap(j+J,i+I))) &&
+	       (getTile((j+J),(i+I))->getMaptileType() != Tile::MOUNTAIN))
+	      {
+		if(getTile((j+J), (i+I))->getMaptileType() != Tile::WATER)
+		  setTile(j+J, i+I, 
+			  new Maptile (d_tileSet, j+J, i+I, 
+				       d_tileSet->getIndex(Tile::HILLS), NULL));
+		else 
+		  // water has priority here, there was some work done to conenct bodies of water
+		  // so don't break those connections.
+		  setTile(j, i, 
+			  new Maptile (d_tileSet, j, i, 
+				       d_tileSet->getIndex(Tile::HILLS), NULL));
+	      }
+}
+
+void GameMap::applyTileStyle (int i, int j)
+{
+  Maptile *mtile = getTile(j, i);
+  Tileset *tileset = getTileset();
+  TileStyle *style = calculatePreferredStyle(i, j);
+  if (!style)
+    style = tileset->getRandomTileStyle(mtile->getType(), 
+					TileStyle::LONE);
+  if (!style)
+    style = tileset->getRandomTileStyle(mtile->getType(), 
+					TileStyle::INNERMIDDLECENTER);
+  if (!style)
+    printf ("applying null tile style at %d,%d for tile of kind %d\n", i, j,
+	    mtile->getMaptileType());
+  mtile->setTileStyle(style);
+}
+
