@@ -27,6 +27,7 @@
 #include <uuid/uuid.h>
 
 #include "GameScenario.h"
+#include "Campaign.h"
 #include "MapGenerator.h"
 #include "playerlist.h"
 #include "FogMap.h"
@@ -45,6 +46,7 @@
 #include "tilesetlist.h"
 #include "shieldsetlist.h"
 #include "stacklist.h"
+#include "stack.h"
 #include "GameMap.h"
 #include "player.h"
 #include "Configuration.h"
@@ -61,6 +63,7 @@
 #include "history.h"
 #include "xmlhelper.h"
 
+std::string GameScenario::d_tag = "scenario";
 using namespace std;
 
 #define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
@@ -154,19 +157,38 @@ bool GameScenario::setupFog(bool hidden_map)
   return true;
 }
 
+bool GameScenario::setupStacks(bool hidden_map)
+{
+  if (!hidden_map)
+    return true;
+  for (Playerlist::iterator it = Playerlist::getInstance()->begin();
+       it != Playerlist::getInstance()->end(); it++)
+    {
+      if ((*it) == Playerlist::getInstance()->getNeutral())
+	continue;
+      for (Stacklist::iterator sit = (*it)->getStacklist()->begin(); 
+	   sit != (*it)->getStacklist()->end(); sit++)
+	(*sit)->deFog();
+    }
+  return true;
+}
+
 bool GameScenario::setupCities(bool quick_start)
 {
   debug("GameScenario::setupCities")
 
-  for (Citylist::iterator it = Citylist::getInstance()->begin();
-       it != Citylist::getInstance()->end(); it++)
+  for (Playerlist::iterator it = Playerlist::getInstance()->begin();
+       it != Playerlist::getInstance()->end(); it++)
     {
-      if ((*it).isCapital() == true)
+      if ((*it) == Playerlist::getInstance()->getNeutral())
+	continue;
+      City *city = Citylist::getInstance()->getFirstCity(*it);
+      if (city)
 	{
-	  (*it).deFog((*it).getOwner());
+	  city->deFog(city->getOwner());
 	  History_CityWon *item = new History_CityWon();
-	  item->fillData(&*it);
-	  (*it).getCapitalOwner()->addHistory(item);
+	  item->fillData(city);
+	  city->getOwner()->addHistory(item);
 	}
     }
 
@@ -176,33 +198,33 @@ bool GameScenario::setupCities(bool quick_start)
   for (Citylist::iterator it = Citylist::getInstance()->begin();
        it != Citylist::getInstance()->end(); it++)
     {
-      if ((*it).getOwner() == Playerlist::getInstance()->getNeutral())
+      if ((*it)->getOwner() == Playerlist::getInstance()->getNeutral())
 	{
 	  switch (GameScenario::s_neutral_cities)
 	    {
 	    case GameParameters::AVERAGE:
-	      (*it).produceScout();
+	      (*it)->produceScout();
 	      break;
 	    case GameParameters::STRONG:
-	      (*it).produceStrongestProductionBase();
+	      (*it)->produceStrongestProductionBase();
 	      break;
 	    case GameParameters::ACTIVE:
 	      if (rand () % 100 >  20)
-		(*it).produceStrongestProductionBase();
+		(*it)->produceStrongestProductionBase();
 	      else
-		(*it).produceWeakestProductionBase();
+		(*it)->produceWeakestProductionBase();
 	      break;
 	    }
-	  (*it).setActiveProductionSlot(-1);
+	  (*it)->setActiveProductionSlot(-1);
 	}
       else
 	{
-	  if ((*it).isCapital())
-	    (*it).produceStrongestProductionBase();
+	  if ((*it)->isCapital())
+	    (*it)->produceStrongestProductionBase();
 	  else
-	    (*it).produceWeakestProductionBase();
+	    (*it)->produceWeakestProductionBase();
 
-	  (*it).setActiveProductionSlot(0);
+	  (*it)->setActiveProductionSlot(0);
 	}
 
     }
@@ -247,21 +269,22 @@ bool GameScenario::loadWithHelper(XML_Helper& helper)
 
   bool broken = false;
 
-  helper.registerTag("scenario", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("itemlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("playerlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("map", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("citylist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("templelist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("ruinlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("rewardlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("signpostlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("roadlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("counter", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("questlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("bridgelist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("portlist", sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag("vectoredunitlist", sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Campaign::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Itemlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Playerlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(GameMap::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Citylist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Templelist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Ruinlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Rewardlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Signpostlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Roadlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(FL_Counter::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(QuestsManager::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Bridgelist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(Portlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
+  helper.registerTag(VectoredUnitlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
 
   if (!helper.parse())
     broken = true;
@@ -288,6 +311,7 @@ GameScenario::~GameScenario()
   Roadlist::deleteInstance();
   QuestsManager::deleteInstance();
   VectoredUnitlist::deleteInstance();
+  Campaign::deleteInstance();
 
   if (fl_counter)
     {
@@ -373,9 +397,10 @@ bool GameScenario::saveWithHelper(XML_Helper &helper) const
   retval &= Bridgelist::getInstance()->save(&helper);
   retval &= QuestsManager::getInstance()->save(&helper);
   retval &= VectoredUnitlist::getInstance()->save(&helper);
+  retval &= Campaign::getInstance()->save(&helper);
 
   //save the private GameScenario data last due to dependencies
-  retval &= helper.openTag("scenario");
+  retval &= helper.openTag(GameScenario::d_tag);
   retval &= helper.saveData("id", d_id);
   retval &= helper.saveData("name", d_name);
   retval &= helper.saveData("comment", d_comment);
@@ -408,7 +433,7 @@ bool GameScenario::saveWithHelper(XML_Helper &helper) const
 
 bool GameScenario::load(std::string tag, XML_Helper* helper)
 {
-  if (tag == "scenario")
+  if (tag == GameScenario::d_tag)
     {
       if (helper->getVersion() != LORDSAWAR_SAVEGAME_VERSION)
 	{
@@ -448,36 +473,43 @@ bool GameScenario::load(std::string tag, XML_Helper* helper)
 
       return true;
     }
+  
+  if (tag == Campaign::d_tag)
+    {
+      debug("loading campaign")
+      Campaign::getInstance(helper);
+      return true;
+    }
 
-  if (tag == "counter")
+  if (tag == FL_Counter::d_tag)
     {
       debug("loading counter")
 	fl_counter = new FL_Counter(helper);
       return true;
     }
 
-  if (tag == "itemlist")
+  if (tag == Itemlist::d_tag)
     {
       debug("loading items");
       Itemlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "playerlist")
+  if (tag == Playerlist::d_tag)
     {
       debug("loading players");
       Playerlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "map")
+  if (tag == GameMap::d_tag)
     {
       debug("loading map")
 	GameMap::getInstance(helper);
       return true;
     }
 
-  if (tag == "citylist")
+  if (tag == Citylist::d_tag)
     {
       debug("loading cities")
 
@@ -485,63 +517,63 @@ bool GameScenario::load(std::string tag, XML_Helper* helper)
       return true;
     }
 
-  if (tag == "templelist")
+  if (tag == Templelist::d_tag)
     {
       debug("loading temples")
 	Templelist::getInstance(helper);
       return true;
     }
 
-  if (tag == "ruinlist")
+  if (tag == Ruinlist::d_tag)
     {
       debug("loading ruins")
 	Ruinlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "rewardlist")
+  if (tag == Rewardlist::d_tag)
     {
       debug("loading rewards")
 	Rewardlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "signpostlist")
+  if (tag == Signpostlist::d_tag)
     {
       debug("loading signposts")
 	Signpostlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "roadlist")
+  if (tag == Roadlist::d_tag)
     {
       debug("loading roads")
 	Roadlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "questlist")
+  if (tag == QuestsManager::d_tag)
     {
       debug("loading quests")
 	QuestsManager::getInstance(helper);
       return true;
     }
 
-  if (tag == "vectoredunitlist")
+  if (tag == VectoredUnitlist::d_tag)
     {
       debug("loading vectored units")
 	VectoredUnitlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "portlist")
+  if (tag == Portlist::d_tag)
     {
       debug("loading ports")
 	Portlist::getInstance(helper);
       return true;
     }
 
-  if (tag == "bridgelist")
+  if (tag == Bridgelist::d_tag)
     {
       debug("loading bridges")
 	Bridgelist::getInstance(helper);
