@@ -47,6 +47,8 @@ class GameScenario: public GameScenarioOptions
 {
     public:
 
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag;
 
         enum PlayMode 
 	  {
@@ -116,6 +118,7 @@ class GameScenario: public GameScenarioOptions
 
 	bool setupFog(bool hidden_map);
 	bool setupCities(bool quick_start);
+	bool setupStacks(bool hidden_map);
 	void setupDiplomacy(bool diplomacy);
         
 	Uint32 getPlayMode() const {return d_playmode;};
