@@ -22,6 +22,7 @@
 
 #include <string>
 #include <list>
+#include <vector>
 
 #include "player.h"
 #include "defs.h"
@@ -121,6 +122,7 @@ class GraphicsCache
           */
         SDL_Surface* getArmyPic(Uint32 armyset, Uint32 army, const Player* p,
                                 const bool* medals);
+	SDL_Surface* getArmyPic(Army *a);
 
         /** Function for getting the shield picture from the cache
           * 
@@ -270,6 +272,8 @@ class GraphicsCache
           * @return image for the shield
           */
         SDL_Surface* getShieldPic(Uint32 type, const Player* p);
+
+
         SDL_Surface* getSmallRuinedCityPic();
         SDL_Surface* getSmallHeroPic();
         SDL_Surface* getPortPic();
@@ -309,6 +313,10 @@ class GraphicsCache
         SDL_Surface* applyMask(SDL_Surface* image, SDL_Surface* mask, const Player* p);
 	static SDL_Surface* applyMask(SDL_Surface* image, SDL_Surface* mask, SDL_Color mask_color, bool isNeutral);
         
+	static bool loadSelectorImages(std::string tileset, std::string filename, Uint32 tilesize, std::vector<SDL_Surface*> &images, std::vector<SDL_Surface *> &masks);
+
+	Uint32 getNumberOfLargeSelectorFrames() {return d_selector.size();};
+	Uint32 getNumberOfSmallSelectorFrames() {return d_smallselector.size();}
     private:
         GraphicsCache();
         ~GraphicsCache();
@@ -452,13 +460,20 @@ class GraphicsCache
 
         //! Loads the images for the two selectors
         void loadSelectors();
+
         
         //! Loads the images for the production shields
         void loadProdShields();
         
         //! Loads the images for the movement bonuses
         void loadMoveBonusPics();
-        
+        /** Get a cityset picture
+          * @param citysetname       the name of the cityset
+          * @param picname          the name of the picture
+          * @return the surface which contains the picture
+          */
+        static SDL_Surface* getCitysetPicture(std::string citysetname, std::string picname);
+
         //the data
         static GraphicsCache* s_instance;
 
@@ -494,10 +509,14 @@ class GraphicsCache
         SDL_Surface* d_razedpic[MAX_PLAYERS + 1]; //+1 for neutral
         SDL_Surface* d_flagpic[MAX_STACK_SIZE];
         SDL_Surface* d_flagmask[MAX_STACK_SIZE];
-	SDL_Surface* d_selector[SELECTOR_FRAMES];
-	SDL_Surface* d_selectormask[SELECTOR_FRAMES];
-	SDL_Surface* d_smallselector[SMALL_SELECTOR_FRAMES];
-	SDL_Surface* d_smallselectormask[SMALL_SELECTOR_FRAMES];
+	//SDL_Surface* d_selector[SELECTOR_FRAMES];
+	//SDL_Surface* d_selectormask[SELECTOR_FRAMES];
+	std::vector<SDL_Surface*> d_selector;
+	std::vector<SDL_Surface*> d_selectormask;
+	std::vector<SDL_Surface*> d_smallselector;
+	std::vector<SDL_Surface*> d_smallselectormask;
+	//SDL_Surface* d_smallselector[SMALL_SELECTOR_FRAMES];
+	//SDL_Surface* d_smallselectormask[SMALL_SELECTOR_FRAMES];
         SDL_Surface* d_prodshieldpic[PRODUCTION_SHIELD_TYPES];
 	SDL_Surface* d_smallruinedcity;
 	SDL_Surface* d_smallhero;
