@@ -4,6 +4,7 @@
 // Copyright (C) 2004 David Barnsdale
 // Copyright (C) 2004 Andrea Paternesi
 // Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2008 Janek Kozicki
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,6 +25,8 @@
 #define MAPGENERATOR_H
 
 #include <string>
+#include <deque>
+#include "vector.h"
 #include <vector>
 #include <sigc++/signal.h>
 
@@ -84,7 +87,7 @@ class MapGenerator
         void setPercentages(int pwater, int pforest, int pswamp,
                             int phills, int pmountains);
 
-        
+
         //! Get number of cities
         int getNoCities() const {return d_nocities;}
 
@@ -96,8 +99,8 @@ class MapGenerator
 
         //! Get number of temples
         int getNoTemples() const {return d_notemples;}
-        
-        
+
+
         /** Creates a map
           * 
           * Use this function to start off the map generation. This
@@ -109,6 +112,12 @@ class MapGenerator
           */
         void makeMap(int width, int height, bool roads);
 
+        /** A debug function, prints map to std::cout, using convention mentioned
+          * at MapGenerator::makeMap
+          */
+        void printMap(int j, int i);
+        void printMap();
+
         /** Get the array for the terrain map (shallow copy)
           * 
           * @param width        is set to the width of the generated map
@@ -116,7 +125,7 @@ class MapGenerator
           * @return char array which represents the terrain map
           */
         const Tile::Type* getMap(int& width, int& height) const;
-        
+
         /** Get the buildings map (shallow copy)
           * 
           * @param width        is set to the width of the generated map
@@ -125,11 +134,11 @@ class MapGenerator
           */
         const Maptile::Building* getBuildings(int& width, int& height) const;
 
-	/**
-	 * @param fraction How far along the progress bar should be.
-	 * @param status   A description of what's being generated.
-	 */
-	//! Emitted when the generator generates something
+        /**
+         * @param fraction How far along the progress bar should be.
+         * @param status   A description of what's being generated.
+         */
+        //! Emitted when the generator generates something
         sigc::signal<void, double, std::string> progress;
 
     protected:
@@ -152,6 +161,54 @@ class MapGenerator
         void makeTerrain(Tile::Type t, int percent, bool contin);
         void makeStreamer(Tile::Type type, int percent, int width);
 
+        /**
+          * Water is special - in real world we usually have one big ocean, and
+          * everything flowing into it with rivers. To avoid generating lots of
+          * unconnected bodies of water (those should be swamps in general,
+          * maybe a pond) we need to find biggest body of water and connect
+          * others with it, using rivers. Ponds are allowed, but not too much of them.
+          */
+        void makeRivers();
+        /**
+          * This helper function searches whole map for enclosed ares of
+          * THIS_TILE. Each such area gets a subsequent number which is
+          * assigned to corresponding cell in box. Maximum number of areas
+          * found is how_many and equals to highest number found in box.
+          */ 
+        void findAreasOf(Tile::Type THIS_TILE,std::vector<std::vector<int> >& box,int& how_many);
+        /**
+          * Too much randomness and rivers can create too many small islands
+          * which normally would be eroded by water along the centuries of
+          * passing time. This function eliminates those islands keeping only
+          * few of them. The randomly generated map looks more realistic in this way.
+          */
+        void verifyIslands();
+
+        void makeBridges();
+	bool canPlaceBridge(Vector<int> pos);
+	void placeBridge(Vector<int> pos, int type);
+        
+        /**
+          * Once makeRivers() finds a connection path between two bodies of water
+          * it calls this function to put water on that path.
+          */
+        void connectWithWater(Vector<int> from, Vector<int> to);
+
+        /** Mountains are specific - they must always be surrounded by hills,
+          * othwerwise the map graphically looks bad. Besides who has ever seen
+          * a mountain without even a tiny amount of hills around?
+          *
+          * This means that a lone montains becomes surrounded by hills and
+          * is not lone anymore. See GameMap::are_those_tiles_similar().
+          */
+        void surroundMountains(int minx, int maxx, int miny, int maxy);
+
+        /** Paving roads and putting cities can create lone mountains.
+          * Making rivers can also create lone tiles.
+          * We need to rescue them!
+          */
+        void rescueLoneTiles(Tile::Type FIND_THIS, Tile::Type REPLACE, bool grow);
+
         /** Tries to find the nearest grass tile from a given location.
           *
           * This function becomes e.g. neccessary if you want to create 
@@ -173,7 +230,7 @@ class MapGenerator
           * @param cities       the number of cities to distribute
           */
         void makeCities(int cities);
-        
+
         //! Returns true if position (x,y) is free for a city
         bool canPutCity(int x, int y);
 
@@ -187,10 +244,10 @@ class MapGenerator
           * @param building     the number of buildings to distribute
           */
         void makeBuildings(Maptile::Building b, int building);
-        
+
         //! Returns true if position (x,y) is free for buildings
         bool canPutBuilding(int x, int y);
-        
+
         /** Tries to place a city around a certain position.
           * 
           * This function is used internally for placing ports, that
@@ -202,7 +259,7 @@ class MapGenerator
           */
         bool tryToPlaceCity(int px, int py, int& city_count);
 
-        
+
         /** Normalizes the terrain
           * 
           * With normalization, we mean that if a tile is surrounded mainly
@@ -221,8 +278,41 @@ class MapGenerator
 	bool makeAccessible(Vector<int> src, Vector<int> dest);
 	bool makeAccessible(int src_x, int src_y, int dest_x, int dest_y);
 	void makeRoads();
+
+        /** Find all places where it's possible to place a bridge:
+          *
+          * Bridge length is 2 tiles. So we can find two options:
+          *
+          * type=1       type=2
+          *
+          * +-+-+-+      +-+-+-+-+
+          * |0|.|.|      |0|=|=|.|     x-----> width - i
+          * +-+-+-+      +-+-+-+-+     |
+          * |=|=|=|      |.|=|=|.|     | 
+          * +-+-+-+  or  +-+-+-+-+    \|/
+          * |=|=|=|      |.|=|=|.|     '
+          * +-+-+-+      +-+-+-+-+   height - j
+          * |.|.|.|               
+          * +-+-+-+               
+          *
+          * this functions returns a randommly sorted vector of all possible
+          * places for bridges in
+          *
+          * std::vector<std::pair<int , Vector<int> > >
+          *    .first is type, 
+          *    .second is (j,i) coordinates of '0' point in there.
+          *
+          * The vector is randomly sorted, so just pick the first few - as much
+          * as you need, and they will be in random (probably in not close to
+          * each other locations).
+          *
+          * The output is checked and "duplicate" brigdes (which are close to
+          * each other - because the river is straight) are removed.
+          */ 
+        std::vector<std::pair < int , Vector<int> > > findBridgePlaces();
 	bool placePort(int x, int y);
 	void calculateBlockedAvenue(int x, int y);
+	bool inhospitableTerrain(int x, int y, unsigned int width);
 
         //Data
         int d_xdir[8];
