@@ -19,8 +19,8 @@
 
 #include "xmlhelper.h"
 
-NamedLocation::NamedLocation(Vector<int> pos, std::string name)
-  :Location(pos), Namable(name)
+NamedLocation::NamedLocation(Vector<int> pos, Uint32 size, std::string name)
+  :Location(pos, size), Namable(name)
 {
 }
 
@@ -29,8 +29,8 @@ NamedLocation::NamedLocation(const NamedLocation& object)
 {
 }
 
-NamedLocation::NamedLocation(XML_Helper* helper)
-  :Location(helper), Namable(helper)
+NamedLocation::NamedLocation(XML_Helper* helper, Uint32 size)
+  :Location(helper, size), Namable(helper)
 {
 }
 
