@@ -18,7 +18,6 @@
 #ifndef NAMEDLOCATION_H
 #define NAMEDLOCATION_H
 
-#include "defs.h"
 #include "vector.h"
 #include "Location.h"
 #include "Namable.h"
@@ -34,11 +33,11 @@ class NamedLocation: public Location, public Namable
 {
  public:
      //! Default constructor.
-     NamedLocation(Vector<int> pos, std::string name);
+     NamedLocation(Vector<int> pos, Uint32 size, std::string name);
      //! Copy constructor.
      NamedLocation(const NamedLocation&);
      //! Loading constructor.
-     NamedLocation(XML_Helper* helper);
+     NamedLocation(XML_Helper* helper, Uint32 size);
      //! Destructor.
     ~NamedLocation();
 
