@@ -25,7 +25,6 @@
 #include "citylist.h"
 #include "playerlist.h"
 #include "stack.h"
-#include "defs.h"
 #include "xmlhelper.h"
 
 using namespace std;
@@ -75,7 +74,7 @@ bool QuestCitySack::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("quest");
+    retval &= helper->openTag(Quest::d_tag);
     retval &= Quest::save(helper);
     retval &= helper->saveData("city", d_city);
     retval &= helper->closeTag();
@@ -107,8 +106,8 @@ City* QuestCitySack::getCity() const
 {
     Citylist* cl = Citylist::getInstance();
     for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
-        if ((*it).getId() == d_city)
-            return &(*it);
+        if ((*it)->getId() == d_city)
+            return (*it);
 
     return 0;
 }
@@ -131,10 +130,10 @@ City * QuestCitySack::chooseToSack(Player *p)
     // Collect all cities
     Citylist* cl = Citylist::getInstance();
     for (Citylist::iterator it = cl->begin(); it != cl->end(); ++it)
-        if (!(*it).isBurnt() && (*it).getOwner() != p && 
-            (*it).getNoOfProductionBases() > 1 &&
-	    (*it).getOwner() != Playerlist::getInstance()->getNeutral())
-            cities.push_back(&(*it));
+        if (!(*it)->isBurnt() && (*it)->getOwner() != p && 
+            (*it)->getNoOfProductionBases() > 1 &&
+	    (*it)->getOwner() != Playerlist::getInstance()->getNeutral())
+            cities.push_back((*it));
 
     // Find a suitable city for us to sack
     if (cities.empty())
