@@ -83,7 +83,7 @@ bool QuestKillHero::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("quest");
+    retval &= helper->openTag(Quest::d_tag);
     retval &= Quest::save(helper);
     retval &= helper->saveData("to_kill", d_victim);
     retval &= helper->closeTag();
