@@ -64,6 +64,9 @@ class QuestsManager : public sigc::trackable
 {
     public:
 
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         //! Gets the singleton instance or creates a new one.
         static QuestsManager* getInstance();
 
