@@ -50,7 +50,7 @@ using namespace std;
 
 AI_Fast::AI_Fast(string name, Uint32 armyset, SDL_Color color, int width, int height, int player_no)
     :RealPlayer(name, armyset, color, width, height, Player::AI_FAST, player_no), d_join(true),
-    d_maniac(false), d_analysis(0), d_diplomacy(0)
+    d_maniac(false), d_analysis(0), d_diplomacy(0), d_abort_requested(false)
 {
 }
 
@@ -59,10 +59,11 @@ AI_Fast::AI_Fast(const Player& player)
     d_diplomacy(0)
 {
     d_type = AI_FAST;
+    d_abort_requested = false;
 }
 
 AI_Fast::AI_Fast(XML_Helper* helper)
-    :RealPlayer(helper), d_analysis(0), d_diplomacy(0)
+    :RealPlayer(helper), d_analysis(0), d_diplomacy(0), d_abort_requested(false)
 {
     helper->getData(d_join, "join");
     helper->getData(d_maniac, "maniac");
@@ -80,7 +81,7 @@ bool AI_Fast::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("player");
+    retval &= helper->openTag(Player::d_tag);
     retval &= helper->saveData("join", d_join);
     retval &= helper->saveData("maniac", d_maniac);
     retval &= Player::save(helper);
@@ -89,6 +90,11 @@ bool AI_Fast::save(XML_Helper* helper) const
     return retval;
 }
 
+void AI_Fast::abortTurn()
+{
+  d_abort_requested = true;
+}
+
 bool AI_Fast::startTurn()
 {
     AI_maybeBuyScout();
@@ -118,7 +124,7 @@ bool AI_Fast::startTurn()
 	Citylist *cl = Citylist::getInstance();
 	for (Citylist::iterator cit = cl->begin(); cit != cl->end(); ++cit)
 	  {
-	    City *c = &*cit;
+	    City *c = *cit;
 	    if (c->getOwner() != this || c->isBurnt())
 	      continue;
 	    if (c->getActiveProductionSlot() == -1)
@@ -158,6 +164,8 @@ bool AI_Fast::startTurn()
 	  }
 	if (found)
 	  found = false;
+	if (d_abort_requested)
+	  break;
       }
 
     delete d_analysis;
@@ -169,6 +177,8 @@ bool AI_Fast::startTurn()
     if (GameScenarioOptions::s_diplomacy)
       d_diplomacy->makeProposals();
 
+    if (d_abort_requested)
+      aborted_turn.emit();
     return true;
 }
 
@@ -553,6 +563,8 @@ bool AI_Fast::computerTurn()
 	    continue;
 
 	  }
+	if (d_abort_requested)
+	  break;
     }
     return stack_moved;
 }
