@@ -45,7 +45,7 @@ using namespace std;
 
 AI_Smart::AI_Smart(string name, unsigned int armyset, SDL_Color color, int width, int height, int player_no)
   :RealPlayer(name, armyset, color, width, height, Player::AI_SMART, player_no),
-   d_mustmakemoney(0)
+   d_mustmakemoney(0), d_abort_requested(false)
 {
 }
 
@@ -53,10 +53,11 @@ AI_Smart::AI_Smart(const Player& player)
     :RealPlayer(player),d_mustmakemoney(0)
 {
     d_type = AI_SMART;
+    d_abort_requested = false;
 }
 
 AI_Smart::AI_Smart(XML_Helper* helper)
-    :RealPlayer(helper),d_mustmakemoney(0)
+    :RealPlayer(helper),d_mustmakemoney(0), d_abort_requested(false)
 {
 }
 
@@ -86,7 +87,7 @@ bool AI_Smart::startTurn()
 
     AI_setupVectoring(18, 2, 30);
 
-    int loopCount = 0;
+    //int loopCount = 0;
     while (true)
     {
         // if the code is working, this loop will eventually terminate.
@@ -107,14 +108,23 @@ bool AI_Smart::startTurn()
         // stop when no more stacks move
         if (moveCount == 0)
             break;
+	if (d_abort_requested)
+	  break;
     }
     d_stacklist->setActivestack(0);
 
     diplomacy.makeProposals();
     
+    if (d_abort_requested)
+      aborted_turn.emit();
     return true;
 }
 
+void AI_Smart::abortTurn()
+{
+  d_abort_requested = true;
+}
+
 void AI_Smart::invadeCity(City* c)
 {
     // always occupy an enemy city
@@ -192,7 +202,7 @@ int AI_Smart::setBestProduction(City *c)
     int scorebasic = -1;
 
     // we try to determine the most attractive basic production
-    for (int i = 0; i < c->getMaxNoOfProductionBases(); i++)
+    for (Uint32 i = 0; i < c->getMaxNoOfProductionBases(); i++)
     {
         if (c->getArmytype(i) == -1)    // no production in this slot
             continue;
@@ -319,7 +329,7 @@ void AI_Smart::examineCities()
     Citylist* cl = Citylist::getInstance();
     for (Citylist::iterator it = cl->begin(); it != cl->end(); ++it)
     {
-        City *city = &(*it);
+        City *city = (*it);
         if ((city->isFriend(this)) && (city->isBurnt()==false))
         {
             // Here we wait to earn more money so we do not buy new productions
