@@ -19,6 +19,7 @@
 //  02110-1301, USA.
 
 #include <iostream>
+#include <algorithm>
 #include <expat.h>
 #include <SDL_image.h>
 #include <SDL.h>
@@ -29,7 +30,7 @@
 #include "armyset.h"
 #include "File.h"
 #include "defs.h"
-
+#include "ucompose.hpp"
 
 
 using namespace std;
@@ -69,8 +70,9 @@ Armysetlist::Armysetlist()
 	for (Armyset::iterator ait = (*it)->begin(); ait != (*it)->end(); ait++)
 	  d_armies[(*it)->getId()].push_back(*ait);
 	d_names[(*it)->getId()] = (*it)->getName();
-	d_ids[(*it)->getName()] = (*it)->getId();
+	d_ids[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = (*it)->getId();
 	(*it)->setSubDir(*i);
+	d_armysets[*i] = *it;
       }
 }
 
@@ -135,6 +137,15 @@ std::list<std::string> Armysetlist::getNames()
   return names;
 }
 
+std::list<std::string> Armysetlist::getNames(Uint32 tilesize)
+{
+  std::list<std::string> names;
+  for (iterator it = begin(); it != end(); it++)
+    if ((*it)->getTileSize() == tilesize)
+      names.push_back((*it)->getName());
+  return names;
+}
+
 std::string Armysetlist::getName(Uint32 id) const
 {
     NameMap::const_iterator it = d_names.find(id);
@@ -161,7 +172,7 @@ std::vector<Uint32> Armysetlist::getArmysets() const
 
 bool Armysetlist::load(std::string tag, XML_Helper *helper)
 {
-  if (tag == "armyset")
+  if (tag == Armyset::d_tag)
     {
       Armyset *armyset = new Armyset(helper);
       push_back(armyset); 
@@ -176,7 +187,7 @@ bool Armysetlist::loadArmyset(std::string name)
 
   XML_Helper helper(File::getArmyset(name), ios::in, false);
 
-  helper.registerTag("armyset", sigc::mem_fun((*this), &Armysetlist::load));
+  helper.registerTag(Armyset::d_tag, sigc::mem_fun((*this), &Armysetlist::load));
 
   if (!helper.parse())
     {
@@ -247,3 +258,22 @@ Armyset *Armysetlist::getArmyset(Uint32 id)
     }
   return NULL;
 }
+
+void Armysetlist::getSizes(std::list<Uint32> &sizes)
+{
+  for (iterator i = begin(); i != end(); i++)
+    {
+      if (find (sizes.begin(), sizes.end(), (*i)->getTileSize()) == sizes.end())
+	sizes.push_back((*i)->getTileSize());
+    }
+}
+
+Uint32 Armysetlist::getArmysetId(std::string armyset, Uint32 tilesize)
+{
+  return d_ids[String::ucompose("%1 %2", armyset, tilesize)];
+}
+
+std::string Armysetlist::getArmysetDir(std::string name, Uint32 tilesize)
+{
+  return getArmyset(getArmysetId(name, tilesize))->getSubDir();
+}
