@@ -34,8 +34,9 @@
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
-Citylist* Citylist::s_instance = 0;
+std::string Citylist::d_tag = "citylist";
 
+Citylist* Citylist::s_instance = 0;
 
 Citylist* Citylist::getInstance()
 {
@@ -69,9 +70,7 @@ Citylist::Citylist()
 Citylist::Citylist(XML_Helper* helper)
 {
     // simply ask the helper to inform us when a city tag is opened
-    helper->registerTag("city", sigc::mem_fun(this, &Citylist::load));
-    helper->registerTag("armyprodbase", sigc::mem_fun(this, &Citylist::load));
-    helper->registerTag("slot", sigc::mem_fun(this, &Citylist::load));
+    helper->registerTag(City::d_tag, sigc::mem_fun(this, &Citylist::load));
 }
 
 Citylist::~Citylist()
@@ -84,9 +83,9 @@ int Citylist::countCities(Player* player) const
     
     for (const_iterator it = begin(); it != end(); it++)
     {
-        if ((*it).isBurnt())
+        if ((*it)->isBurnt())
           continue;
-        if ((*it).getOwner() == player) cities++;
+        if ((*it)->getOwner() == player) cities++;
     }
     
     return cities;
@@ -96,8 +95,8 @@ void Citylist::collectTaxes(Player* p)
 {
   // Collect the taxes
   for (const_iterator it = begin(); it != end(); it++)
-    if ((*it).getOwner() == p && (*it).isBurnt() == false)
-      p->addGold((*it).getGold());
+    if ((*it)->getOwner() == p && (*it)->isBurnt() == false)
+      p->addGold((*it)->getGold());
 
 }
 
@@ -106,14 +105,14 @@ Uint32 Citylist::calculateUpcomingUpkeep(Player *p)
 {
   Uint32 total = 0;
   for (const_iterator it = begin(); it != end(); it++)
-    if ((*it).getOwner() == p && (*it).isBurnt() == false)
+    if ((*it)->getOwner() == p && (*it)->isBurnt() == false)
       {
-	if ((*it).getDuration() == 1)
+	if ((*it)->getDuration() == 1)
 	  {
-	    int slot =(*it).getActiveProductionSlot();
+	    int slot =(*it)->getActiveProductionSlot();
 	    if (slot == -1)
 	      continue;
-	    const ArmyProdBase *a = (*it).getProductionBase(slot);
+	    const ArmyProdBase *a = (*it)->getProductionBase(slot);
 	    total += a->getUpkeep();
 	  }
       }
@@ -133,24 +132,24 @@ void Citylist::nextTurn(Player* p)
     //fixme: here we want the upkeep that we would pay out to all cities.
     //and not the total upkeep.
     Uint32 upkeep_for_new_armies = calculateUpcomingUpkeep(p);
-    if (p->getGold() < upkeep_for_new_armies)
+    if (p->getGold() < (int)upkeep_for_new_armies)
       {
 	int diff = upkeep_for_new_armies - p->getGold();
 	//then we have to turn off enough production to make up for diff
 	//gold pieces.
 	for (iterator it = begin(); it != end(); it++)
 	  {
-	    if ((*it).isBurnt() == true)
+	    if ((*it)->isBurnt() == true)
 	      continue;
-	    if ((*it).getOwner() != p)
+	    if ((*it)->getOwner() != p)
 	      continue;
-	    int slot =(*it).getActiveProductionSlot();
+	    int slot =(*it)->getActiveProductionSlot();
 	    if (slot == -1)
 	      continue;
-	    const ArmyProdBase *a = (*it).getProductionBase(slot);
+	    const ArmyProdBase *a = (*it)->getProductionBase(slot);
 	    diff -= a->getUpkeep();
     
-	    p->cityTooPoorToProduce(&(*it), slot);
+	    p->cityTooPoorToProduce((*it), slot);
 	    if (diff < 0)
 	      break;
 	  }
@@ -159,8 +158,8 @@ void Citylist::nextTurn(Player* p)
     // This iteration adds the city production to the player    
     for (iterator it = begin(); it != end(); it++)
       {
-        if ((*it).getOwner() == p)
-            (*it).nextTurn();
+        if ((*it)->getOwner() == p)
+            (*it)->nextTurn();
       }
 
 }
@@ -205,7 +204,7 @@ static bool isNotOwnedByEnemy(void *object)
 static bool canNotAcceptVectoring(void *object)
 {
   City *c = ((City*)object);
-  Uint32 num = c->countCitiesVectoringToHere();
+  Uint32 num = Citylist::getInstance()->countCitiesVectoringTo(c);
   if (num < MAX_ARMIES_VECTORED_TO_ONE_CITY)
     return false;
   return true;
@@ -263,12 +262,12 @@ City* Citylist::getNearestCity(const Vector<int>& pos, Player *p)
     
     for (iterator it = begin(); it != end(); ++it)
     {
-        if ((*it).isBurnt())
+        if ((*it)->isBurnt())
             continue;
 
-        if ((*it).getOwner() == p)
+        if ((*it)->getOwner() == p)
         {
-            Vector<int> p = (*it).getPos();
+            Vector<int> p = (*it)->getPos();
             int delta = abs(p.x - pos.x);
             if (delta < abs(p.y - pos.y))
                 delta = abs(p.y - pos.y);
@@ -282,7 +281,7 @@ City* Citylist::getNearestCity(const Vector<int>& pos, Player *p)
     }
     
     if (diff == -1) return 0;
-    return &(*diffit);
+    return (*diffit);
 }
 
 City* Citylist::getNearestCity(const Vector<int>& pos)
@@ -352,8 +351,8 @@ City* Citylist::getNearestFriendlyVectorableCity(const Vector<int>& pos)
 City* Citylist::getFirstCity(Player* p)
 {
     for (iterator it = begin(); it != end(); it++)
-        if ((*it).getOwner() == p)
-            return &(*it);
+        if ((*it)->getOwner() == p)
+            return (*it);
 
     return 0;
 }
@@ -362,10 +361,10 @@ bool Citylist::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("citylist");
+    retval &= helper->openTag(Citylist::d_tag);
 
     for (const_iterator it = begin(); it != end(); it++)
-        (*it).save(helper);
+        (*it)->save(helper);
     
     retval &= helper->closeTag();
 
@@ -374,30 +373,9 @@ bool Citylist::save(XML_Helper* helper) const
 
 bool Citylist::load(std::string tag, XML_Helper* helper)
 {
-    if (tag == "armyprodbase")
+    if (tag == City::d_tag)
       {
-	//add it to the right city
-	//how do i add it to the right slot?
-	Citylist::iterator it = end();
-	it--;
-	City *city = &*it;
-	ArmyProdBase *a = new ArmyProdBase (helper);
-	int slot = city->getMaxNoOfProductionBases() - 1;
-	city->addProductionBase(slot, a);
-	return true;
-      }
-    if (tag == "slot")
-      {
-	Citylist::iterator it = end();
-	it--;
-	City *city = &*it;
-	city->setMaxNoOfProductionBases(city->getMaxNoOfProductionBases() + 1);
-	return true;
-      }
-    if (tag == "city")
-      {
-	City c(helper);
-	push_back(c);
+	push_back(new City(helper));
 	return true;
       }
     return false;
@@ -406,12 +384,12 @@ bool Citylist::load(std::string tag, XML_Helper* helper)
 void Citylist::changeOwnership(Player *old_owner, Player *new_owner)
 {
   for (iterator it = begin(); it != end(); it++)
-    if ((*it).getOwner() == old_owner)
+    if ((*it)->getOwner() == old_owner)
       {
-	(*it).setOwner(new_owner);
-	if ((*it).isCapital())
-	  if ((*it).getCapitalOwner() == old_owner)
-	    (*it).setCapitalOwner(new_owner);
+	(*it)->setOwner(new_owner);
+	if ((*it)->isCapital())
+	  if ((*it)->getCapitalOwner() == old_owner)
+	    (*it)->setCapitalOwner(new_owner);
       }
 }
 
@@ -419,12 +397,12 @@ void Citylist::stopVectoringTo(City *c)
 {
   for (iterator it = begin(); it != end(); it++)
     {
-      if ((*it).isBurnt() == true)
+      if ((*it)->isBurnt() == true)
 	continue;
-      if ((*it).getVectoring() == Vector<int>(-1,-1))
+      if ((*it)->getVectoring() == Vector<int>(-1,-1))
 	continue;
-      if (c->contains((*it).getVectoring()))
-	(*it).setVectoring(Vector<int>(-1,-1));
+      if (c->contains((*it)->getVectoring()))
+	(*it)->setVectoring(Vector<int>(-1,-1));
     }
   return;
 }
@@ -438,9 +416,9 @@ Vector<int> Citylist::calculateCenterOfTerritory (Player *p)
   int count = 0;
   for (iterator it = begin(); it != end(); it++)
     {
-      if (p && (*it).getOwner() == p)
+      if (p && (*it)->getOwner() == p)
 	continue;
-      Vector<int> pos = (*it).getPos();
+      Vector<int> pos = (*it)->getPos();
       count++;
       if (pos.x > e)
 	e = pos.x;
@@ -460,9 +438,9 @@ bool Citylist::isVectoringTarget(City *target)
 {
   for (iterator it = begin(); it != end(); it++)
     {
-      if ((*it).getOwner() != target->getOwner())
+      if ((*it)->getOwner() != target->getOwner())
 	continue;
-      if (target->contains((*it).getVectoring()))
+      if (target->contains((*it)->getVectoring()))
 	return true;
     }
   return false;
@@ -473,10 +451,10 @@ std::list<City*> Citylist::getCitiesVectoringTo(City *target)
   std::list<City*> cities;
   for (iterator it = begin(); it != end(); it++)
     {
-      if ((*it).getOwner() != target->getOwner())
+      if ((*it)->getOwner() != target->getOwner())
 	continue;
-      if (target->contains((*it).getVectoring()))
-	cities.push_back(&(*it));
+      if (target->contains((*it)->getVectoring()))
+	cities.push_back((*it));
     }
   return cities;
 }
@@ -488,4 +466,18 @@ City* Citylist::getNearestCityPast(const Vector<int>& pos, int dist)
   return getNearestObjectAfter(pos, dist, &filters);
 }
 
+Uint32 Citylist::countCitiesVectoringTo(City *dest)
+{
+  Uint32 count = 0;
+  for (iterator it = begin(); it != end(); it++)
+    {
+      City *c = *it;
+      if (c->getOwner() != dest->getOwner())
+	continue;
+      if (c->getVectoring() == dest->getPos())
+	count++;
+    }
+
+  return count;
+}
 // End of file
