@@ -34,9 +34,12 @@ class Player;
  * is implemented as a singleton because many classes use it for looking 
  * up cities.
  */
-class Citylist : public LocationList<City>, public sigc::trackable
+class Citylist : public LocationList<City*>, public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         //! Returns the singleton instance.  Creates a new one if neccessary.
         static Citylist* getInstance();
 
@@ -345,6 +348,8 @@ class Citylist : public LocationList<City>, public sigc::trackable
 
 	Uint32 calculateUpcomingUpkeep(Player *p);
 
+	Uint32 countCitiesVectoringTo(City *dest);
+
     protected:
         // CREATORS
 	//! Default constructor.
