@@ -25,12 +25,12 @@
 #ifndef DEFINITIONS_H
 #define DEFINITIONS_H
 
+#include <string>
 #include <libintl.h>
 
-#define LORDSAWAR_SAVEGAME_VERSION "0.1.1"
-#define LORDSAWAR_CONFIG_VERSION "0.1.1"
-#define LORDSAWAR_RECENTLY_PLAYED_VERSION "0.1.1"
-#define ENABLE_NLS 1 // Very important toactivate localization
+#define LORDSAWAR_SAVEGAME_VERSION "0.1.2"
+#define LORDSAWAR_CONFIG_VERSION "0.1.2"
+#define LORDSAWAR_RECENTLY_PLAYED_VERSION "0.1.2"
 #define _(string) gettext(string) // Macro for the gettext
 #define __(astring) std::string(gettext(astring.c_str()))
 
@@ -59,6 +59,7 @@ const unsigned int DIPLOMACY_MAX_SCORE = 15;
 const unsigned int DIPLOMACY_MIN_SCORE = 0;
 const unsigned int MAX_STACK_SIZE = 8;
 const unsigned int MAX_PRODUCTION_SLOTS_IN_A_CITY = 4;
+const unsigned int MAX_ARMIES_PRODUCED_IN_ACTIVE_NEUTRAL_CITY = 5;
 
 const unsigned int MAP_SIZE_TINY_WIDTH = 50;
 const unsigned int MAP_SIZE_TINY_HEIGHT = 75;
@@ -74,18 +75,9 @@ const unsigned int MOVE_BONUS_WIDTH = 32;
 const unsigned int MOVE_BONUS_HEIGHT = 20;
 const unsigned int MOVE_BONUS_TYPES = 6;
 
-// from www.boost.org - derivation from this class makes the derived class
-// noncopyable
-class noncopyable
-{
-protected:
-  noncopyable() {}
-  ~noncopyable() {}
-private:
-  noncopyable(const noncopyable&);
-  const noncopyable& operator=(const noncopyable&);
-};
-
+const unsigned int CITY_TILE_WIDTH = 2;
+const unsigned int RUIN_TILE_WIDTH = 1;
+const unsigned int TEMPLE_TILE_WIDTH = 1;
 
 const unsigned short LORDSAWAR_PORT = 14998;
 #define HUMAN_PLAYER_TYPE _("Human")
@@ -94,4 +86,10 @@ const unsigned short LORDSAWAR_PORT = 14998;
 #define NO_PLAYER_TYPE _("Off")
 #define NETWORKED_PLAYER_TYPE _("Network")
 
+const std::string ARMYSETDIR = "army";
+const std::string TILESETDIR = "tilesets";
+const std::string CITYSETDIR = "citysets";
+const std::string SHIELDSETDIR = "shield";
+const std::string CAMPAIGNDIR = "campaign";
+const std::string MAPDIR = "map";
 #endif // DEFINITIONS_H
