@@ -60,6 +60,7 @@ EditorBigMap::EditorBigMap()
     pointer_size = 1;
     pointer_terrain = Tile::GRASS;
     pointer_tile_style_id = -1;
+    show_tile_types_instead_of_tile_styles = false;
 }
 
 EditorBigMap::~EditorBigMap()
@@ -231,9 +232,6 @@ std::vector<Vector<int> > EditorBigMap::get_cursor_tiles()
 
 void EditorBigMap::after_draw()
 {
-    if (pointer == POINTER)
-	return;
-    
     int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
     std::vector<Vector<int> > tiles;
 
@@ -383,11 +381,11 @@ namespace
     void remove_from_map(T *l, Vector<int> tile)
     {
 	for (typename T::iterator i = l->begin(), end = l->end(); i != end; ++i)
-	    if (i->contains(tile))
+	    if ((*i)->contains(tile))
 	    {
 		// erase from map
 		GameMap *gamemap = GameMap::getInstance();
-		Rectangle r = i->get_area();
+		Rectangle r = (*i)->get_area();
 		for (int x = r.x; x < r.x + r.w; ++x)
 		    for (int y = r.y; y < r.y + r.h; ++y)
 			gamemap->getTile(Vector<int>(x, y))->setBuilding(Maptile::NONE);
@@ -440,9 +438,19 @@ void EditorBigMap::change_map_under_cursor()
 	    maptile->setType(ts->getIndex(pointer_terrain));
 	    if (pointer_tile_style_id == -1)
 	      {
-		GameMap::getInstance()->applyTileStyles(tile.y-1, tile.x-1, 
-							tile.y+2, tile.x+2,
-							false);
+		if (pointer_terrain == Tile::MOUNTAIN)
+		  {
+		    GameMap *gm = GameMap::getInstance();
+		    gm->surroundMountains (tile.y-1, tile.x-1, 
+					   tile.y+2, tile.x+2);
+		    gm->applyTileStyles(tile.y-2, tile.x-2, 
+					tile.y+3, tile.x+3,
+					false);
+		  }
+		else
+		  GameMap::getInstance()->applyTileStyles(tile.y-1, tile.x-1, 
+							  tile.y+2, tile.x+2,
+							  false);
 	      }
 	    else
 	      {
@@ -558,13 +566,13 @@ void EditorBigMap::change_map_under_cursor()
 		break;
 	    
 	    // create the city
-	    City c(tile);
-	    c.setOwner(Playerlist::getInstance()->getNeutral());
+	    City *c = new City(tile);
+	    c->setOwner(Playerlist::getInstance()->getNeutral());
 	    Citylist::getInstance()->push_back(c);
 
 	    bool replaced_grass = false;
 	    // notify the maptiles that a city has been placed here
-	    Rectangle r = c.get_area();
+	    Rectangle r = c->get_area();
 	    for (int x = r.x; x < r.x + r.w; ++x)
 		for (int y = r.y; y < r.y + r.h; ++y)
 		{
@@ -576,26 +584,26 @@ void EditorBigMap::change_map_under_cursor()
 		}
 
 	    //change allegiance of stacks under this city
-	    for (unsigned int x = 0; x < c.getSize(); x++)
+	    for (unsigned int x = 0; x < c->getSize(); x++)
 	      {
-		for (unsigned int y = 0; y < c.getSize(); y++)
+		for (unsigned int y = 0; y < c->getSize(); y++)
 		  {
-		    Stack *s = Stacklist::getObjectAt(c.getPos().x + x, 
-						      c.getPos().y + y);
+		    Stack *s = Stacklist::getObjectAt(c->getPos().x + x, 
+						      c->getPos().y + y);
 		    if (s)
 		      {
-			if (s->getOwner() != c.getOwner())
+			if (s->getOwner() != c->getOwner())
 			  {
 			    //remove it from the old player's list of stacks
 			    s->getOwner()->getStacklist()->remove(s);
 			    //and give it to the new player list of stacks
-			    c.getOwner()->getStacklist()->push_back(s);
+			    c->getOwner()->getStacklist()->push_back(s);
 			    //change the ownership of the stack
-			    s->setOwner(c.getOwner());
+			    s->setOwner(c->getOwner());
 			    //and all of it's armies
 			    for (Stack::iterator it = s->begin(); 
 				 it != s->end(); it++)
-			      (*it)->setOwner(c.getOwner());
+			      (*it)->setOwner(c->getOwner());
 			  }
 		      }
 		  }
@@ -619,7 +627,7 @@ void EditorBigMap::change_map_under_cursor()
 		  replaced_grass = true;
 		maptile->setType(grass_index);
 		Ruin *ruin = new Ruin(tile);
-		Ruinlist::getInstance()->push_back(*ruin);
+		Ruinlist::getInstance()->push_back(ruin);
 		if (replaced_grass)
 		  GameMap::getInstance()->applyTileStyles
 		    (0, 0, GameMap::getHeight(), GameMap::getWidth(), true);
@@ -635,7 +643,7 @@ void EditorBigMap::change_map_under_cursor()
 		if (maptile->getMaptileType() != Tile::GRASS)
 		  replaced_grass = true;
 		maptile->setType(grass_index);
-		Templelist::getInstance()->push_back(Temple(tile));
+		Templelist::getInstance()->push_back(new Temple(tile));
 		if (replaced_grass)
 		  GameMap::getInstance()->applyTileStyles
 		    (0, 0, GameMap::getHeight(), GameMap::getWidth(), true);
@@ -647,7 +655,7 @@ void EditorBigMap::change_map_under_cursor()
 		&& maptile->getMaptileType() == Tile::GRASS)
 	    {
 		maptile->setBuilding(Maptile::SIGNPOST);
-		Signpostlist::getInstance()->push_back(Signpost(tile));
+		Signpostlist::getInstance()->push_back(new Signpost(tile));
 	    }
 	    break;
 	    
@@ -657,7 +665,7 @@ void EditorBigMap::change_map_under_cursor()
 		maptile->getTileStyle()->getType() != TileStyle::INNERMIDDLECENTER)
 	    {
 		maptile->setBuilding(Maptile::PORT);
-		Portlist::getInstance()->push_back(Port(tile));
+		Portlist::getInstance()->push_back(new Port(tile));
 	    }
 	    break;
 	    
@@ -672,7 +680,7 @@ void EditorBigMap::change_map_under_cursor()
 		else
 		{
 		    maptile->setBuilding(Maptile::BRIDGE);
-		    Bridgelist::getInstance()->push_back(Bridge(tile, type));
+		    Bridgelist::getInstance()->push_back(new Bridge(tile, type));
 		}
 	        changed_tiles.dim = Vector<int>(1, 1);
 	    }
@@ -687,15 +695,15 @@ void EditorBigMap::change_map_under_cursor()
 		if (maptile->getBuilding() == Maptile::NONE)
 		{
 		    maptile->setBuilding(Maptile::ROAD);
-		    Roadlist::getInstance()->push_back(Road(tile, type));
+		    Roadlist::getInstance()->push_back(new Road(tile, type));
 		}
 
 		// now reconfigure all roads in the surroundings
 		for (int x = tile.x - 1; x <= tile.x + 1; ++x)
 		    for (int y = tile.y - 1; y <= tile.y + 1; ++y)
 		    {
-			if (x < 0 || x >= GameMap::getWidth() &&
-			    y < 0 || y >= GameMap::getHeight())
+			if ((x < 0 || x >= GameMap::getWidth()) &&
+			    (y < 0 || y >= GameMap::getHeight()))
 			    continue;
 
 			Vector<int> pos(x, y);
@@ -793,4 +801,3 @@ int EditorBigMap::calculateRoadType (Vector<int> t)
 	type = 0;
     return type;
 }
-
