@@ -26,7 +26,6 @@
 #include <sigc++/functors/ptr_fun.h>
 
 #include <gtkmm/widget.h>
-#include <gtkmm/menuitem.h>
 #include <gtkmm/eventbox.h>
 #include <gtkmm/image.h>
 #include <gtkmm/dialog.h>
@@ -168,6 +167,10 @@ MainWindow::MainWindow()
 			 sigc::mem_fun(this, &MainWindow::on_save_map_activated));
     xml->connect_clicked("save_map_as_menuitem", 
 			 sigc::mem_fun(this, &MainWindow::on_save_map_as_activated));
+    xml->connect_clicked("export_as_bitmap_menuitem",
+			 sigc::mem_fun(this, &MainWindow::on_export_as_bitmap_activated));
+    xml->connect_clicked("export_as_bitmap_no_game_objects_menuitem",
+			 sigc::mem_fun(this, &MainWindow::on_export_as_bitmap_no_game_objects_activated));
     xml->connect_clicked("quit_menuitem", 
 			 sigc::mem_fun(this, &MainWindow::on_quit_activated));
 
@@ -351,7 +354,7 @@ bool MainWindow::on_delete_event(GdkEventAny *e)
 void MainWindow::show_initial_map()
 {
     set_filled_map(112, 156, Tile::WATER, "default", "default", "default",
-		   "Default");
+		   "default");
     setup_terrain_radiobuttons();
     remove_tile_style_buttons();
     setup_tile_style_buttons(Tile::GRASS);
@@ -379,7 +382,8 @@ void MainWindow::set_filled_map(int width, int height, int fill_style, std::stri
 
     // ...however we need to do some of the setup by hand. We need to create a
     // neutral player to give cities a player upon creation...
-    Uint32 armyset_id = Armysetlist::getInstance()->getArmysetId(armyset);
+    Uint32 armyset_id = 
+      Armysetlist::getInstance()->getArmyset(armyset)->getId();
     Shieldsetlist *ssl = Shieldsetlist::getInstance();
     Player* neutral = new AI_Dummy(_("Neutral"), armyset_id, 
 				   ssl->getColor(shieldset, MAX_PLAYERS), 
@@ -425,7 +429,8 @@ void MainWindow::set_random_map(int width, int height,
     
     // We need to create a neutral player to give cities a player upon
     // creation...
-    Uint32 armyset_id = Armysetlist::getInstance()->getArmysetId(armyset);
+    Uint32 armyset_id = 
+      Armysetlist::getInstance()->getArmyset(armyset)->getId();
     Shieldsetlist *ssl = Shieldsetlist::getInstance();
     Player* neutral = new AI_Dummy(_("Neutral"), armyset_id, 
 				   ssl->getColor(shieldset, MAX_PLAYERS), 
@@ -475,27 +480,27 @@ void MainWindow::set_random_map(int width, int height,
 	    switch(build[j * width + i])
 	    {
 	    case Maptile::CITY:
-		Citylist::getInstance()->push_back(City(Vector<int>(i,j)));
-		(*Citylist::getInstance()->rbegin()).setOwner(
+		Citylist::getInstance()->push_back(new City(Vector<int>(i,j)));
+		(*Citylist::getInstance()->rbegin())->setOwner(
 		    Playerlist::getInstance()->getNeutral());
 		break;
 	    case Maptile::TEMPLE:
-		Templelist::getInstance()->push_back(Temple(Vector<int>(i,j)));
+		Templelist::getInstance()->push_back(new Temple(Vector<int>(i,j)));
 		break;
 	    case Maptile::RUIN:
-		Ruinlist::getInstance()->push_back(Ruin(Vector<int>(i,j)));
+		Ruinlist::getInstance()->push_back(new Ruin(Vector<int>(i,j)));
 		break;
 	    case Maptile::SIGNPOST:
-		Signpostlist::getInstance()->push_back(Signpost(Vector<int>(i,j)));
+		Signpostlist::getInstance()->push_back(new Signpost(Vector<int>(i,j)));
 		break;
 	    case Maptile::ROAD:
-		Roadlist::getInstance()->push_back(Road(Vector<int>(i,j)));
+		Roadlist::getInstance()->push_back(new Road(Vector<int>(i,j)));
 		break;
 	    case Maptile::BRIDGE:
-		Bridgelist::getInstance()->push_back(Bridge(Vector<int>(i,j)));
+		Bridgelist::getInstance()->push_back(new Bridge(Vector<int>(i,j)));
 		break;
 	    case Maptile::PORT:
-		Portlist::getInstance()->push_back(Port(Vector<int>(i,j)));
+		Portlist::getInstance()->push_back(new Port(Vector<int>(i,j)));
 		break;
 	    case Maptile::NONE:
 		break;
@@ -539,8 +544,17 @@ bool MainWindow::on_sdl_mouse_button_event(GdkEventButton *e)
 
 bool MainWindow::on_sdl_mouse_motion_event(GdkEventMotion *e)
 {
-    if (bigmap.get())
-	bigmap->mouse_motion_event(to_input_event(e));
+  static guint prev = 0;
+  if (bigmap.get())
+    {
+      guint delta = e->time - prev;
+      if (delta > 40 || delta < 0)
+	{
+	  bigmap->mouse_motion_event(to_input_event(e));
+	  sdl_widget->grab_focus();
+	  prev = e->time;
+	}
+    }
     
     return true;
 }
@@ -679,6 +693,60 @@ void MainWindow::on_save_map_activated()
     }
 }
 
+void MainWindow::on_export_as_bitmap_activated()
+{
+    Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
+				   Gtk::FILE_CHOOSER_ACTION_SAVE);
+    Gtk::FileFilter sav_filter;
+    sav_filter.add_pattern("*.bmp");
+    chooser.set_filter(sav_filter);
+    chooser.set_current_folder(Configuration::s_savePath);
+
+    chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+    chooser.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
+    chooser.set_default_response(Gtk::RESPONSE_ACCEPT);
+    
+    chooser.show_all();
+    int res = chooser.run();
+    
+    if (res == Gtk::RESPONSE_ACCEPT)
+    {
+	current_save_filename = chooser.get_filename();
+	chooser.hide();
+
+	bool success = bigmap->saveAsBitmap(current_save_filename);
+	if (!success)
+	    show_error(_("Map was not exported!"));
+    }
+}
+
+void MainWindow::on_export_as_bitmap_no_game_objects_activated()
+{
+    Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
+				   Gtk::FILE_CHOOSER_ACTION_SAVE);
+    Gtk::FileFilter sav_filter;
+    sav_filter.add_pattern("*.bmp");
+    chooser.set_filter(sav_filter);
+    chooser.set_current_folder(Configuration::s_savePath);
+
+    chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+    chooser.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
+    chooser.set_default_response(Gtk::RESPONSE_ACCEPT);
+    
+    chooser.show_all();
+    int res = chooser.run();
+    
+    if (res == Gtk::RESPONSE_ACCEPT)
+    {
+	current_save_filename = chooser.get_filename();
+	chooser.hide();
+
+	bool success = bigmap->saveUnderlyingMapAsBitmap(current_save_filename);
+	if (!success)
+	    show_error(_("Map was not exported!"));
+    }
+}
+
 void MainWindow::on_save_map_as_activated()
 {
     Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
@@ -814,9 +882,45 @@ void MainWindow::setup_tile_style_buttons(Tile::Type terrain)
   terrain_tile_style_hbox->show_all();
 }
 
+    
+void MainWindow::auto_select_appropriate_pointer()
+{
+  switch (get_terrain())
+    {
+    case Tile::GRASS:
+      //do 1x1
+      pointer_items[1].button->set_active();
+      break;
+    case Tile::WATER:
+    case Tile::FOREST:
+    case Tile::SWAMP:
+    case Tile::HILLS:
+    case Tile::VOID:
+	{
+	  Tileset *tileset = GameMap::getInstance()->getTileset();
+	  Tile *tile = (*tileset)[tileset->getIndex(get_terrain())];
+	  if (tile->consistsOnlyOfLoneAndOtherStyles())
+	    pointer_items[1].button->set_active();
+	  else
+	    pointer_items[2].button->set_active();
+	  break;
+	}
+    case Tile::MOUNTAIN:
+	//do 6x6
+      pointer_items[4].button->set_active();
+      break;
+    }
+}
+
 void MainWindow::on_tile_style_radiobutton_toggled()
 {
   on_pointer_radiobutton_toggled();
+      
+  //was the first one (auto) clicked?  if so, we want 1x1
+  if (get_tile_style_id() != -1)
+    pointer_items[1].button->set_active();
+  else
+    auto_select_appropriate_pointer();
 }
 
 void MainWindow::on_terrain_radiobutton_toggled()
@@ -824,6 +928,7 @@ void MainWindow::on_terrain_radiobutton_toggled()
   remove_tile_style_buttons();
   setup_tile_style_buttons(get_terrain());
   on_pointer_radiobutton_toggled();
+  auto_select_appropriate_pointer();
 }
 
 void MainWindow::on_pointer_radiobutton_toggled()
@@ -1041,7 +1146,7 @@ void MainWindow::on_random_all_cities_activated()
 {
   Citylist *cl = Citylist::getInstance();
   for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
-    randomize_city(&*it);
+    randomize_city(*it);
 }
 
 void MainWindow::on_random_unnamed_cities_activated()
@@ -1049,8 +1154,8 @@ void MainWindow::on_random_unnamed_cities_activated()
   Citylist *cl = Citylist::getInstance();
   for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
     {
-      if ((*it).getName() == DEFAULT_CITY_NAME)
-	randomize_city(&*it);
+      if ((*it)->getName() == DEFAULT_CITY_NAME)
+	randomize_city(*it);
     }
 }
 
@@ -1069,7 +1174,7 @@ void MainWindow::on_random_all_ruins_activated()
 {
   Ruinlist *rl = Ruinlist::getInstance();
   for (Ruinlist::iterator it = rl->begin(); it != rl->end(); it++)
-    randomize_ruin(&*it);
+    randomize_ruin(*it);
 }
 
 void MainWindow::on_random_unnamed_ruins_activated()
@@ -1077,8 +1182,8 @@ void MainWindow::on_random_unnamed_ruins_activated()
   Ruinlist *rl = Ruinlist::getInstance();
   for (Ruinlist::iterator it = rl->begin(); it != rl->end(); it++)
     {
-      if ((*it).getName() == DEFAULT_RUIN_NAME)
-	randomize_ruin(&*it);
+      if ((*it)->getName() == DEFAULT_RUIN_NAME)
+	randomize_ruin(*it);
     }
 }
 
@@ -1090,7 +1195,7 @@ void MainWindow::on_random_all_temples_activated()
       std::string name = d_create_scenario_names->popRandomTempleName();
       if (name != "")
 	{
-	  Location *l = &*it;
+	  Location *l = *it;
 	  RenamableLocation *renamable_temple = 
 	    static_cast<RenamableLocation*>(l);
 	  renamable_temple->setName(name);
@@ -1103,12 +1208,12 @@ void MainWindow::on_random_unnamed_temples_activated()
   Templelist *tl = Templelist::getInstance();
   for (Templelist::iterator it = tl->begin(); it != tl->end(); it++)
     {
-      if ((*it).getName() == DEFAULT_TEMPLE_NAME)
+      if ((*it)->getName() == DEFAULT_TEMPLE_NAME)
 	{
 	  std::string name = d_create_scenario_names->popRandomTempleName();
 	  if (name != "")
 	    {
-	      Location *l = &*it;
+	      Location *l = *it;
 	      RenamableLocation *renamable_temple = 
 		static_cast<RenamableLocation*>(l);
 	      renamable_temple->setName(name);
@@ -1133,7 +1238,7 @@ void MainWindow::on_random_all_signs_activated()
 {
   Signpostlist *sl = Signpostlist::getInstance();
   for (Signpostlist::iterator it = sl->begin(); it != sl->end(); it++)
-    randomize_signpost(&*it);
+    randomize_signpost(*it);
 }
 
 void MainWindow::on_random_unnamed_signs_activated()
@@ -1141,8 +1246,8 @@ void MainWindow::on_random_unnamed_signs_activated()
   Signpostlist *sl = Signpostlist::getInstance();
   for (Signpostlist::iterator it = sl->begin(); it != sl->end(); it++)
     {
-      if ((*it).getName() == DEFAULT_SIGNPOST)
-	randomize_signpost(&*it);
+      if ((*it)->getName() == DEFAULT_SIGNPOST)
+	randomize_signpost(*it);
     }
 }
 
