@@ -33,6 +33,7 @@
 #include "select-item-dialog.h"
 #include "select-army-dialog.h"
 #include "select-hidden-ruin-dialog.h"
+#include "armyproto.h"
 
 RewardDialog::RewardDialog(Player *player, bool hidden_ruins, Reward *r)
 {
@@ -173,8 +174,8 @@ void RewardDialog::fill_in_reward_info()
   else if (reward->getType() == Reward::MAP)
     {
       Reward_Map *r = static_cast<Reward_Map*>(reward);
-      map_x_spinbutton->set_value(r->getLocation()->getPos().x);
-      map_y_spinbutton->set_value(r->getLocation()->getPos().y);
+      map_x_spinbutton->set_value(r->getLocation().x);
+      map_y_spinbutton->set_value(r->getLocation().y);
       map_width_spinbutton->set_value(r->getWidth());
       map_height_spinbutton->set_value(r->getHeight());
 	  map_radiobutton->set_active(true);
