@@ -16,7 +16,7 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
 //  02110-1301, USA.
 
-#include <config.h>
+#include "config.h"
 
 #include <algorithm>
 #include <vector>
@@ -66,6 +66,9 @@
 #include "history.h"
 #include "pbm-game-server.h"
 #include "LocationBox.h"
+#include "Campaign.h"
+#include "Backpack.h"
+#include "MapBackpack.h"
 
 #include "herotemplates.h"
 
@@ -106,7 +109,11 @@ void Game::addPlayer(Player *p)
 	(p->advice_asked.connect
 	 (sigc::mem_fun(advice_asked, &sigc::signal<void, float>::emit)));
     }
-    
+      
+  connections[p->getId()].push_back
+    (p->aborted_turn.connect (sigc::mem_fun
+	   (game_stopped, &sigc::signal<void>::emit)));
+
   connections[p->getId()].push_back
     (p->schangingStatus.connect 
      (sigc::mem_fun(this, &Game::update_sidebar_stats)));
@@ -761,6 +768,7 @@ void Game::invading_city(City* city, int gold)
 void Game::lock_inputs()
 {
   // don't accept modifying user input from now on
+  bigmap->reset_zoom();
   bigmap->set_input_locked(true);
   smallmap->set_input_locked(true);
   input_locked = true;
@@ -834,7 +842,7 @@ void Game::update_control_panel()
   if (stack)
     {
       can_move_selected_stack_along_path.emit
-	(!stack->getPath()->empty() && stack->enoughMoves() ||
+	((!stack->getPath()->empty() && stack->enoughMoves()) ||
 	 (!stack->getPath()->empty() && stack->getPath()->getMovesExhaustedAtPoint() > 0));
 
       /*
@@ -865,13 +873,8 @@ void Game::update_control_panel()
 	      if ((*it)->isHero())
 		{
 		  Hero *hero = dynamic_cast<Hero*>((*it));
-		  std::list<Item*> backpack = hero->getBackpack();
-		  for (std::list<Item*>::iterator i = backpack.begin(), 
-		       end = backpack.end(); i != end; ++i)
+		  if (hero->getBackpack()->getPlantableItem(player))
 		    {
-		      if ((*i)->isPlantable() && 
-			  (*i)->getPlantableOwner() == player)
-			{
 			  //can't plant on city/ruin/temple/signpost
 			  Citylist *cl = Citylist::getInstance();
 			  City *city = cl->getObjectAt(stack->getPos());
@@ -884,22 +887,15 @@ void Game::update_control_panel()
 			  if (!city && !temple && !ruin && !sign)
 			    {
 			      GameMap *gm = GameMap::getInstance();
-			      std::list<Item*> items;
+			      MapBackpack *backpack;
 			      Vector<int> pos = stack->getPos();
-			      items = gm->getTile(pos)->getItems();
-			      std::list<Item*>::iterator iit;
-			      bool standard_already_planted = false;
-			      for (iit = items.begin(); iit != items.end();
-				   iit++)
-				{
-				  if ((*iit)->getPlanted())
-				    standard_already_planted = true;
-				}
+			      backpack = gm->getTile(pos)->getBackpack();
+			      bool standard_already_planted = 
+				backpack->getFirstPlantedItem() != NULL;
 			      //are there any other standards here?
 			      if (standard_already_planted == false)
 				can_plant_standard_selected_stack.emit(true);
 			    }
-			}
 		    }
 		}
 	    }
@@ -1088,7 +1084,15 @@ void Game::on_player_died(Player *player)
 {
   const Playerlist* pl = Playerlist::getInstance();
   if (pl->getNoOfPlayers() <= 1)
-    game_over.emit(pl->getFirstLiving());
+    {
+      Campaign *campaign = Campaign::getInstance();
+      if (campaign->getNextScenario() != "" &&
+	  pl->getFirstLiving()->getType() == Player::HUMAN)
+	next_scenario.emit(File::getCampaignFile(campaign->getNextScenario()),
+			   campaign->getNumberOfHeroesToCarryOver());
+      else
+	game_over.emit(pl->getFirstLiving());
+    }
   else
     player_died.emit(player);
 }
@@ -1135,10 +1139,11 @@ void Game::center_view_on_city()
   for (Citylist::iterator i = Citylist::getInstance()->begin();
        i != Citylist::getInstance()->end(); i++)
     {
-      if (i->getOwner() == p && i->isCapital() &&
-	  i->getCapitalOwner() == p)
+      City *c = *i;
+      if (c->getOwner() == p && c->isCapital() &&
+	  c->getCapitalOwner() == p)
 	{
-	  smallmap->center_view_on_tile(i->getPos(), 
+	  smallmap->center_view_on_tile(c->getPos(), 
 					!GameScenario::s_hidden_map);
 	  return;
 	}
@@ -1148,11 +1153,12 @@ void Game::center_view_on_city()
   for (Citylist::iterator i = Citylist::getInstance()->begin();
        i != Citylist::getInstance()->end(); i++)
     {
-      if (i->getOwner() == p)
+      City *c = *i;
+      if (c->getOwner() == p)
 	{
 	  if (Playerlist::isFinished())
 	    return;
-	  smallmap->center_view_on_tile(i->getPos(), 
+	  smallmap->center_view_on_tile(c->getPos(), 
 					!GameScenario::s_hidden_map);
 	  break;
 	}
@@ -1243,7 +1249,7 @@ void Game::on_city_fight_finished(City *city, Fight::Result result)
 	  if (o)
 	    {
 	      int army_type = o->getStrongestArmy()->getTypeId();
-	      for (int i = 0; i < city->getMaxNoOfProductionBases(); i++)
+	      for (Uint32 i = 0; i < city->getMaxNoOfProductionBases(); i++)
 		{
 		  if (city->getArmytype(i) == army_type)
 		    {
