@@ -24,6 +24,7 @@
 #include <sigc++/connection.h>
 #include <memory>
 #include <list>
+#include <string>
 
 #include "rectangle.h"
 #include "sidebar-stats.h"
@@ -33,6 +34,7 @@
 #include "fight.h"
 #include "game-parameters.h"
 #include "player.h"
+#include "defs.h"
 
 class NextTurn;
 class GameBigMap;
@@ -147,7 +149,9 @@ class Game
     sigc::signal<Army::Stat, Army *> army_gains_level;
     sigc::signal<void, Player *> game_loaded;
     sigc::signal<void, Player *> game_over;
+    sigc::signal<void, std::string, int> next_scenario;
     sigc::signal<void, Player *> player_died;
+    sigc::signal<void> game_stopped;
     
     void addPlayer(Player *p);
 
