@@ -39,7 +39,6 @@
 #include "temple.h"
 #include "road.h"
 #include "playerlist.h"
-#include "defs.h"
 #include "File.h"
 #include "GameMap.h"
 #include "GraphicsCache.h"
@@ -125,11 +124,15 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
   if (input_locked)
     return;
 
+  Player *active = Playerlist::getActiveplayer();
   Vector<int> tile = mouse_pos_to_tile(e.pos);
 
   if (e.button == MouseButtonEvent::LEFT_BUTTON
       && e.state == MouseButtonEvent::PRESSED)
     {
+      if (active->getFogMap()->isCompletelyObscuredFogTile(tile) == true)
+	return;
+
       Stack* stack = Playerlist::getActiveplayer()->getActivestack();
 
       if (stack)
@@ -218,13 +221,17 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 		    }
 		  else
 		    {
-		      if (!stack->getPath()->empty() && 
+		      if (stack->getPath()->empty() == false && 
 			  stack->getPath()->getMovesExhaustedAtPoint() == 0)
 			deselect = true;
 		      if ((d_cursor == GraphicsCache::SWORD ||
 			   d_cursor == GraphicsCache::HEART) &&
 			  stack->canMove() == false)
 			deselect = true;
+		      if ((d_cursor == GraphicsCache::FEET ||
+			   d_cursor == GraphicsCache::SHIP) &&
+			  stack->canMove() == false)
+			deselect = true;
 		    }
 
 		  if (deselect)
@@ -251,7 +258,7 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	    }
 	  else
 	    {
-	      if (City* c = Citylist::getInstance()->getObjectAt(tile.x, tile.y))
+	      if (City* c = Citylist::getInstance()->getObjectAt(tile))
 		{
 		  if (!c->isBurnt())
 		    {
@@ -313,12 +320,14 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
     {
       if (e.state == MouseButtonEvent::PRESSED)
 	{
-	  if (City* c = Citylist::getInstance()->getObjectAt(tile.x, tile.y))
+	  if (active->getFogMap()->isCompletelyObscuredFogTile(tile) == true)
+	    return;
+	  if (City* c = Citylist::getInstance()->getObjectAt(tile))
 	    {
 	      city_queried (c, true);
 	      mouse_state = SHOWING_CITY;
 	    }
-	  else if (Ruin* r = Ruinlist::getInstance()->getObjectAt(tile.x, tile.y))
+	  else if (Ruin* r = Ruinlist::getInstance()->getObjectAt(tile))
 	    {
 	      if ((r->isHidden() == true && 
 		   r->getOwner() == Playerlist::getActiveplayer()) ||
@@ -328,17 +337,17 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 		  mouse_state = SHOWING_RUIN;
 		}
 	    }
-	  else if (Signpost* s = Signpostlist::getInstance()->getObjectAt(tile.x, tile.y))
+	  else if (Signpost* s = Signpostlist::getInstance()->getObjectAt(tile))
 	    {
 	      signpost_queried (s);
 	      mouse_state = SHOWING_SIGNPOST;
 	    }
-	  else if (Temple* t = Templelist::getInstance()->getObjectAt(tile.x, tile.y))
+	  else if (Temple* t = Templelist::getInstance()->getObjectAt(tile))
 	    {
 	      temple_queried.emit(t, true);
 	      mouse_state = SHOWING_TEMPLE;
 	    }
-	  else if (Stack *st = Stacklist::getObjectAt(tile.x, tile.y))
+	  else if (Stack *st = Stacklist::getObjectAt(tile))
 	    {
 	      if (d_see_opponents_stacks == true)
 		{
@@ -399,11 +408,62 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	  mouse_state = NONE;
 	}
     }
+  else if (e.button == MouseButtonEvent::WHEEL_UP)
+    {
+      zoom_in();
+    }
+  else if (e.button == MouseButtonEvent::WHEEL_DOWN)
+    {
+      zoom_out();
+    }
+}
+
+void GameBigMap::zoom_in()
+{
+  if (input_locked)
+    return;
+  if ((zoom_step / 100.0) + magnification_factor <= max_magnification_factor / 100.0)
+    {
+      SDL_Surface *v = SDL_GetVideoSurface();
+      int ts = GameMap::getInstance()->getTileset()->getTileSize();
+      Rectangle new_view;
+      double mag = magnification_factor + (zoom_step / 100.0);
+      new_view.w = v->w / (ts * mag) + 1;
+      new_view.h = v->h / (ts * mag) + 1;
+      if (new_view.w <= GameMap::getWidth() && 
+	  new_view.h <= GameMap::getHeight() && 
+	  new_view.w >= 0 && new_view.h >= 0)
+	zoom_view(zoom_step);
+    }
+}
+
+void GameBigMap::zoom_out()
+{
+  if (input_locked)
+    return;
+  if (magnification_factor - (zoom_step / 100.0) >= min_magnification_factor / 100.0)
+    {
+      SDL_Surface *v = SDL_GetVideoSurface();
+      int ts = GameMap::getInstance()->getTileset()->getTileSize();
+      Rectangle new_view;
+      double mag = magnification_factor - (zoom_step / 100.0);
+      new_view.w = v->w / (ts * mag) + 1;
+      new_view.h = v->h / (ts * mag) + 1;
+      if (new_view.w <= GameMap::getWidth() && 
+	  new_view.h <= GameMap::getHeight() && 
+	  new_view.w >= 0 && new_view.h >= 0)
+	zoom_view(-zoom_step);
+    }
 }
 
 void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 {
-  if (stack && mouse_state == DRAGGING_STACK)
+  Player *active = Playerlist::getActiveplayer();
+  if (active->getFogMap()->isCompletelyObscuredFogTile(tile))
+    {
+      d_cursor = GraphicsCache::HAND;
+    }
+  else if (stack && mouse_state == DRAGGING_STACK)
     {
       d_cursor = GraphicsCache::GOTO_ARROW;
     }
@@ -417,7 +477,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	  City *c = Citylist::getInstance()->getObjectAt(tile);
 	  if (c)
 	    {
-	      if (c->getOwner() == Playerlist::getActiveplayer())
+	      if (c->getOwner() == active)
 		d_cursor = GraphicsCache::FEET;
 	      else if (c->isBurnt() == true)
 		d_cursor = GraphicsCache::FEET;
@@ -456,7 +516,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	    {
 	      Maptile *t = GameMap::getInstance()->getTile(tile);
 	      Stack *st = Stacklist::getObjectAt(tile);
-	      if (st && st->getOwner() != Playerlist::getActiveplayer())
+	      if (st && st->getOwner() != active)
 		{
 		  int delta = abs(stack->getPos().x - st->getPos().x);
 		  if (delta <= 1)
@@ -509,10 +569,10 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
       d_cursor = GraphicsCache::HAND;
       Stack *st;
 
-      st = Playerlist::getActiveplayer()->getStacklist()->getObjectAt(tile);
+      st = active->getStacklist()->getObjectAt(tile);
       if (st)
 	{
-	  if (st->getOwner() == Playerlist::getActiveplayer())
+	  if (st->getOwner() == active)
 	    d_cursor = GraphicsCache::TARGET;
 	  else
 	    d_cursor = GraphicsCache::HAND;
@@ -525,7 +585,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	      City *c = Citylist::getInstance()->getObjectAt(tile);
 	      if (c->isBurnt() == true)
 		d_cursor = GraphicsCache::HAND;
-	      else if (c->getOwner() == Playerlist::getActiveplayer())
+	      else if (c->getOwner() == active)
 		d_cursor = GraphicsCache::ROOK;
 	      else if (d_see_opponents_production == true)
 		d_cursor = GraphicsCache::ROOK;
@@ -538,6 +598,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 
     }
   cursor_changed.emit(d_cursor);
+  //debugFogTile(tile.x, tile.y);
 }
 
 void GameBigMap::mouse_motion_event(MouseMotionEvent e)
@@ -546,7 +607,8 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
   if (input_locked)
     return;
 
-  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
+  Player *active = Playerlist::getActiveplayer();
+  Stack* stack = active->getActivestack();
   Vector<int> tile = mouse_pos_to_tile(e.pos);
   if (tile.x < 0)
     tile.x = 0;
@@ -560,7 +622,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 
   if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
       && (mouse_state == NONE || mouse_state == SHOWING_STACK) && 
-      stack && stack->getPos() == tile)
+      stack && stack->getPos() == tile && active->getFogMap()->isCompletelyObscuredFogTile(tile) == false)
     {
       //initial drag
       mouse_state = DRAGGING_STACK;
@@ -580,10 +642,10 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
       Vector<int> screen_dim(screen->w, screen->h);
       view_pos = clip(Vector<int>(0, 0),
 		      view_pos + delta,
-		      GameMap::get_dim() * ts - screen_dim);
+		      GameMap::get_dim() * ts *magnification_factor - screen_dim);
 
       // calculate new view position in tiles, rounding up
-      Vector<int> new_view = (view_pos + Vector<int>(ts - 1, ts - 1)) / ts;
+      Vector<int> new_view = (view_pos + Vector<int>(ts * magnification_factor - 1, ts * magnification_factor - 1)) / (ts * magnification_factor);
 
       bool redraw_buffer = false;
 
@@ -608,7 +670,8 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 
   // drag stack with left mouse button
   if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
-      && (mouse_state == DRAGGING_STACK))
+      && (mouse_state == DRAGGING_STACK) && 
+      active->getFogMap()->isCompletelyObscuredFogTile(tile) == false)
     {
       //subsequent dragging
       //alright.  calculate the path, and show it but don't move
@@ -647,6 +710,27 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
   last_tile = tile;
 }
 
+void GameBigMap::reset_zoom()
+{
+  magnification_factor = 1.0;
+  screen_size_changed();
+  draw(true);
+  view_changed.emit(view);
+}
+
+void GameBigMap::zoom_view(double percent)
+{
+  magnification_factor += percent / 100.0;
+  //call with +2, or -2
+  //Rectangle new_view = view;
+  //new_view.dim += Vector<int>(tiles, tiles);
+  //new_view.pos += Vector<int>(tiles*-1/2, tiles*-1/2);
+  //set_view (new_view);
+  screen_size_changed();
+  draw(true);
+  view_changed.emit(view);
+}
+
 void GameBigMap::after_draw()
 {
   GraphicsCache *gc = GraphicsCache::getInstance();
@@ -704,11 +788,11 @@ void GameBigMap::after_draw()
 	  static int smallframe = -1;
 
 	  bigframe++;
-	  if (bigframe >= gc->getNumberOfLargeSelectorFrames())
+	  if (bigframe >= (int)gc->getNumberOfLargeSelectorFrames())
 	    bigframe = 0;
 
 	  smallframe++;
-	  if (smallframe >= gc->getNumberOfSmallSelectorFrames())
+	  if (smallframe >= (int)gc->getNumberOfSmallSelectorFrames())
 	    smallframe = 0;
 
 	  p = tile_to_buffer_pos(p);
