@@ -27,13 +27,15 @@
 
 #include "glade-helpers.h"
 #include "image-helpers.h"
-#include "../ucompose.hpp"
-#include "../defs.h"
-#include "../army.h"
+#include "ucompose.hpp"
+#include "defs.h"
+#include "army.h"
+#include "GraphicsCache.h"
 
 //give a hero some more abilities
 ArmyGainsLevelDialog::ArmyGainsLevelDialog(Army *a, bool show_sight_stat)
 {
+    GraphicsCache *gc = GraphicsCache::getInstance();
     army = a;
     
     Glib::RefPtr<Gnome::Glade::Xml> xml
@@ -43,17 +45,19 @@ ArmyGainsLevelDialog::ArmyGainsLevelDialog(Army *a, bool show_sight_stat)
     Gtk::Dialog *d = 0;
     xml->get_widget("dialog", d);
     dialog.reset(d);
+    decorate(dialog.get());
+    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
     
     Gtk::Image *image;
     xml->get_widget("image", image);
-    image->property_pixbuf() = to_pixbuf(army->getPixmap());
+    image->property_pixbuf() = to_pixbuf(gc->getArmyPic(army));
     
     Gtk::Label *label;
     xml->get_widget("label", label);
     Glib::ustring s;
     s = String::ucompose(_("%1 has advanced to level %2!"), a->getName(),
 			 a->getLevel() + 1);
-    dialog->set_title(s);
+    set_title(s);
     s += "\n\n";
     s += _("Choose an attribute to improve:");
     label->set_text(s);
