@@ -94,9 +94,10 @@ CityWindow::CityWindow(City *c, bool razing_possible,
     raze_button->signal_clicked().connect(
 	sigc::mem_fun(this, &CityWindow::on_raze_clicked));
 
-    for (int i = 1; i <= city->getMaxNoOfProductionBases(); ++i) {
-	Gtk::ToggleButton *toggle;
-	xml->get_widget(String::ucompose("production_toggle%1", i), toggle);
+    xml->get_widget("production_toggles_hbox", production_toggles_hbox);
+    for (unsigned int i = 1; i <= city->getMaxNoOfProductionBases(); ++i) {
+	Gtk::ToggleButton *toggle = new Gtk::ToggleButton();
+	production_toggles_hbox->pack_start(*manage(toggle), false, false, 0);
 	production_toggles.push_back(toggle);
 	toggle->signal_toggled().connect(
 	    sigc::bind(sigc::mem_fun(this, &CityWindow::on_production_toggled),
@@ -188,7 +189,7 @@ void CityWindow::fill_in_production_toggles()
     empty_pic->fill(0x00000000);
     
     ignore_toggles = true;
-    for (int i = 0; i < city->getMaxNoOfProductionBases(); i++)
+    for (unsigned int i = 0; i < city->getMaxNoOfProductionBases(); i++)
     {
 	Gtk::ToggleButton *toggle = production_toggles[i];
 	toggle->foreach(sigc::mem_fun(toggle, &Gtk::Container::remove));
@@ -203,7 +204,7 @@ void CityWindow::fill_in_production_toggles()
 	
 	toggle->add(*manage(new Gtk::Image(pic)));
 
-	toggle->set_active(i == production_index);
+	toggle->set_active((int)i == production_index);
 	toggle->show_all();
     }
     ignore_toggles = false;
