@@ -30,14 +30,16 @@
 #include "glade-helpers.h"
 #include "image-helpers.h"
 #include "input-helpers.h"
-#include "../ucompose.hpp"
-#include "../defs.h"
-#include "../GameMap.h"
-#include "../city.h"
-#include "../armysetlist.h"
-#include "../citylist.h"
-#include "../GraphicsCache.h"
-#include "../vectoredunitlist.h"
+#include "ucompose.hpp"
+#include "defs.h"
+#include "GameMap.h"
+#include "city.h"
+#include "armysetlist.h"
+#include "armyprodbase.h"
+#include "citylist.h"
+#include "GraphicsCache.h"
+#include "vectoredunitlist.h"
+#include "vectoredunit.h"
 
 DestinationDialog::DestinationDialog(City *c, bool *see_all)
 {
@@ -51,6 +53,8 @@ DestinationDialog::DestinationDialog(City *c, bool *see_all)
     Gtk::Dialog *d = 0;
     xml->get_widget("dialog", d);
     dialog.reset(d);
+    decorate(dialog.get());
+    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
 
     xml->get_widget("map_image", map_image);
     xml->get_widget("see_all_togglebutton", see_all_toggle);
@@ -191,7 +195,7 @@ void DestinationDialog::fill_in_vectoring_info()
   std::list<VectoredUnit*> vectored;
   std::list<VectoredUnit*>::const_iterator it;
   VectoredUnitlist *vul = VectoredUnitlist::getInstance();
-  dialog->set_title(city->getName());
+  set_title(city->getName());
 
   Player *player = city->getOwner();
   unsigned int as = player->getArmyset();
@@ -231,8 +235,8 @@ void DestinationDialog::fill_in_vectoring_info()
     }
   else
     {
-      const Army* a = city->getProductionBase(slot);
-      pic = to_pixbuf(gc->getArmyPic(as, a->getType(), player, NULL));
+      const ArmyProdBase* a = city->getProductionBase(slot);
+      pic = to_pixbuf(gc->getArmyPic(as, a->getTypeId(), player, NULL));
       s1 = String::ucompose(_("%1t"), city->getDuration());
       turns_label->set_markup("<i>" + s1 + "</i>");
     }
@@ -244,7 +248,7 @@ void DestinationDialog::fill_in_vectoring_info()
   vul->getVectoredUnitsComingFrom(city->getPos(), vectored);
   for (it = vectored.begin(); it != vectored.end(); it++)
     {
-      int armytype = (*it)->getArmy()->getType();
+      int armytype = (*it)->getArmy()->getTypeId();
       if ((*it)->getDuration() == 2)
         {
           pic = to_pixbuf(gc->getArmyPic(as, armytype, player, NULL));
@@ -274,7 +278,7 @@ void DestinationDialog::fill_in_vectoring_info()
           case 2: image = next_turn_3_image; break;
           case 3: image = next_turn_4_image; break;
         }
-      pic = to_pixbuf(gc->getArmyPic(as, (*it)->getArmy()->getType(), player, NULL));
+      pic = to_pixbuf(gc->getArmyPic(as, (*it)->getArmy()->getTypeId(), player, NULL));
       image->set(pic);
       count++;
     }
@@ -290,7 +294,7 @@ void DestinationDialog::fill_in_vectoring_info()
           case 2: image = turn_after_3_image; break;
           case 3: image = turn_after_4_image; break;
         }
-      pic = to_pixbuf(gc->getArmyPic(as, (*it)->getArmy()->getType(), player, NULL));
+      pic = to_pixbuf(gc->getArmyPic(as, (*it)->getArmy()->getTypeId(), player, NULL));
       image->set(pic);
       count++;
     }
