@@ -38,6 +38,9 @@
 #include "File.h"
 #include "armysetlist.h"
 #include "playerlist.h"
+#include "player.h"
+#include "stacklist.h"
+#include "citylist.h"
 #include "xmlhelper.h"
 #include "Configuration.h"
 #include "ucompose.hpp"
@@ -55,6 +58,8 @@
 #include "NextTurnNetworked.h"
 #include "pbm/pbm.h"
 #include "recently-played-game-list.h"
+#include "Backpack.h"
+#include "Item.h"
 
 Driver::Driver(std::string load_filename)
 {
@@ -104,7 +109,7 @@ void Driver::run()
       p.id = 1;
       p.name = "Evil";
       g.players.push_back(p);
-      for (int i = 2; i < MAX_PLAYERS; i++)
+      for (unsigned int i = 2; i < MAX_PLAYERS; i++)
 	{
 	  p.type = GameParameters::Player::OFF;
 	  p.id = i;
@@ -131,7 +136,7 @@ void Driver::run()
       g.quick_start = false;
       g.intense_combat = false;
       g.military_advisor = false;
-      g.army_theme = "Default";
+      g.army_theme = "default";
       g.tile_theme = "default";
       g.shield_theme = "default";
       g.city_theme = "default";
@@ -461,7 +466,10 @@ void Driver::on_load_requested(std::string filename)
 
     GameScenario *game_scenario = load_game(filename);
     if (game_scenario == NULL)
-      return;
+      {
+	splash_window->show();
+	return;
+      }
 
     init_game_window();
     
@@ -511,12 +519,48 @@ void Driver::on_game_ended()
   splash_window->show();
 }
 
+void Driver::on_next_scenario(std::string scenario, int num_heroes)
+{
+  GameClient::deleteInstance();
+  PbmGameClient::deleteInstance();
+  GameServer::deleteInstance();
+  PbmGameServer::deleteInstance();
+
+  GraphicsCache::deleteInstance();
+
+  Player *p = Playerlist::getInstance()->getFirstLiving();
+
+  std::list<Hero*> heroes = p->getStacklist()->getTopHeroes(num_heroes);
+
+  //load the game again
+  GameScenario *game_scenario = load_game(scenario);
+
+
+  Player *player = Playerlist::getInstance()->getFirstHuman();
+  City *c = Citylist::getInstance()->getFirstCity(player);
+
+  for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end(); it++)
+    {
+      //munge the IDs of those heroes.
+      (*it)->assignNewId();
+      //munge the IDs of the items
+      Backpack *backpack = (*it)->getBackpack();
+      for (Backpack::iterator i = backpack->begin(); i != backpack->end(); i++)
+	(*i)->assignNewId();
+      c->addArmy(*it);
+    }
+
+  delete game_scenario;
+}
+
 void Driver::init_game_window()
 {
     game_window.reset(new GameWindow);
 
     game_window->game_ended.connect(
 	sigc::mem_fun(*this, &Driver::on_game_ended));
+    game_window->next_scenario.connect(
+	sigc::mem_fun(*this, &Driver::on_next_scenario));
     game_window->show_lobby.connect(
 	sigc::mem_fun(*this, &Driver::on_show_lobby_requested));
     game_window->quit_requested.connect(
@@ -533,7 +577,7 @@ Driver::create_and_dump_scenario(const std::string &file, const GameParameters &
 
     // then fill the other players
     int c = 0;
-    int army_id = Armysetlist::getInstance()->getArmysetId(g.army_theme);
+    int army_id = Armysetlist::getInstance()->getArmyset(g.army_theme)->getId();
     Shieldsetlist *ssl = Shieldsetlist::getInstance();
     for (std::vector<GameParameters::Player>::const_iterator
 	     i = g.players.begin(), end = g.players.end();
@@ -683,7 +727,7 @@ void Driver::stress_test()
   // quick load a test scenario
   GameParameters g;
   GameParameters::Player p;
-  for (int i = 0; i < MAX_PLAYERS; i++)
+  for (unsigned int i = 0; i < MAX_PLAYERS; i++)
     {
       p.type = GameParameters::Player::EASY;
       p.id = i;
@@ -720,7 +764,7 @@ void Driver::stress_test()
   g.quick_start = false;
   g.intense_combat = false;
   g.military_advisor = false;
-  g.army_theme = "Default";
+  g.army_theme = "default";
   g.tile_theme = "default";
   g.shield_theme = "default";
   g.city_theme = "default";
@@ -790,7 +834,7 @@ void Driver::on_game_scenario_received_for_robots(std::string path)
   GameClient::getInstance()->round_begins.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start));
   Playerlist *pl = Playerlist::getInstance();
 
-  int count = 0;
+  unsigned int count = 0;
   for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
     {
       if (count >= number_of_robots && number_of_robots > 0)
@@ -805,7 +849,7 @@ void Driver::on_game_scenario_received_for_robots(std::string path)
   pl->turnHumansInto(robot_player_type, number_of_robots);
 
   for (Playerlist::iterator it = pl->begin(); it != pl->end(); it++)
-    if ((*it)->getType() == robot_player_type)
+    if (Player::Type((*it)->getType()) == robot_player_type)
       {
 	GameClient::getInstance()->listenForLocalEvents(*it);
       }
