@@ -44,8 +44,16 @@
 
 static bool inhibit_difficulty_combobox = false;
 
+Uint32 GamePreferencesDialog::get_active_tile_size()
+{
+  return (Uint32) atoi(tile_size_combobox->get_active_text().c_str());
+}
+
 void GamePreferencesDialog::init()
 {
+    Uint32 counter = 0;
+    Uint32 default_id = 0;
+    Gtk::Box *box;
     Glib::RefPtr<Gnome::Glade::Xml> xml
 	= Gnome::Glade::Xml::create(get_glade_path() + "/game-preferences-dialog.glade");
 
@@ -135,50 +143,44 @@ void GamePreferencesDialog::init()
     load_map_filechooser->set_current_folder(Configuration::s_savePath);
     load_map_filechooser->set_filter(map_filter);
 
-
-    // fill in tile themes combobox
-    tile_theme_combobox = manage(new Gtk::ComboBoxText);
-    
-    Uint32 default_id = 0;
-    Uint32 counter = 0;
-    Tilesetlist *tl = Tilesetlist::getInstance();
-    std::list<std::string> tile_themes = tl->getNames();
-    for (std::list<std::string>::iterator i = tile_themes.begin(),
-	     end = tile_themes.end(); i != end; ++i)
+    //fill in tile sizes combobox
+    tile_size_combobox = manage(new Gtk::ComboBoxText);
+    std::list<Uint32> sizes;
+    Tilesetlist::getInstance()->getSizes(sizes);
+    Citysetlist::getInstance()->getSizes(sizes);
+    Armysetlist::getInstance()->getSizes(sizes);
+    for (std::list<Uint32>::iterator it = sizes.begin(); it != sizes.end();
+	 it++)
       {
-	if (*i == "Default")
+	Glib::ustring s = String::ucompose(_("%1x%1"), *it);
+	tile_size_combobox->append_text(s);
+	if ((*it) == Tileset::getDefaultTileSize())
 	  default_id = counter;
-	tile_theme_combobox->append_text(Glib::filename_to_utf8(*i));
 	counter++;
       }
+    tile_size_combobox->set_active(default_id);
+    xml->get_widget("tile_size_box", box);
+    box->pack_start(*tile_size_combobox, Gtk::PACK_SHRINK);
+    tile_size_combobox->signal_changed().connect(
+	sigc::mem_fun(*this, &GamePreferencesDialog::on_tile_size_changed));
 
-    tile_theme_combobox->set_active(default_id);
-
-    Gtk::Box *box;
+    // make new tile themes combobox
+    tile_theme_combobox = manage(new Gtk::ComboBoxText);
     xml->get_widget("tile_theme_box", box);
     box->pack_start(*tile_theme_combobox, Gtk::PACK_SHRINK);
 
-    // fill in army themes combobox
+    // make new army themes combobox
     army_theme_combobox = manage(new Gtk::ComboBoxText);
-    
-    Armysetlist *al = Armysetlist::getInstance();
-    std::list<std::string> army_themes = al->getNames();
-    counter = 0;
-    default_id = 0;
-    for (std::list<std::string>::iterator i = army_themes.begin(),
-	     end = army_themes.end(); i != end; ++i)
-      {
-	if (*i == "Default")
-	  default_id = counter;
-	army_theme_combobox->append_text(Glib::filename_to_utf8(*i));
-	counter++;
-      }
-
-    army_theme_combobox->set_active(default_id);
-
     xml->get_widget("army_theme_box", box);
     box->pack_start(*army_theme_combobox, Gtk::PACK_SHRINK);
 
+    // make new city themes combobox
+    city_theme_combobox = manage(new Gtk::ComboBoxText);
+    xml->get_widget("city_theme_box", box);
+    box->pack_start(*city_theme_combobox, Gtk::PACK_SHRINK);
+
+    on_tile_size_changed();
+
     // fill in shield themes combobox
     shield_theme_combobox = manage(new Gtk::ComboBoxText);
     
@@ -202,27 +204,6 @@ void GamePreferencesDialog::init()
     xml->get_widget("shield_theme_box", box);
     box->pack_start(*shield_theme_combobox, Gtk::PACK_SHRINK);
 
-    // fill in city themes combobox
-    city_theme_combobox = manage(new Gtk::ComboBoxText);
-    
-    Citysetlist *cl = Citysetlist::getInstance();
-    std::list<std::string> city_themes = cl->getNames();
-    counter = 0;
-    default_id = 0;
-    for (std::list<std::string>::iterator i = city_themes.begin(),
-	     end = city_themes.end(); i != end; ++i)
-      {
-	if (*i == "Default")
-	  default_id = counter;
-	city_theme_combobox->append_text(Glib::filename_to_utf8(*i));
-	counter++;
-      }
-
-    city_theme_combobox->set_active(default_id);
-
-    xml->get_widget("city_theme_box", box);
-    box->pack_start(*city_theme_combobox, Gtk::PACK_SHRINK);
-
     start_game_button->signal_clicked().connect
       (sigc::mem_fun(*this, &GamePreferencesDialog::on_start_game_clicked));
 
@@ -291,6 +272,7 @@ bool GamePreferencesDialog::run(std::string nickname)
 	game_name_entry->set_text(text);
       }
     update_shields();
+    on_player_type_changed();
     int response = dialog->run();
     if (response == 0)
       return true;
@@ -534,24 +516,25 @@ void GamePreferencesDialog::update_difficulty_rating()
 	g.players.push_back(p);
       }
 
-    g.see_opponents_stacks = Configuration::s_see_opponents_stacks;
-    g.see_opponents_production = Configuration::s_see_opponents_production;
-    g.play_with_quests = Configuration::s_play_with_quests;
-    g.hidden_map = Configuration::s_hidden_map;
-    g.neutral_cities = Configuration::s_neutral_cities;
-    g.razing_cities = Configuration::s_razing_cities;
-    g.diplomacy = Configuration::s_diplomacy;
-    g.cusp_of_war = Configuration::s_cusp_of_war;
-    g.random_turns = Configuration::s_random_turns;
+    g.see_opponents_stacks = GameScenarioOptions::s_see_opponents_stacks;
+    g.see_opponents_production = GameScenarioOptions::s_see_opponents_production;
+    g.play_with_quests = GameScenarioOptions::s_play_with_quests;
+    g.hidden_map = GameScenarioOptions::s_hidden_map;
+    g.neutral_cities = GameScenarioOptions::s_neutral_cities;
+    g.razing_cities = GameScenarioOptions::s_razing_cities;
+    g.diplomacy = GameScenarioOptions::s_diplomacy;
+    g.cusp_of_war = GameScenarioOptions::s_cusp_of_war;
+    g.random_turns = GameScenarioOptions::s_random_turns;
     g.quick_start = Configuration::s_quick_start;
-    g.intense_combat = Configuration::s_intense_combat;
-    g.military_advisor = Configuration::s_military_advisor;
+    g.intense_combat = GameScenarioOptions::s_intense_combat;
+    g.military_advisor = GameScenarioOptions::s_military_advisor;
 
     int difficulty = GameScenario::calculate_difficulty_rating(g);
     g.players.clear();
 
     difficulty_label->set_markup(String::ucompose("<b>%1%%</b>", difficulty));
 }
+
 void GamePreferencesDialog::on_start_game_clicked()
 {
   Armysetlist *al = Armysetlist::getInstance();
@@ -659,14 +642,19 @@ void GamePreferencesDialog::on_start_game_clicked()
       }
 
     g.tile_theme = tl->getTilesetDir 
-      (Glib::filename_from_utf8(tile_theme_combobox->get_active_text()));
+      (Glib::filename_from_utf8(tile_theme_combobox->get_active_text()),
+       get_active_tile_size());
+
+    g.army_theme = al->getArmysetDir
+      (Glib::filename_from_utf8(army_theme_combobox->get_active_text()),
+       get_active_tile_size());
 
-    g.army_theme = Glib::filename_from_utf8(army_theme_combobox->get_active_text());
     g.shield_theme = sl->getShieldsetDir 
       (Glib::filename_from_utf8(shield_theme_combobox->get_active_text()));
 
     g.city_theme = cl->getCitysetDir 
-      (Glib::filename_from_utf8(city_theme_combobox->get_active_text()));
+      (Glib::filename_from_utf8(city_theme_combobox->get_active_text()),
+       get_active_tile_size());
 
     g.process_armies = GameParameters::PROCESS_ARMIES_AT_PLAYERS_TURN;
 
@@ -692,7 +680,8 @@ void GamePreferencesDialog::on_start_game_clicked()
       g.name = _("Autogenerated");
 
     //don't start if the armyset size differs from the terrain set size.
-    Uint32 army_tilesize = al->getTileSize(al->getArmysetId(g.army_theme));
+    Uint32 army_tilesize = al->getArmyset(g.army_theme)->getTileSize();
+      //al->getTileSize(al->getArmysetId(g.army_theme, get_active_tile_size()));
     Uint32 terrain_size = tl->getTileset(g.tile_theme)->getTileSize();
     Uint32 city_size = cl->getCityset(g.city_theme)->getTileSize();
     if (army_tilesize != (Uint32) terrain_size)
@@ -713,26 +702,32 @@ void GamePreferencesDialog::on_grass_random_toggled()
 {
   grass_scale->set_sensitive(!grass_random_togglebutton->get_active());
 }
+
 void GamePreferencesDialog::on_water_random_toggled()
 {
   water_scale->set_sensitive(!water_random_togglebutton->get_active());
 }
+
 void GamePreferencesDialog::on_swamp_random_toggled()
 {
   swamp_scale->set_sensitive(!swamp_random_togglebutton->get_active());
 }
+
 void GamePreferencesDialog::on_forest_random_toggled()
 {
   forest_scale->set_sensitive(!forest_random_togglebutton->get_active());
 }
+
 void GamePreferencesDialog::on_hills_random_toggled()
 {
   hills_scale->set_sensitive(!hills_random_togglebutton->get_active());
 }
+
 void GamePreferencesDialog::on_mountains_random_toggled()
 {
   mountains_scale->set_sensitive(!mountains_random_togglebutton->get_active());
 }
+
 void GamePreferencesDialog::on_cities_random_toggled()
 {
   cities_scale->set_sensitive(!cities_random_togglebutton->get_active());
@@ -744,47 +739,47 @@ void GamePreferencesDialog::on_difficulty_changed()
   switch (difficulty_combobox->get_active_row_number()) 
     {
     case BEGINNER:
-      Configuration::s_see_opponents_stacks = true;
-      Configuration::s_see_opponents_production = true;
-      Configuration::s_play_with_quests = false;
-      Configuration::s_hidden_map = false;
-      Configuration::s_neutral_cities = GameParameters::AVERAGE;
-      Configuration::s_razing_cities = GameParameters::ALWAYS;
-      Configuration::s_diplomacy = false;
-      Configuration::s_cusp_of_war = false;
+      GameScenarioOptions::s_see_opponents_stacks = true;
+      GameScenarioOptions::s_see_opponents_production = true;
+      GameScenarioOptions::s_play_with_quests = false;
+      GameScenarioOptions::s_hidden_map = false;
+      GameScenarioOptions::s_neutral_cities = GameParameters::AVERAGE;
+      GameScenarioOptions::s_razing_cities = GameParameters::ALWAYS;
+      GameScenarioOptions::s_diplomacy = false;
+      GameScenarioOptions::s_cusp_of_war = false;
       type_num = 1; break;
 
     case INTERMEDIATE:
-      Configuration::s_see_opponents_stacks = false;
-      Configuration::s_see_opponents_production = true;
-      Configuration::s_play_with_quests = true;
-      Configuration::s_hidden_map = false;
-      Configuration::s_neutral_cities = GameParameters::STRONG;
-      Configuration::s_razing_cities = GameParameters::ALWAYS;
-      Configuration::s_diplomacy = true;
-      Configuration::s_cusp_of_war = false;
+      GameScenarioOptions::s_see_opponents_stacks = false;
+      GameScenarioOptions::s_see_opponents_production = true;
+      GameScenarioOptions::s_play_with_quests = true;
+      GameScenarioOptions::s_hidden_map = false;
+      GameScenarioOptions::s_neutral_cities = GameParameters::STRONG;
+      GameScenarioOptions::s_razing_cities = GameParameters::ALWAYS;
+      GameScenarioOptions::s_diplomacy = true;
+      GameScenarioOptions::s_cusp_of_war = false;
       type_num = 1; break;
 
     case ADVANCED:
-      Configuration::s_see_opponents_stacks = false;
-      Configuration::s_see_opponents_production = false;
-      Configuration::s_play_with_quests = true;
-      Configuration::s_hidden_map = true;
-      Configuration::s_neutral_cities = GameParameters::ACTIVE;
-      Configuration::s_razing_cities = GameParameters::ON_CAPTURE;
-      Configuration::s_diplomacy = true;
-      Configuration::s_cusp_of_war = false;
+      GameScenarioOptions::s_see_opponents_stacks = false;
+      GameScenarioOptions::s_see_opponents_production = false;
+      GameScenarioOptions::s_play_with_quests = true;
+      GameScenarioOptions::s_hidden_map = true;
+      GameScenarioOptions::s_neutral_cities = GameParameters::ACTIVE;
+      GameScenarioOptions::s_razing_cities = GameParameters::ON_CAPTURE;
+      GameScenarioOptions::s_diplomacy = true;
+      GameScenarioOptions::s_cusp_of_war = false;
       type_num = 2; break;
 
     case I_AM_THE_GREATEST:
-      Configuration::s_see_opponents_stacks = false;
-      Configuration::s_see_opponents_production = false;
-      Configuration::s_play_with_quests = true;
-      Configuration::s_hidden_map = true;
-      Configuration::s_neutral_cities = GameParameters::ACTIVE;
-      Configuration::s_razing_cities = GameParameters::NEVER;
-      Configuration::s_diplomacy = true;
-      Configuration::s_cusp_of_war = true;
+      GameScenarioOptions::s_see_opponents_stacks = false;
+      GameScenarioOptions::s_see_opponents_production = false;
+      GameScenarioOptions::s_play_with_quests = true;
+      GameScenarioOptions::s_hidden_map = true;
+      GameScenarioOptions::s_neutral_cities = GameParameters::ACTIVE;
+      GameScenarioOptions::s_razing_cities = GameParameters::NEVER;
+      GameScenarioOptions::s_diplomacy = true;
+      GameScenarioOptions::s_cusp_of_war = true;
       type_num = 2; break;
 
     case CUSTOM:
@@ -808,49 +803,52 @@ void GamePreferencesDialog::on_difficulty_changed()
 
 bool GamePreferencesDialog::is_beginner()
 {
-  return (Configuration::s_see_opponents_stacks == true &&
-	  Configuration::s_see_opponents_production == true &&
-	  Configuration::s_play_with_quests == false &&
-	  Configuration::s_hidden_map == false &&
-	  Configuration::s_neutral_cities == GameParameters::AVERAGE &&
-	  Configuration::s_razing_cities == GameParameters::ALWAYS &&
-	  Configuration::s_diplomacy == false &&
-	  Configuration::s_cusp_of_war == false);
+  return (GameScenarioOptions::s_see_opponents_stacks == true &&
+	  GameScenarioOptions::s_see_opponents_production == true &&
+	  GameScenarioOptions::s_play_with_quests == false &&
+	  GameScenarioOptions::s_hidden_map == false &&
+	  GameScenarioOptions::s_neutral_cities == GameParameters::AVERAGE &&
+	  GameScenarioOptions::s_razing_cities == GameParameters::ALWAYS &&
+	  GameScenarioOptions::s_diplomacy == false &&
+	  GameScenarioOptions::s_cusp_of_war == false);
 }
+
 bool GamePreferencesDialog::is_intermediate()
 {
-  return (
-	  Configuration::s_see_opponents_stacks == false &&
-	  Configuration::s_see_opponents_production == true &&
-	  Configuration::s_play_with_quests == true &&
-	  Configuration::s_hidden_map == false &&
-	  Configuration::s_neutral_cities == GameParameters::STRONG &&
-	  Configuration::s_razing_cities == GameParameters::ALWAYS &&
-	  Configuration::s_diplomacy == true &&
-	  Configuration::s_cusp_of_war == false);
+  return (GameScenarioOptions::s_see_opponents_stacks == false &&
+	  GameScenarioOptions::s_see_opponents_production == true &&
+	  GameScenarioOptions::s_play_with_quests == true &&
+	  GameScenarioOptions::s_hidden_map == false &&
+	  GameScenarioOptions::s_neutral_cities == GameParameters::STRONG &&
+	  GameScenarioOptions::s_razing_cities == GameParameters::ALWAYS &&
+	  GameScenarioOptions::s_diplomacy == true &&
+	  GameScenarioOptions::s_cusp_of_war == false);
 }
+
 bool GamePreferencesDialog::is_advanced()
 {
-  return (Configuration::s_see_opponents_stacks == false &&
-	  Configuration::s_see_opponents_production == false &&
-	  Configuration::s_play_with_quests == true &&
-	  Configuration::s_hidden_map == true &&
-	  Configuration::s_neutral_cities == GameParameters::ACTIVE &&
-	  Configuration::s_razing_cities == GameParameters::ON_CAPTURE &&
-	  Configuration::s_diplomacy == true &&
-	  Configuration::s_cusp_of_war == false);
+  return (GameScenarioOptions::s_see_opponents_stacks == false &&
+	  GameScenarioOptions::s_see_opponents_production == false &&
+	  GameScenarioOptions::s_play_with_quests == true &&
+	  GameScenarioOptions::s_hidden_map == true &&
+	  GameScenarioOptions::s_neutral_cities == GameParameters::ACTIVE &&
+	  GameScenarioOptions::s_razing_cities == GameParameters::ON_CAPTURE &&
+	  GameScenarioOptions::s_diplomacy == true &&
+	  GameScenarioOptions::s_cusp_of_war == false);
 }
+
 bool GamePreferencesDialog::is_greatest()
 {
-  return (Configuration::s_see_opponents_stacks == false &&
-	  Configuration::s_see_opponents_production == false &&
-	  Configuration::s_play_with_quests == true &&
-	  Configuration::s_hidden_map == true &&
-	  Configuration::s_neutral_cities == GameParameters::ACTIVE &&
-	  Configuration::s_razing_cities == GameParameters::NEVER &&
-	  Configuration::s_diplomacy == true &&
-	  Configuration::s_cusp_of_war == true);
+  return (GameScenarioOptions::s_see_opponents_stacks == false &&
+	  GameScenarioOptions::s_see_opponents_production == false &&
+	  GameScenarioOptions::s_play_with_quests == true &&
+	  GameScenarioOptions::s_hidden_map == true &&
+	  GameScenarioOptions::s_neutral_cities == GameParameters::ACTIVE &&
+	  GameScenarioOptions::s_razing_cities == GameParameters::NEVER &&
+	  GameScenarioOptions::s_diplomacy == true &&
+	  GameScenarioOptions::s_cusp_of_war == true);
 }
+
 void GamePreferencesDialog::on_map_chosen()
 {
   std::string selected_filename = load_map_filechooser->get_filename();
@@ -873,8 +871,10 @@ void GamePreferencesDialog::on_map_chosen()
     }
   helper.close();
   update_shields();
+  on_player_type_changed();
   return;
 }
+
 bool GamePreferencesDialog::scan_shieldset(std::string tag, XML_Helper* helper)
 {
     if (tag == "map")
@@ -883,6 +883,7 @@ bool GamePreferencesDialog::scan_shieldset(std::string tag, XML_Helper* helper)
       }
     return true;
 }
+
 bool GamePreferencesDialog::scan_players(std::string tag, XML_Helper* helper)
 {
     if (tag == "player")
@@ -912,6 +913,8 @@ bool GamePreferencesDialog::scan_players(std::string tag, XML_Helper* helper)
 	    break;
 	  case Player::AI_SMART: p.type = GameParameters::Player::HARD;
 	    break;
+	  case Player::NETWORKED: p.type = GameParameters::Player::HUMAN;
+	    break;
 	  }
         helper->getData(name, "name");
 	p.name = name;
@@ -927,3 +930,61 @@ void GamePreferencesDialog::set_title(std::string text)
 {
   Decorated::set_title(text);
 }
+
+void GamePreferencesDialog::on_tile_size_changed()
+{
+  Uint32 default_id = 0;
+  Uint32 counter = 0;
+
+  tile_theme_combobox->clear_items();
+  Tilesetlist *tl = Tilesetlist::getInstance();
+  std::list<std::string> tile_themes = tl->getNames(get_active_tile_size());
+  for (std::list<std::string>::iterator i = tile_themes.begin(),
+       end = tile_themes.end(); i != end; ++i)
+    {
+      if (*i == "Default")
+	default_id = counter;
+      tile_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+      counter++;
+    }
+
+  tile_theme_combobox->set_active(default_id);
+  if (tile_theme_combobox->get_children().size() == 0)
+    start_game_button->set_sensitive(false);
+
+  army_theme_combobox->clear_items();
+  Armysetlist *al = Armysetlist::getInstance();
+  std::list<std::string> army_themes = al->getNames(get_active_tile_size());
+  counter = 0;
+  default_id = 0;
+  for (std::list<std::string>::iterator i = army_themes.begin(),
+       end = army_themes.end(); i != end; ++i)
+    {
+      if (*i == "Default")
+	default_id = counter;
+      army_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+      counter++;
+    }
+
+  army_theme_combobox->set_active(default_id);
+  if (army_theme_combobox->get_children().size() == 0)
+    start_game_button->set_sensitive(false);
+
+  city_theme_combobox->clear_items();
+  Citysetlist *cl = Citysetlist::getInstance();
+  std::list<std::string> city_themes = cl->getNames(get_active_tile_size());
+  counter = 0;
+  default_id = 0;
+  for (std::list<std::string>::iterator i = city_themes.begin(),
+       end = city_themes.end(); i != end; ++i)
+    {
+      if (*i == "Default")
+	default_id = counter;
+      city_theme_combobox->append_text(Glib::filename_to_utf8(*i));
+      counter++;
+    }
+
+  city_theme_combobox->set_active(default_id);
+  if (city_theme_combobox->get_children().size() == 0)
+    start_game_button->set_sensitive(false);
+}
