@@ -166,7 +166,7 @@ GameWindow::GameWindow()
     xml->get_widget("map_image", map_image);
     xml->get_widget("map_eventbox", map_eventbox);
     map_eventbox->add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK |
-			     Gdk::POINTER_MOTION_MASK);
+			     Gdk::POINTER_MOTION_MASK | Gdk::SCROLL_MASK);
       map_eventbox->signal_button_press_event().connect
        (sigc::mem_fun(*this, &GameWindow::on_map_mouse_button_event));
       map_eventbox->signal_button_release_event().connect
@@ -254,9 +254,10 @@ GameWindow::GameWindow()
     xml->get_widget("save_game_as_menuitem", save_game_as_menuitem);
     save_game_as_menuitem->signal_activate().connect
       (sigc::mem_fun(*this, &GameWindow::on_save_game_as_activated));
-
     xml->connect_clicked("quit_menuitem", 
 			 sigc::mem_fun(*this, &GameWindow::on_quit_activated));
+    xml->connect_clicked("toggle_grid_menuitem", 
+			 sigc::mem_fun(*this, &GameWindow::on_grid_toggled));
     xml->connect_clicked("army_report_menuitem",
 			 sigc::mem_fun(*this, &GameWindow::on_army_report_activated));
     xml->connect_clicked("city_report_menuitem", 
@@ -298,6 +299,8 @@ GameWindow::GameWindow()
 			 sigc::mem_fun(*this, &GameWindow::on_fight_order_activated));
     xml->connect_clicked("resign_menuitem",
 			 sigc::mem_fun(*this, &GameWindow::on_resign_activated));
+    xml->connect_clicked("production_menuitem",
+			 sigc::mem_fun(*this, &GameWindow::on_production_activated));
     xml->connect_clicked("levels_menuitem",
 			 sigc::mem_fun(*this, &GameWindow::on_levels_activated));
     xml->connect_clicked("ruin_report_menuitem",
@@ -411,6 +414,8 @@ void GameWindow::init(int width, int height)
 	sigc::mem_fun(*this, &GameWindow::on_sdl_mouse_button_event));
     sdl_widget->signal_motion_notify_event().connect(
 	sigc::mem_fun(*this, &GameWindow::on_sdl_mouse_motion_event));
+    sdl_widget->signal_scroll_event().connect
+       (sigc::mem_fun(*this, &GameWindow::on_sdl_scroll_event));
     
     // connect to the special signal that signifies that a new surface has been
     // generated and attached to the widget
@@ -447,7 +452,6 @@ void GameWindow::continue_network_game(NextTurn *next_turn)
 void GameWindow::new_game(GameScenario *game_scenario, NextTurn *next_turn)
 {
   bool success = false;
-  stop_game();
   success = setup_game(game_scenario, next_turn);
   if (!success)
     return;
@@ -628,6 +632,9 @@ void GameWindow::setup_signals(GameScenario *game_scenario)
 		 game->can_select_next_movable_stack);
 
   // setup game callbacks
+  connections.push_back
+    (game->game_stopped.connect
+     (sigc::mem_fun(*this, &GameWindow::on_game_stopped)));
   connections.push_back 
     (game->sidebar_stats_changed.connect
      (sigc::mem_fun(*this, &GameWindow::on_sidebar_stats_changed)));
@@ -718,6 +725,9 @@ void GameWindow::setup_signals(GameScenario *game_scenario)
   connections.push_back
     (game->game_over.connect
      (sigc::mem_fun(*this, &GameWindow::on_game_over)));
+  connections.push_back
+    (game->next_scenario.connect
+     (sigc::mem_fun(*this, &GameWindow::on_next_scenario)));
   connections.push_back
     (game->player_died.connect
      (sigc::mem_fun(*this, &GameWindow::on_player_died)));
@@ -850,10 +860,33 @@ bool GameWindow::on_sdl_mouse_button_event(GdkEventButton *e)
 
 bool GameWindow::on_sdl_mouse_motion_event(GdkEventMotion *e)
 {
+  static guint prev = 0;
   if (game.get())
     {
-      game->get_bigmap().mouse_motion_event(to_input_event(e));
-      sdl_widget->grab_focus();
+      guint delta = e->time - prev;
+      if (delta > 40 || delta < 0)
+	{
+	  game->get_bigmap().mouse_motion_event(to_input_event(e));
+	  sdl_widget->grab_focus();
+	  prev = e->time;
+	}
+    }
+  return true;
+}
+    
+bool GameWindow::on_sdl_scroll_event(GdkEventScroll* event)
+{
+  switch (event->direction) 
+    {
+    case GDK_SCROLL_LEFT:
+    case GDK_SCROLL_RIGHT:
+      break;
+    case GDK_SCROLL_UP:
+      game->get_bigmap().zoom_in();
+      break;
+    case GDK_SCROLL_DOWN:
+      game->get_bigmap().zoom_out();
+      break;
     }
   return true;
 }
@@ -940,32 +973,9 @@ void GameWindow::on_load_game_activated()
     {
       std::string filename = chooser.get_filename();
       current_save_filename = filename;
-      stop_game();
-    
-      bool broken = false;
-      GameScenario* game_scenario = new GameScenario(filename, broken);
-
-      if (broken)
-	{
-	  on_message_requested(_("Corrupted saved game file."));
-	  game_ended.emit();
-	  return;
-	}
-      if (game_scenario->getPlayMode() == GameScenario::HOTSEAT)
-	load_game(game_scenario, 
-		  new NextTurnHotseat(game_scenario->getTurnmode(),
-				      game_scenario->s_random_turns));
-      else if (game_scenario->getPlayMode() == GameScenario::PLAY_BY_MAIL)
-	{
-	  PbmGameServer::getInstance()->start();
-	  load_game(game_scenario, 
-		    new NextTurnPbm(game_scenario->getTurnmode(),
-				    game_scenario->s_random_turns));
-	}
-      else if (game_scenario->getPlayMode() == GameScenario::NETWORKED)
-	load_game(game_scenario, 
-		  new NextTurnNetworked(game_scenario->getTurnmode(),
-					game_scenario->s_random_turns));
+      d_load_filename = filename;
+      stop_game("load-game");
+      //now look at on_game_stopped.
     }
 }
 
@@ -1035,8 +1045,43 @@ void GameWindow::on_quit_activated()
 
   if (response == 0) //end the game
     {
-      stop_game();
+      stop_game("quit");
+    }
+}
+
+void GameWindow::on_game_stopped()
+{
+  game.reset();
+  if (stop_action == "quit" || stop_action == "game-over")
       game_ended.emit();
+  else if (stop_action == "next-scenario")
+      next_scenario.emit(d_scenario, d_num_heroes);
+  else if (stop_action == "load-game")
+    {
+      bool broken = false;
+      GameScenario* game_scenario = new GameScenario(d_load_filename, broken);
+
+      if (broken)
+	{
+	  on_message_requested(_("Corrupted saved game file."));
+	  game_ended.emit();
+	  return;
+	}
+      if (game_scenario->getPlayMode() == GameScenario::HOTSEAT)
+	load_game(game_scenario, 
+		  new NextTurnHotseat(game_scenario->getTurnmode(),
+				      game_scenario->s_random_turns));
+      else if (game_scenario->getPlayMode() == GameScenario::PLAY_BY_MAIL)
+	{
+	  PbmGameServer::getInstance()->start();
+	  load_game(game_scenario, 
+		    new NextTurnPbm(game_scenario->getTurnmode(),
+				    game_scenario->s_random_turns));
+	}
+      else if (game_scenario->getPlayMode() == GameScenario::NETWORKED)
+	load_game(game_scenario, 
+		  new NextTurnNetworked(game_scenario->getTurnmode(),
+					game_scenario->s_random_turns));
     }
 }
 
@@ -1223,6 +1268,24 @@ void GameWindow::on_resign_activated()
   return;
 }
 
+void GameWindow::on_production_activated()
+{
+  City *city;
+  if (Playerlist::getActiveplayer()->getType() != Player::HUMAN)
+    return;
+
+  if (currently_selected_stack)
+    {
+      Vector<int> pos = currently_selected_stack->getPos();
+      city = Citylist::getInstance()->getNearestVisibleFriendlyCity(pos);
+    }
+  else
+    city = Citylist::getInstance()->getFirstCity(Playerlist::getActiveplayer());
+
+  on_city_visited(city);
+  return;
+}
+
 void GameWindow::on_preferences_activated()
 {
   Player *current = Playerlist::getInstance()->getActiveplayer();
@@ -1445,17 +1508,25 @@ void GameWindow::on_diplomacy_button_clicked()
   d.hide();
 }
 
-void GameWindow::stop_game()
+void GameWindow::stop_game(std::string action)
 {
+  stop_action = action;
   Sound::getInstance()->disableBackground();
   if (game.get())
     {
       game->stopGame();
-      game.reset();
       current_save_filename = "";
     }
 }
 
+void GameWindow::on_next_scenario(std::string scenario, int num_heroes)
+{
+  //fixme: show a message here.  we won, but there's another scenario to go
+  d_scenario = scenario;
+  d_num_heroes = num_heroes;
+  stop_game("next-scenario");
+}
+
 void GameWindow::on_game_over(Player *winner)
 {
 
@@ -1492,8 +1563,7 @@ void GameWindow::on_game_over(Player *winner)
   dialog->run();
   dialog->hide();
 
-  stop_game();
-  game_ended.emit();
+  stop_game("game-over");
 }
 
 void GameWindow::on_player_died(Player *player)
@@ -1665,7 +1735,11 @@ void GameWindow::on_stack_info_changed(Stack *s)
   else
     {
       if (s->getOwner()->getType() == Player::HUMAN)
-	show_stack(s);
+	{
+	  s->setDefending(false);
+	  s->setParked(false);
+	  show_stack(s);
+	}
       else
 	show_stats();
     }
@@ -2973,3 +3047,9 @@ void GameWindow::on_player_replaced(Player *p)
 {
   game->addPlayer(p);
 }
+
+void GameWindow::on_grid_toggled()
+{
+  game->get_bigmap().toggle_grid();
+}
+
