@@ -62,6 +62,7 @@ class Temple;
 class Quest;
 class City;
 class Reward;
+class Reward_Ruin;
 class NextTurn;
 
 /** The main window in which all the game action is going on.
@@ -98,6 +99,9 @@ class GameWindow: public Decorated
     // emitted when the game has ended and it is time to show the splash again
     sigc::signal<void> game_ended;
     
+    // emitted when we're in a campaign, and we want to go to the next scenario
+    sigc::signal<void, std::string, int> next_scenario;
+    
     sigc::signal<void> show_lobby;
 
     sigc::signal<void> quit_requested;
@@ -188,6 +192,7 @@ class GameWindow: public Decorated
     bool on_sdl_mouse_button_event(GdkEventButton *e);
     bool on_sdl_mouse_motion_event(GdkEventMotion *e);
     bool on_sdl_key_event(GdkEventKey *e);
+    bool on_sdl_scroll_event(GdkEventScroll* event);
 
     bool on_map_mouse_button_event(GdkEventButton *e);
     bool on_map_mouse_motion_event(GdkEventMotion *e);
@@ -197,6 +202,7 @@ class GameWindow: public Decorated
     void on_save_game_as_activated();
     void on_show_lobby_activated();
     void on_quit_activated();
+    void on_game_stopped();
     void on_quests_activated();
     void on_disband_activated();
     void on_stack_info_activated();
@@ -220,6 +226,8 @@ class GameWindow: public Decorated
     
     void on_fight_order_activated();
     void on_levels_activated();
+    void on_production_activated();
+    void on_grid_toggled();
     void on_ruin_report_activated();
     void on_army_bonus_activated();
     void on_city_history_activated();
@@ -281,6 +289,7 @@ class GameWindow: public Decorated
     Army::Stat on_army_gains_level(Army *army);
     void on_game_loaded(Player *player);
     void on_game_over(Player *winner);
+    void on_next_scenario(std::string scenario, int num_heroes);
     void on_player_died(Player *player);
     void on_advice_asked(float percent);
     void end_turn_play_by_mail ();
@@ -299,7 +308,7 @@ class GameWindow: public Decorated
 
     bool setup_game(GameScenario *game_scenario, NextTurn *nextTurn);
     void setup_signals(GameScenario *game_scenario);
-    void stop_game();
+    void stop_game(std::string action);
     std::list<sigc::connection> connections;
     
     void setup_menuitem(Gtk::MenuItem*, sigc::slot<void> , sigc::signal<void, bool> &);
@@ -310,6 +319,10 @@ public:
     std::vector<Glib::RefPtr<Gdk::Pixbuf> > d_button_images;
     std::vector<Glib::RefPtr<Gdk::Pixbuf> > d_arrow_images;
     bool d_quick_fights; //do we speed up fights for this player's turn?
+    std::string stop_action; //hackhackhack
+    std::string d_scenario;
+    int d_num_heroes;
+    std::string d_load_filename;
 };
 
 #endif
