@@ -25,16 +25,16 @@
 
 #include "glade-helpers.h"
 #include "image-helpers.h"
-#include "../ucompose.hpp"
-#include "../defs.h"
-#include "../playerlist.h"
-#include "../player.h"
-#include "../army.h"
-#include "../armysetlist.h"
-#include "../stacklist.h"
-#include "../stack.h"
-#include "../hero.h"
-#include "../GraphicsCache.h"
+#include "ucompose.hpp"
+#include "defs.h"
+#include "playerlist.h"
+#include "player.h"
+#include "army.h"
+#include "armysetlist.h"
+#include "stacklist.h"
+#include "stack.h"
+#include "hero.h"
+#include "GraphicsCache.h"
 
 HeroLevelsDialog::HeroLevelsDialog(Player *theplayer)
 {
@@ -47,6 +47,8 @@ HeroLevelsDialog::HeroLevelsDialog(Player *theplayer)
     Gtk::Dialog *d = 0;
     xml->get_widget("dialog", d);
     dialog.reset(d);
+    decorate(dialog.get());
+    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
 
     heroes_list = Gtk::ListStore::create(heroes_columns);
     xml->get_widget("treeview", heroes_treeview);
@@ -100,7 +102,7 @@ void HeroLevelsDialog::addHero(Hero *h)
     Gtk::TreeIter i = heroes_list->append();
     (*i)[heroes_columns.name] = h->getName();
     (*i)[heroes_columns.image] = to_pixbuf(gc->getArmyPic(player->getArmyset(),
-                                           h->getType(), player, NULL));
+                                           h->getTypeId(), player, NULL));
     (*i)[heroes_columns.level] = String::ucompose(_("%1"), h->getLevel());
     (*i)[heroes_columns.exp] = (Uint32)h->getXP();
     (*i)[heroes_columns.needs] = (Uint32)h->getXpNeededForNextLevel();
