@@ -249,14 +249,14 @@ void HistoryReportDialog::generatePastCitylists()
     }
 
   //start off with an initial city list where all cities are neutral owned
-  LocationList<City> *clist = new LocationList<City>();
+  LocationList<City*> *clist = new LocationList<City*>();
   Citylist *cl = Citylist::getInstance();
   for (Citylist::iterator it = cl->begin(); it != cl->end(); ++it)
     clist->push_back(*it);
-  for (LocationList<City>::iterator it = clist->begin(); it != clist->end(); ++it)
+  for (LocationList<City*>::iterator it = clist->begin(); it != clist->end(); ++it)
     {
-      (*it).setOwner(Playerlist::getInstance()->getNeutral());
-      (*it).setBurnt(false);
+      (*it)->setOwner(Playerlist::getInstance()->getNeutral());
+      (*it)->setBurnt(false);
     }
 
   unsigned int count = 0;
@@ -284,11 +284,11 @@ void HistoryReportDialog::generatePastCitylists()
 		  Uint32 city_id;
 		  city_id = dynamic_cast<History_CityWon*>(*hit[id])->getCityId();
 		  //find city with this city id in clist
-		  LocationList<City>::iterator cit = clist->begin();
+		  LocationList<City*>::iterator cit = clist->begin();
 		  for (; cit != clist->end(); ++cit)
-		    if ((*cit).getId() == city_id)
+		    if ((*cit)->getId() == city_id)
 		      {
-			(*cit).setOwner(*pit);
+			(*cit)->setOwner(*pit);
 			break;
 		      }
 		}
@@ -297,13 +297,13 @@ void HistoryReportDialog::generatePastCitylists()
 		  Uint32 city_id;
 		  city_id = dynamic_cast<History_CityRazed*>(*hit[id])->getCityId();
 		  //find city with this city id in clist
-		  LocationList<City>::iterator cit = clist->begin();
+		  LocationList<City*>::iterator cit = clist->begin();
 		  for (; cit != clist->end(); ++cit)
-		    if ((*cit).getId() == city_id)
+		    if ((*cit)->getId() == city_id)
 		      {
 			//change the owner to neutral 
-			(*cit).setOwner(Playerlist::getInstance()->getNeutral());
-			(*cit).setBurnt(true);
+			(*cit)->setOwner(Playerlist::getInstance()->getNeutral());
+			(*cit)->setBurnt(true);
 			break;
 		      }
 		}
@@ -317,7 +317,7 @@ void HistoryReportDialog::generatePastCitylists()
 	}
       //and add it to the list
       past_citylists.push_back(clist);
-      LocationList<City> *new_clist = new LocationList<City>(*clist);
+      LocationList<City*> *new_clist = new LocationList<City*>(*clist);
       clist = new_clist;
       if (last_turn == true)
 	break;
@@ -650,10 +650,10 @@ void HistoryReportDialog::generatePastCityCounts()
       for (unsigned int i = 0; i < past_citylists.size(); i++)
 	{
 	  Uint32 total_cities = 0;
-	  LocationList<City>::iterator it = past_citylists[i]->begin();
+	  LocationList<City*>::iterator it = past_citylists[i]->begin();
 	  for (; it != past_citylists[i]->end(); it++)
 	    {
-	      if ((*it).getOwner() == *pit)
+	      if ((*it)->getOwner() == *pit)
 		total_cities++;
 	    }
 	  line.push_back(total_cities);
