@@ -28,8 +28,10 @@
 #include "main.h"
 
 #include "driver.h"
-#include "../defs.h"
-#include "../timing.h"
+#include "defs.h"
+#include "File.h"
+#include "Configuration.h"
+#include "timing.h"
 
 
 struct Main::Impl: public sigc::trackable 
@@ -50,7 +52,12 @@ Main::Main(int &argc, char **&argv)
     singleton = this;
 
     start_test_scenario = false;
+    start_stress_test = false;
+    start_robots = 0;
+    load_filename = "";
+    turn_filename = "";
     
+    Glib::thread_init();
     try
     {
 	impl->gtk_main.reset(new Gtk::Main(argc, argv));
@@ -92,9 +99,12 @@ bool Main::iterate_main_loop()
 
 void Main::start_main_loop()
 {
+    if (Configuration::s_decorated)
+      Gtk::RC::add_default_file(File::getMiscFile("gtkrc"));
+
     try
     {
-	impl->driver.reset(new Driver);
+	impl->driver.reset(new Driver(load_filename));
 	impl->gtk_main->run();
     }
     catch (const Glib::Error &ex) {
