@@ -29,11 +29,12 @@
 #include <gtkmm/scale.h>
 #include <gtkmm/box.h>
 
-#include "../vector.h"
+#include "vector.h"
 
+#include "decorated.h"
 class Game;
 // dialog for showing sound and game preferences
-class PreferencesDialog: public sigc::trackable
+class PreferencesDialog: public Decorated
 {
  public:
     PreferencesDialog(bool readonly);
