@@ -27,9 +27,9 @@
 #include "glade-helpers.h"
 #include "image-helpers.h"
 #include "input-helpers.h"
-#include "../ucompose.hpp"
-#include "../defs.h"
-#include "../GameMap.h"
+#include "ucompose.hpp"
+#include "defs.h"
+#include "GameMap.h"
 
 QuestAssignedDialog::QuestAssignedDialog(Hero *h, Quest *q)
 {
@@ -43,6 +43,8 @@ QuestAssignedDialog::QuestAssignedDialog(Hero *h, Quest *q)
     Gtk::Dialog *d = 0;
     xml->get_widget("dialog", d);
     dialog.reset(d);
+    decorate(dialog.get());
+    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
 
     xml->get_widget("map_image", map_image);
 
@@ -53,7 +55,7 @@ QuestAssignedDialog::QuestAssignedDialog(Hero *h, Quest *q)
     Gtk::EventBox *map_eventbox;
     xml->get_widget("map_eventbox", map_eventbox);
 
-    dialog->set_title(String::ucompose(_("Quest for %1"), hero->getName()));
+    set_title(String::ucompose(_("Quest for %1"), hero->getName()));
 
     xml->get_widget("label", label);
     Glib::ustring s;
