@@ -34,6 +34,7 @@
 
 #include "game-preferences-dialog.h"
 #include "load-scenario-dialog.h"
+#include "new-campaign-dialog.h"
 #include "glade-helpers.h"
 #include "Configuration.h"
 #include "defs.h"
@@ -45,6 +46,7 @@
 //#include "netggz.h"
 #include "gtksdl.h"
 #include "main-preferences-dialog.h"
+#include "timed-message-dialog.h"
 
 namespace
 {
@@ -69,7 +71,7 @@ SplashWindow::SplashWindow()
     xml->get_widget("window", w);
     window.reset(w);
     decorate(window.get(), File::getMiscFile("various/back.bmp"));
-    window_closed.connect(sigc::mem_fun(window.get(), &Gtk::Window::hide));
+    window_closed.connect(sigc::mem_fun(this, &SplashWindow::on_window_closed));
 
     xml->get_widget("sdl_container", sdl_container);
     w->signal_delete_event().connect(
@@ -88,6 +90,8 @@ SplashWindow::SplashWindow()
 			 sigc::mem_fun(*this, &SplashWindow::on_new_game_clicked));
     xml->connect_clicked("load_game_button",
 			 sigc::mem_fun(*this, &SplashWindow::on_load_game_clicked));
+    xml->connect_clicked("new_campaign_button",
+			 sigc::mem_fun(*this, &SplashWindow::on_new_campaign_clicked));
     xml->connect_clicked("load_scenario_button",
 			 sigc::mem_fun(*this, &SplashWindow::on_load_scenario_clicked));
     xml->connect_clicked("quit_button",
@@ -151,6 +155,13 @@ void SplashWindow::hide()
     window->hide();
 }
 
+    
+void SplashWindow::on_window_closed()
+{
+  hide();
+  quit_requested.emit();
+}
+
 bool SplashWindow::on_delete_event(GdkEventAny *e)
 {
     quit_requested.emit();
@@ -285,6 +296,27 @@ void SplashWindow::on_load_scenario_clicked()
 	//load_requested.emit(filename);
 }
 
+void SplashWindow::on_new_campaign_clicked()
+{
+    NewCampaignDialog d;
+    
+    d.set_parent_window(*window.get());
+    
+    d.run();
+    d.hide();
+    
+    std::string filename = d.get_campaign_filename();
+    if (!filename.empty())
+      {
+	GamePreferencesDialog gp(filename);
+	gp.set_parent_window(*window.get());
+	gp.game_started.connect(sigc::mem_fun(*this, &SplashWindow::on_game_started));
+    
+	gp.run();
+      } 
+	//load_requested.emit(filename);
+}
+
 void SplashWindow::on_network_game_selected(std::string ip, unsigned short port)
 {
   new_remote_network_game_requested.emit(ip, port, network_game_nickname);
@@ -487,8 +519,14 @@ void SplashWindow::on_pbm_game_created(GameParameters g)
     
 void SplashWindow::on_preferences_clicked()
 {
+  bool saved = Configuration::s_decorated;
   MainPreferencesDialog d;
   d.set_parent_window(*window.get());
   d.run();
   d.hide();
+  if (saved != Configuration::s_decorated)
+    {
+      TimedMessageDialog dialog(*window.get(), _("Please exit the program and restart it for the changes to take effect."), 30);
+      dialog.run();
+    }
 }
