@@ -50,6 +50,8 @@
 #include "signpost.h"
 #include "history.h"
 #include "vectoredunit.h"
+#include "Backpack.h"
+#include "MapBackpack.h"
 
 using namespace std;
 
@@ -59,7 +61,7 @@ using namespace std;
 NetworkPlayer::NetworkPlayer(string name, Uint32 armyset, SDL_Color color, int width,
 		       int height, Player::Type type, int player_no)
     :Player(name, armyset, color, width, height, type, player_no),
-    d_connected(false)
+    d_connected(false), d_abort_requested(false)
 {
 }
 
@@ -67,11 +69,13 @@ NetworkPlayer::NetworkPlayer(const Player& player)
     :Player(player), d_connected(false)
 {
     d_type = Player::NETWORKED;
+    d_abort_requested = false;
 }
 
 NetworkPlayer::NetworkPlayer(XML_Helper* helper)
     :Player(helper), d_connected(false)
 {
+    d_abort_requested = false;
 }
 
 NetworkPlayer::~NetworkPlayer()
@@ -83,13 +87,18 @@ bool NetworkPlayer::save(XML_Helper* helper) const
     // This may seem a bit dumb, but allows derived players (especially
     // AI's) to save additional data, such as character types or so.
     bool retval = true;
-    retval &= helper->openTag("player");
+    retval &= helper->openTag(Player::d_tag);
     retval &= Player::save(helper);
     retval &= helper->closeTag();
 
     return retval;
 }
 
+void NetworkPlayer::abortTurn()
+{
+  d_abort_requested = true;
+}
+
 bool NetworkPlayer::startTurn()
 {
   //d_stacklist->setActivestack(0);
@@ -320,7 +329,6 @@ void NetworkPlayer::decodeActionFight(const Action_Fight *action)
     defenders.push_back(findStackById(*i));
 
   Stack *attack = &*attackers.front();
-  Stack *defend = &*defenders.front();
   Fight fight(attackers, defenders, action->getBattleHistory());
   Fight::Result result = fight.battleFromHistory();
   fight_started.emit(fight);
@@ -487,12 +495,12 @@ void NetworkPlayer::decodeActionEquip(const Action_Equip *action)
   switch (action->getToBackpackOrToGround())
   {
   case Action_Equip::BACKPACK:
-    item = findItemById(GameMap::getInstance()->getTile(action->getItemPos())->getItems(), action->getItemId());
+    item = GameMap::getInstance()->getTile(action->getItemPos())->getBackpack()->getItemById(action->getItemId());
     doHeroPickupItem(hero, item, action->getItemPos());
     break;
 
   case Action_Equip::GROUND:
-    item = findItemById(hero->getBackpack(), action->getItemId());
+    item = hero->getBackpack()->getItemById(action->getItemId());
     doHeroDropItem(hero, item, action->getItemPos());
     break;
   }
@@ -552,7 +560,7 @@ void NetworkPlayer::decodeActionPlant(const Action_Plant *action)
 {
   Stack *stack = d_stacklist->getArmyStackById(action->getHeroId());
   Hero *hero = dynamic_cast<Hero *>(stack->getArmyById(action->getHeroId()));
-  Item *item = findItemById(hero->getBackpack(), action->getItemId());
+  Item *item = hero->getBackpack()->getItemById(action->getItemId());
     
   doHeroPlantStandard(hero, item, stack->getPos());
 }
