@@ -60,12 +60,16 @@
 #include "vectoredunit.h"
 #include "ucompose.hpp"
 #include "armyprodbase.h"
+#include "Triumphs.h"
+#include "Backpack.h"
+#include "MapBackpack.h"
 
 using namespace std;
 
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<flush<<endl;}
 #define debug(x)
 
+std::string Player::d_tag = "player";
 
 // signal
 sigc::signal<void, Player::Type> sendingTurn;
@@ -92,8 +96,6 @@ Player::Player(string name, Uint32 armyset, SDL_Color color, int width,
       d_fight_order.push_back(i);
     }
 
-    memset(d_triumph, 0, sizeof(d_triumph));
-
     for (unsigned int i = 0 ; i < MAX_PLAYERS; i++)
     {
       d_diplomatic_state[i] = AT_PEACE;
@@ -102,6 +104,8 @@ Player::Player(string name, Uint32 armyset, SDL_Color color, int width,
     }
     d_diplomatic_rank = 0;
     d_diplomatic_title = std::string("");
+
+    d_triumphs = new Triumphs();
 }
 
 Player::Player(const Player& player)
@@ -146,6 +150,8 @@ Player::Player(const Player& player)
       }
     d_diplomatic_rank = player.d_diplomatic_rank;
     d_diplomatic_title = player.d_diplomatic_title;
+
+    d_triumphs = new Triumphs(*player.getTriumphs());
 }
 
 Player::Player(XML_Helper* helper)
@@ -222,11 +228,11 @@ Player::Player(XML_Helper* helper)
 	    d_diplomatic_score[i] = val;
     }
 
-    helper->registerTag("action", sigc::mem_fun(this, &Player::load));
-    helper->registerTag("history", sigc::mem_fun(this, &Player::load));
-    helper->registerTag("stacklist", sigc::mem_fun(this, &Player::load));
-    helper->registerTag("fogmap", sigc::mem_fun(this, &Player::load));
-    helper->registerTag("triumphs", sigc::mem_fun(this, &Player::load));
+    helper->registerTag(Action::d_tag, sigc::mem_fun(this, &Player::load));
+    helper->registerTag(History::d_tag, sigc::mem_fun(this, &Player::load));
+    helper->registerTag(Stacklist::d_tag, sigc::mem_fun(this, &Player::load));
+    helper->registerTag(FogMap::d_tag, sigc::mem_fun(this, &Player::load));
+    helper->registerTag(Triumphs::d_tag, sigc::mem_fun(this, &Player::load));
 
 }
 
@@ -448,8 +454,8 @@ void Player::doKill()
     // single cities
     Citylist* cl = Citylist::getInstance();
     for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
-        if ((*it).getOwner() == this && (*it).isBurnt() == false)
-            Playerlist::getInstance()->getNeutral()->takeCityInPossession(&*it);
+        if ((*it)->getOwner() == this && (*it)->isBurnt() == false)
+            Playerlist::getInstance()->getNeutral()->takeCityInPossession(*it);
 
     d_diplomatic_rank = 0;
     d_diplomatic_title = std::string("");
@@ -528,35 +534,7 @@ bool Player::save(XML_Helper* helper) const
 
     retval &= d_stacklist->save(helper);
     retval &= d_fogmap->save(helper);
-
-    //save the triumphs
-	    
-    helper->openTag("triumphs");
-    for (unsigned int i = 0; i < 5; i++)
-      {
-	std::stringstream tally;
-	for (unsigned int j = 0; j < MAX_PLAYERS; j++)
-	    tally << d_triumph[j][i] << " ";
-	switch (TriumphType(i))
-	  {
-	  case TALLY_HERO:
-	    retval &= helper->saveData("hero", tally.str());
-	    break;
-	  case TALLY_NORMAL:
-	    retval &= helper->saveData("normal", tally.str());
-	    break;
-	  case TALLY_SPECIAL:
-	    retval &= helper->saveData("special", tally.str());
-	    break;
-	  case TALLY_SHIP:
-	    retval &= helper->saveData("ship", tally.str());
-	    break;
-	  case TALLY_FLAG:
-	    retval &= helper->saveData("flag", tally.str());
-	    break;
-	  }
-      }
-    helper->closeTag();
+    retval &= d_triumphs->save(helper);
 
     return retval;
 }
@@ -587,58 +565,27 @@ Player* Player::loadPlayer(XML_Helper* helper)
 
 bool Player::load(string tag, XML_Helper* helper)
 {
-    if (tag == "action")
+    if (tag == Action::d_tag)
     {
         Action* action;
         action = Action::handle_load(helper);
         d_actions.push_back(action);
     }
-    if (tag == "history")
+    if (tag == History::d_tag)
     {
         History* history;
         history = History::handle_load(helper);
         d_history.push_back(history);
     }
 
-    if (tag == "stacklist")
+    if (tag == Stacklist::d_tag)
         d_stacklist = new Stacklist(helper);
 
-    if (tag == "fogmap")
+    if (tag == FogMap::d_tag)
         d_fogmap = new FogMap(helper);
 
-    if (tag == "triumphs")
-      {
-	for (unsigned int i = 0; i < 5; i++)
-	  {
-	    std::string tally;
-	    std::stringstream stally;
-	    Uint32 val;
-	    switch (TriumphType(i))
-	      {
-	      case TALLY_HERO:
-		helper->getData(tally, "hero");
-		break;
-	      case TALLY_NORMAL:
-		helper->getData(tally, "normal");
-		break;
-	      case TALLY_SPECIAL:
-		helper->getData(tally, "special");
-		break;
-	      case TALLY_SHIP:
-		helper->getData(tally, "ship");
-		break;
-	      case TALLY_FLAG:
-		helper->getData(tally, "flag");
-		break;
-	      }
-	    stally.str(tally);
-	    for (unsigned int j = 0; j < MAX_PLAYERS; j++)
-	      {
-		stally >> val;
-		d_triumph[j][i] = val;
-	      }
-	  }
-      }
+    if (tag == Triumphs::d_tag)
+	d_triumphs = new Triumphs(helper);
 
     return true;
 }
@@ -687,8 +634,8 @@ void Player::calculateIncome()
     Citylist *cl = Citylist::getInstance();
     for (Citylist::iterator i = cl->begin(), iend = cl->end(); i != iend; ++i)
       {
-	if ((*i).getOwner() == this)
-	  d_income += (*i).getGold();
+	if ((*i)->getOwner() == this)
+	  d_income += (*i)->getGold();
       }
 }
 
@@ -1557,7 +1504,7 @@ void Player::doCityPillage(City *c, int& gold, int* pillaged_army_type)
 
   if (c->getNoOfProductionBases() > 0)
     {
-      int i;
+      unsigned int i;
       unsigned int max_cost = 0;
       int slot = -1;
       for (i = 0; i < c->getNoOfProductionBases(); i++)
@@ -1620,7 +1567,7 @@ void Player::doCitySack(City* c, int& gold, std::list<Uint32> *sacked_types)
   if (c->getNoOfProductionBases() > 1)
     {
       const ArmyProdBase *a;
-      int i, max = 0;
+      unsigned int i, max = 0;
       for (i = 0; i < c->getNoOfProductionBases(); i++)
 	{
 	  a = c->getProductionBase(i);
@@ -1720,7 +1667,7 @@ bool Player::cityBuyProduction(City* c, int slot, int type)
     return false;
 
   // can't put it in that slot
-  if (slot >= c->getMaxNoOfProductionBases())
+  if (slot >= (int)c->getMaxNoOfProductionBases())
     return false;
   
   Action_Buy* item = new Action_Buy();
@@ -1765,8 +1712,8 @@ void Player::doGiveReward(Stack *s, Reward *reward)
         }
       break;
     case Reward::ITEM:
-      static_cast<Hero*>(s->getFirstHero())->addToBackpack(
-      						     dynamic_cast<Reward_Item*>(reward)->getItem());
+      static_cast<Hero*>(s->getFirstHero())->getBackpack()->addToBackpack
+	(dynamic_cast<Reward_Item*>(reward)->getItem());
       break;
     case Reward::RUIN:
         {
@@ -1780,9 +1727,7 @@ void Player::doGiveReward(Stack *s, Reward *reward)
     case Reward::MAP:
         {
           Reward_Map *map = dynamic_cast<Reward_Map*>(reward);
-          d_fogmap->alterFogRectangle(map->getLocation()->getPos(), 
-      				map->getHeight(), map->getWidth(), 
-      				FogMap::OPEN);
+          d_fogmap->alterFog(map->getSightMap());
         }
       break;
     }
@@ -1825,8 +1770,8 @@ bool Player::stackDisband(Stack* s)
 
 void Player::doHeroDropItem(Hero *h, Item *i, Vector<int> pos)
 {
-  GameMap::getInstance()->getTile(pos)->addItem(i);
-  h->removeFromBackpack(i);
+  GameMap::getInstance()->getTile(pos)->getBackpack()->addToBackpack(i);
+  h->getBackpack()->removeFromBackpack(i);
 }
 
 bool Player::heroDropItem(Hero *h, Item *i, Vector<int> pos)
@@ -1842,26 +1787,23 @@ bool Player::heroDropItem(Hero *h, Item *i, Vector<int> pos)
 
 bool Player::heroDropAllItems(Hero *h, Vector<int> pos)
 {
-  std::list<Item*> backpack = h->getBackpack();
-  for (std::list<Item*>::iterator i = backpack.begin(), end = backpack.end();
-       i != end; ++i)
-    heroDropItem(h, *i, pos);
+  while (h->getBackpack()->empty() == false)
+    heroDropItem(h, h->getBackpack()->front(), pos);
   return true;
 }
 
 bool Player::doHeroDropAllItems(Hero *h, Vector<int> pos)
 {
-  std::list<Item*> backpack = h->getBackpack();
-  for (std::list<Item*>::iterator i = backpack.begin(), end = backpack.end();
-       i != end; ++i)
-    doHeroDropItem(h, *i, pos);
+  while (h->getBackpack()->empty() == false)
+    doHeroDropItem(h, h->getBackpack()->front(), pos);
   return true;
 }
+
 void Player::doHeroPickupItem(Hero *h, Item *i, Vector<int> pos)
 {
-  bool found = GameMap::getInstance()->getTile(pos)->removeItem(i);
+  bool found = GameMap::getInstance()->getTile(pos)->getBackpack()->removeFromBackpack(i);
   if (found)
-    h->addToBackpack(i);
+    h->getBackpack()->addToBackpack(i);
 }
 
 bool Player::heroPickupItem(Hero *h, Item *i, Vector<int> pos)
@@ -1877,10 +1819,9 @@ bool Player::heroPickupItem(Hero *h, Item *i, Vector<int> pos)
 
 bool Player::heroPickupAllItems(Hero *h, Vector<int> pos)
 {
-  std::list<Item*> bag = GameMap::getInstance()->getTile(pos)->getItems();
-  for (std::list<Item*>::iterator i = bag.begin(), end = bag.end();
-       i != end; ++i)
-    heroPickupItem(h, *i, pos);
+  MapBackpack *backpack = GameMap::getInstance()->getTile(pos)->getBackpack();
+  while (backpack->empty() == false)
+    heroPickupItem(h, backpack->front(), pos);
   return true;
 }
 
@@ -1902,11 +1843,11 @@ void Player::doResign()
   Citylist *cl = Citylist::getInstance();
   for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
     {
-      if ((*it).getOwner() == this)
+      if ((*it)->getOwner() == this)
 	{
-	  (*it).setBurnt(true);
+	  (*it)->setBurnt(true);
 	  History_CityRazed* history = new History_CityRazed();
-	  history->fillData(&(*it));
+	  history->fillData((*it));
 	  addHistory(history);
 	}
     }
@@ -2012,21 +1953,17 @@ bool Player::heroPlantStandard(Stack* s)
     if ((*it)->isHero())
     {
       Hero *hero = dynamic_cast<Hero*>((*it));
-      std::list<Item*> backpack = hero->getBackpack();
-      for (std::list<Item*>::iterator i = backpack.begin(), 
-             end = backpack.end(); i != end; ++i)
-      {
-        if ((*i)->isPlantable() && (*i)->getPlantableOwner() == this)
+      Item *item = hero->getBackpack()->getPlantableItem(this);
+      if (item)
         {
           //drop the item, and plant it
-          doHeroPlantStandard(hero, *i, s->getPos());
+          doHeroPlantStandard(hero, item, s->getPos());
                   
-          Action_Plant * item = new Action_Plant();
-          item->fillData(hero, *i);
-          addAction(item);
+          Action_Plant * i = new Action_Plant();
+          i->fillData(hero, item);
+          addAction(i);
           return true;
         }
-      }
     }
   }
   return true;
@@ -2036,8 +1973,8 @@ void Player::doHeroPlantStandard(Hero *hero, Item *item, Vector<int> pos)
 {
   item->setPlanted(true);
   GameMap *gm = GameMap::getInstance();
-  gm->getTile(pos)->addItem(item);
-  hero->removeFromBackpack(item);
+  gm->getTile(pos)->getBackpack()->addToBackpack(item);
+  hero->getBackpack()->removeFromBackpack(item);
 }
 
 void Player::getHeroes(const std::list<Stack*> stacks, std::vector<Uint32>& dst)
@@ -2074,95 +2011,97 @@ double Player::removeDeadArmies(std::list<Stack*>& stacks,
             {
 		//Tally up the triumphs
 		if ((*sit)->getAwardable()) //hey a special died
-		  tallyTriumph((*sit)->getOwner(), TALLY_SPECIAL);
+		  d_triumphs->tallyTriumph((*sit)->getOwner(), 
+					   Triumphs::TALLY_SPECIAL);
 		else if ((*sit)->isHero() == false)
-		  tallyTriumph((*sit)->getOwner(), TALLY_NORMAL);
+		  d_triumphs->tallyTriumph((*sit)->getOwner(), 
+					   Triumphs::TALLY_NORMAL);
 		if ((*sit)->getStat(Army::SHIP, false)) //hey it was on a boat
-		  tallyTriumph((*sit)->getOwner(), TALLY_SHIP);
+		  d_triumphs->tallyTriumph((*sit)->getOwner(), 
+					   Triumphs::TALLY_SHIP);
                 debug("Army: " << (*sit)->getName())
                 debug("Army: " << (*sit)->getXpReward())
                 if ((*sit)->isHero())
                 {
-		  tallyTriumph((*sit)->getOwner(), TALLY_HERO);
+		  d_triumphs->tallyTriumph((*sit)->getOwner(), 
+					   Triumphs::TALLY_HERO);
 		  Hero *hero = dynamic_cast<Hero*>((*sit));
-		  std::list<Item*> backpack = hero->getBackpack();
-		  for (std::list<Item*>::iterator i = backpack.begin(), 
-		       end = backpack.end(); i != end; ++i)
+		  Uint32 count = hero->getBackpack()->countPlantableItems();
+		  for (Uint32 i = 0; i < count; i++)
+		    d_triumphs->tallyTriumph((*sit)->getOwner(), 
+					     Triumphs::TALLY_FLAG);
+
+		  //one of our heroes died
+		  //drop hero's stuff
+		  Hero *h = static_cast<Hero *>(*sit);
+		  //now record the details of the death
+		  GameMap *gm = GameMap::getInstance();
+		  Maptile *tile = gm->getTile((*it)->getPos());
+		  if (tile->getBuilding() == Maptile::RUIN)
 		    {
-		      if ((*i)->isPlantable())
-			tallyTriumph((*sit)->getOwner(), TALLY_FLAG);
+		      History_HeroKilledSearching* item;
+		      item = new History_HeroKilledSearching();
+		      item->fillData(h);
+		      h->getOwner()->addHistory(item);
+		      doHeroDropAllItems (h, (*it)->getPos());
 		    }
-                    //one of our heroes died
-                    //drop hero's stuff
-                    Hero *h = static_cast<Hero *>(*sit);
-                    //now record the details of the death
-                    GameMap *gm = GameMap::getInstance();
-                    Maptile *tile = gm->getTile((*it)->getPos());
-                    if (tile->getBuilding() == Maptile::RUIN)
-                    {
-                        History_HeroKilledSearching* item;
-                        item = new History_HeroKilledSearching();
-                        item->fillData(h);
-			h->getOwner()->addHistory(item);
-                        doHeroDropAllItems (h, (*it)->getPos());
-                    }
-                    else if (tile->getBuilding() == Maptile::CITY)
-                    {
-		        Citylist *clist = Citylist::getInstance();
-                        City* c = clist->getObjectAt((*it)->getPos());
-                        History_HeroKilledInCity* item;
-                        item = new History_HeroKilledInCity();
-                        item->fillData(h, c);
-			h->getOwner()->addHistory(item);
-                        doHeroDropAllItems (h, (*it)->getPos());
-                    }
-                    else //somewhere else
-                    {
-                        History_HeroKilledInBattle* item;
-                        item = new History_HeroKilledInBattle();
-                        item->fillData(h);
-			h->getOwner()->addHistory(item);
-                        doHeroDropAllItems (h, (*it)->getPos());
-                    }
-                }
-                //Add the XP bonus to the total of the battle;
-                total+=(*sit)->getXpReward();
+		  else if (tile->getBuilding() == Maptile::CITY)
+		    {
+		      Citylist *clist = Citylist::getInstance();
+		      City* c = clist->getObjectAt((*it)->getPos());
+		      History_HeroKilledInCity* item;
+		      item = new History_HeroKilledInCity();
+		      item->fillData(h, c);
+		      h->getOwner()->addHistory(item);
+		      doHeroDropAllItems (h, (*it)->getPos());
+		    }
+		  else //somewhere else
+		    {
+		      History_HeroKilledInBattle* item;
+		      item = new History_HeroKilledInBattle();
+		      item->fillData(h);
+		      h->getOwner()->addHistory(item);
+		      doHeroDropAllItems (h, (*it)->getPos());
+		    }
+		}
+		//Add the XP bonus to the total of the battle;
+		total+=(*sit)->getXpReward();
 		//tell the quest manager that someone died
 		//(maybe it was a hero, or a target that's an army)
 		QuestsManager::getInstance()->armyDied(*sit, culprits);
-                // here we destroy the army, so we send
-                // the signal containing the fight data
-                debug("sending sdyingArmy!")
-                sdyingArmy.emit(*sit, culprits);
-                sit = (*it)->flErase(sit);
-                continue;
-            }
+		// here we destroy the army, so we send
+		// the signal containing the fight data
+		debug("sending sdyingArmy!")
+		  sdyingArmy.emit(*sit, culprits);
+		sit = (*it)->flErase(sit);
+		continue;
+	    }
 
-            // heal this army to full hitpoints
-            (*sit)->heal((*sit)->getStat(Army::HP));
+	    // heal this army to full hitpoints
+	    (*sit)->heal((*sit)->getStat(Army::HP));
 
-            sit++;
-        }
-        
-        debug("Is stack empty?")
-            
-        if ((*it)->empty())
-        {
-            if (owner)
-            {
-                debug("Removing this stack from the owner's stacklist");
-                bool found = owner->deleteStack(*it);
-		assert (found == true);
-            }
-            else // there is no owner - like for the ruin's occupants
-                debug("No owner for this stack - do stacklist too");
+	    sit++;
+	}
 
-            debug("Removing from the vector too (the vector had "
-                  << stacks.size() << " elt)");
-            it = stacks.erase(it);
-        }
-        else
-            it++;
+	debug("Is stack empty?")
+
+	  if ((*it)->empty())
+	    {
+	      if (owner)
+		{
+		  debug("Removing this stack from the owner's stacklist");
+		  bool found = owner->deleteStack(*it);
+		  assert (found == true);
+		}
+	      else // there is no owner - like for the ruin's occupants
+		debug("No owner for this stack - do stacklist too");
+
+	      debug("Removing from the vector too (the vector had "
+		    << stacks.size() << " elt)");
+	      it = stacks.erase(it);
+	    }
+	  else
+	    it++;
     }
     debug("after removeDead: size = " << stacks.size());
     return total;
@@ -2180,130 +2119,114 @@ void Player::updateArmyValues(std::list<Stack*>& stacks, double xp_sum)
   double numberarmy = 0;
 
   for (it = stacks.begin(); it != stacks.end(); it++)
-      numberarmy += (*it)->size();
+    numberarmy += (*it)->size();
 
   for (it = stacks.begin(); it != stacks.end(); )
     {
       debug("Stack: " << (*it))
 
-      for (Stack::iterator sit = (*it)->begin(); sit != (*it)->end();)
-        {
-          Army *army = *sit;
-          debug("Army: " << army)
+	for (Stack::iterator sit = (*it)->begin(); sit != (*it)->end();)
+	  {
+	    Army *army = *sit;
+	    debug("Army: " << army)
 
-          // here we adds XP
-          army->gainXp((double)((xp_sum)/numberarmy));
-          debug("Army gets " << (double)((xp_sum)/numberarmy) << " XP")
+	      // here we adds XP
+	      army->gainXp((double)((xp_sum)/numberarmy));
+	    debug("Army gets " << (double)((xp_sum)/numberarmy) << " XP")
 
-          // here we adds 1 to number of battles
-          army->setBattlesNumber(army->getBattlesNumber()+1);
-          debug("Army battles " <<  army->getBattlesNumber())
+	      // here we adds 1 to number of battles
+	      army->setBattlesNumber(army->getBattlesNumber()+1);
+	    debug("Army battles " <<  army->getBattlesNumber())
 
-          // medals only go to non-ally armies.
-          if ((*it)->hasHero() && army->isHero() == false && 
-              army->getAwardable() == false)
-            {
-              if((army->getBattlesNumber())>10 && 
-                 !(army->getMedalBonus(2)))
-                {
-                  army->setMedalBonus(2,true);
-                  // We must recalculate the XPValue of this unit since it 
-                  // got a medal
-                  army->setXpReward(army->getXpReward()+1);
-                  // We get the medal bonus here
-                  army->setStat(Army::STRENGTH, army->getStat(Army::STRENGTH, false)+1);
-                  // Emit signal
-                  snewMedalArmy.emit(army);
-                }
+	      // medals only go to non-ally armies.
+	      if ((*it)->hasHero() && army->isHero() == false && 
+		  army->getAwardable() == false)
+		{
+		  if((army->getBattlesNumber())>10 && 
+		     !(army->getMedalBonus(2)))
+		    {
+		      army->setMedalBonus(2,true);
+		      // We must recalculate the XPValue of this unit since it 
+		      // got a medal
+		      army->setXpReward(army->getXpReward()+1);
+		      // We get the medal bonus here
+		      army->setStat(Army::STRENGTH, army->getStat(Army::STRENGTH, false)+1);
+		      // Emit signal
+		      snewMedalArmy.emit(army);
+		    }
 
-              debug("Army hits " <<  army->getNumberHasHit())
+		  debug("Army hits " <<  army->getNumberHasHit())
 
-              // Only give medals if the unit has attacked often enough, else
-              // medals lose the flair of something special; a value of n 
-              // means roughly to hit an equally strong unit around n 
-              // times. (note: one hit! An attack can consist of up to 
-              // strength hits)
-              if((army->getNumberHasHit()>50) && !army->getMedalBonus(0))
-                {
-                  army->setMedalBonus(0,true);
-                  // We must recalculate the XPValue of this unit since it
-                  // got a medal
-                  army->setXpReward(army->getXpReward()+1);
-                  // We get the medal bonus here
-                  army->setStat(Army::STRENGTH, army->getStat(Army::STRENGTH, false)+1);
-                  // Emit signal
-                  snewMedalArmy.emit(army);
-                }
+		    // Only give medals if the unit has attacked often enough, else
+		    // medals lose the flair of something special; a value of n 
+		    // means roughly to hit an equally strong unit around n 
+		    // times. (note: one hit! An attack can consist of up to 
+		    // strength hits)
+		    if((army->getNumberHasHit()>50) && !army->getMedalBonus(0))
+		      {
+			army->setMedalBonus(0,true);
+			// We must recalculate the XPValue of this unit since it
+			// got a medal
+			army->setXpReward(army->getXpReward()+1);
+			// We get the medal bonus here
+			army->setStat(Army::STRENGTH, army->getStat(Army::STRENGTH, false)+1);
+			// Emit signal
+			snewMedalArmy.emit(army);
+		      }
 
-              debug("army being hit " <<  army->getNumberHasBeenHit())
+		  debug("army being hit " <<  army->getNumberHasBeenHit())
 
-              // Gives the medal for good defense. The more negative the 
-              // number the more blows the unit evaded. n means roughly 
-              // avoid n hits from an equally strong unit. Since we want 
-              // to punish the case of the unit hiding among many others, 
-              // we set this value quite high.
-              if((army->getNumberHasBeenHit() < -100) && !army->getMedalBonus(1))
-                {
-                  army->setMedalBonus(1,true);
-                  // We must recalculate the XPValue of this unit since it 
-                  // got a medal
-                  army->setXpReward(army->getXpReward()+1);
-                  // We get the medal bonus here
-                  army->setStat(Army::STRENGTH, army->getStat(Army::STRENGTH, false)+1);
-                  // Emit signal
-                  snewMedalArmy.emit(army);
-                }
-              debug("Army hits " <<  army->getNumberHasHit())
+		    // Gives the medal for good defense. The more negative the 
+		    // number the more blows the unit evaded. n means roughly 
+		    // avoid n hits from an equally strong unit. Since we want 
+		    // to punish the case of the unit hiding among many others, 
+		    // we set this value quite high.
+		    if((army->getNumberHasBeenHit() < -100) && !army->getMedalBonus(1))
+		      {
+			army->setMedalBonus(1,true);
+			// We must recalculate the XPValue of this unit since it 
+			// got a medal
+			army->setXpReward(army->getXpReward()+1);
+			// We get the medal bonus here
+			army->setStat(Army::STRENGTH, army->getStat(Army::STRENGTH, false)+1);
+			// Emit signal
+			snewMedalArmy.emit(army);
+		      }
+		  debug("Army hits " <<  army->getNumberHasHit())
 
-              for(int i=0;i<3;i++)
-                {
-                  debug("MEDAL[" << i << "]==" << army->getMedalBonus(i))
-                }
-            }
+		    for(int i=0;i<3;i++)
+		      {
+			debug("MEDAL[" << i << "]==" << army->getMedalBonus(i))
+		      }
+		}
 
-            // We reset the hit values after the battle
-            army->setNumberHasHit(0);
-            army->setNumberHasBeenHit(0);
+	    // We reset the hit values after the battle
+	    army->setNumberHasHit(0);
+	    army->setNumberHasBeenHit(0);
 
-            if (army->isHero() && getType() != Player::NETWORKED)
-              {
-                while(army->canGainLevel())
-                  {
-                    // Units not associated to a player never raise levels.
-                    if (army->getOwner() == 
-                        Playerlist::getInstance()->getNeutral())
-                      break;
+	    if (army->isHero() && getType() != Player::NETWORKED)
+	      {
+		while(army->canGainLevel())
+		  {
+		    // Units not associated to a player never raise levels.
+		    if (army->getOwner() == 
+			Playerlist::getInstance()->getNeutral())
+		      break;
 
-                    //Here this for is to check if army must raise 2 or more 
-                    //levels per time depending on the XP and level itself
+		    //Here this for is to check if army must raise 2 or more 
+		    //levels per time depending on the XP and level itself
 
-                    debug("ADVANCING LEVEL "<< "CANGAINLEVEL== " << army->canGainLevel());
+		    debug("ADVANCING LEVEL "<< "CANGAINLEVEL== " << army->canGainLevel());
 		    army->getOwner()->levelArmy(army);
-                  }
-                debug("Army new XP=" << army->getXP())
-              }
-            sit++;
-          }
-        it++;
+		  }
+		debug("Army new XP=" << army->getXP())
+	      }
+	    sit++;
+	  }
+      it++;
     }
 }
 
-void Player::tallyTriumph(Player *p, TriumphType type)
-{
-  //ignore monsters in a ruin who aren't owned by a player
-  if (!p) 
-    return;
-  Uint32 id = p->getId();
-  //let's not tally fratricide
-  if (p == this) 
-    return;
-  //let's not tally neutrals
-  if (p == Playerlist::getInstance()->getNeutral()) 
-    return;
-  //we (this player) have killed P's army. it was of type TYPE.
-  d_triumph[id][type]++;
-}
-
 Hero* Player::doRecruitHero(HeroProto* herotemplate, City *city, int cost, int alliesCount, const ArmyProto *ally)
 {
   Hero *newhero = new Hero(*herotemplate);
@@ -2311,19 +2234,19 @@ Hero* Player::doRecruitHero(HeroProto* herotemplate, City *city, int cost, int a
   GameMap::getInstance()->addArmy(city, newhero);
 
   if (alliesCount > 0)
-  {
-    Reward_Allies::addAllies(this, city->getPos(), ally, alliesCount);
-    hero_arrives_with_allies.emit(alliesCount);
-  }
-  
+    {
+      Reward_Allies::addAllies(this, city->getPos(), ally, alliesCount);
+      hero_arrives_with_allies.emit(alliesCount);
+    }
+
   if (cost == 0)
-  {
-    // Initially give the first hero the player's standard.
-    std::string name = String::ucompose(_("%1 Standard"), getName());
-    Item *battle_standard = new Item (name, true, this);
-    battle_standard->addBonus(Item::ADD1STACK);
-    newhero->addToBackpack(battle_standard, 0);
-  }
+    {
+      // Initially give the first hero the player's standard.
+      std::string name = String::ucompose(_("%1 Standard"), getName());
+      Item *battle_standard = new Item (name, true, this);
+      battle_standard->addBonus(Item::ADD1STACK);
+      newhero->getBackpack()->addToBackpack(battle_standard, 0);
+    }
   withdrawGold(cost);
   supdatingStack.emit(0);
   return newhero;
@@ -2338,7 +2261,7 @@ void Player::recruitHero(HeroProto* heroproto, City *city, int cost, int alliesC
   item->fillData(heroproto, city);
   addHistory(item);
 
-  Hero *hero = doRecruitHero(heroproto, city, cost, alliesCount, ally);
+  doRecruitHero(heroproto, city, cost, alliesCount, ally);
 }
 
 void Player::doDeclareDiplomacy (DiplomaticState state, Player *player)
@@ -2356,7 +2279,7 @@ void Player::doDeclareDiplomacy (DiplomaticState state, Player *player)
 void Player::declareDiplomacy (DiplomaticState state, Player *player)
 {
   doDeclareDiplomacy(state, player);
-  
+
   Action_DiplomacyState * item = new Action_DiplomacyState();
   item->fillData(player, state);
   addAction(item);
@@ -2448,7 +2371,7 @@ Player::DiplomaticState Player::negotiateDiplomacy (Player *player)
     }
 
 }
-	
+
 Player::DiplomaticState Player::getDiplomaticState (Player *player)
 {
   if (player == Playerlist::getInstance()->getNeutral())
@@ -2457,7 +2380,7 @@ Player::DiplomaticState Player::getDiplomaticState (Player *player)
     return AT_PEACE;
   return d_diplomatic_state[player->getId()];
 }
-	
+
 Player::DiplomaticProposal Player::getDiplomaticProposal (Player *player)
 {
   if (player == Playerlist::getInstance()->getNeutral())
@@ -2498,9 +2421,9 @@ void Player::improveDiplomaticRelationship (Player *player, Uint32 amount)
   Playerlist *pl = Playerlist::getInstance();
   if (pl->getNeutral() == player || player == this)
     return;
-  
+
   alterDiplomaticRelationshipScore (player, amount);
-  
+
   Action_DiplomacyScore* item = new Action_DiplomacyScore();
   item->fillData(player, amount);
   addAction(item);
@@ -2511,9 +2434,9 @@ void Player::deteriorateDiplomaticRelationship (Player *player, Uint32 amount)
   Playerlist *pl = Playerlist::getInstance();
   if (pl->getNeutral() == player || player == this)
     return;
-  
+
   alterDiplomaticRelationshipScore (player, -amount);
-  
+
   Action_DiplomacyScore* item = new Action_DiplomacyScore();
   item->fillData(player, -amount);
   addAction(item);
@@ -2550,7 +2473,7 @@ void Player::improveDiplomaticRelationship (Uint32 amount, Player *except)
       (*it)->improveDiplomaticRelationship (this, amount);
     }
 }
-		  
+
 void Player::deteriorateAlliesRelationship(Player *player, Uint32 amount,
 					   Player::DiplomaticState state)
 {
@@ -2590,17 +2513,17 @@ void Player::AI_maybeBuyScout()
   bool hero_exists = false;
   for (Stacklist::iterator it = d_stacklist->begin(); 
        it != d_stacklist->end(); it++)
-    
+
     if ((*it)->hasHero())
       hero_exists = true; 
-    
+
   if (Citylist::getInstance()->countCities(this) == 1 && 
-	hero_exists == false)
+      hero_exists == false)
     {
       bool one_turn_army_exists = false;
       City *c = Citylist::getInstance()->getFirstCity(this);
       //do we already have something that can be produced in one turn?
-      for (int i = 0; i < c->getMaxNoOfProductionBases(); i++)
+      for (unsigned int i = 0; i < c->getMaxNoOfProductionBases(); i++)
 	{
 	  if (c->getArmytype(i) == -1)    // no production in this slot
 	    continue;
@@ -2659,7 +2582,7 @@ bool Player::AI_maybePickUpItems(Stack *s, int max_dist, int max_mp,
   //if no bags of stuff, or the bag is too far away
   if (min_dist == -1 || min_dist > max_dist)
     return false;
-  
+
   //are we not standing on it?
   if (s->getPos() != item_tile)
     {
@@ -2723,7 +2646,7 @@ bool Player::AI_maybeVisitTempleForBlessing(Stack *s, int dist, int max_mp,
 	  return false;
 	}
       stack_moved = stackMove(s);
-        
+
       //maybe we died -- an enemy stack was guarding the temple
       if (!d_stacklist->getActivestack())
 	{
@@ -2780,7 +2703,7 @@ bool Player::AI_maybeDisband(Stack *s, City *city, Uint32 min_defenders,
 
   if (city->countDefenders() - s->size() >= min_defenders)
     {
-    return stackDisband(s);
+      return stackDisband(s);
     }
 
   //okay, we need to disband part of our stack
@@ -2913,11 +2836,11 @@ void Player::AI_setupVectoring(Uint32 safe_mp, Uint32 min_defenders,
   //turn off vectoring for destinations that are far away from the
   //nearest enemy city
 
-	  
+
   debug("setting up vectoring\n");
   for (Citylist::iterator cit = cl->begin(); cit != cl->end(); ++cit)
     {
-      City *c = &*cit;
+      City *c = *cit;
       if (c->getOwner() != this || c->isBurnt())
 	continue;
       Vector<int> dest = c->getVectoring();
@@ -2925,18 +2848,18 @@ void Player::AI_setupVectoring(Uint32 safe_mp, Uint32 min_defenders,
 	continue;
       if (safeFromAttack(c, safe_mp, min_defenders) == false)
 	{
-	  City *target_city = Citylist::getInstance()->getObjectAt(dest);
-	  debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because it's not safe to anymore!\n")
-	    c->setVectoring(Vector<int>(-1,-1));
+	  //City *target_city = Citylist::getInstance()->getObjectAt(dest);
+	  //debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because it's not safe to anymore!\n")
+	  c->setVectoring(Vector<int>(-1,-1));
 	  continue;
 	}
 
       City *enemy_city = cl->getNearestEnemyCity(dest);
       if (!enemy_city)
 	{
-	  City *target_city = Citylist::getInstance()->getObjectAt(dest);
-	  debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because there aren't any more enemy cities!\n")
-	    c->setVectoring(Vector<int>(-1,-1));
+	  //City *target_city = Citylist::getInstance()->getObjectAt(dest);
+	  //debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because there aren't any more enemy cities!\n")
+	  c->setVectoring(Vector<int>(-1,-1));
 	  continue;
 	}
 
@@ -2944,16 +2867,16 @@ void Player::AI_setupVectoring(Uint32 safe_mp, Uint32 min_defenders,
       if ((int)mp <= 0 || mp > mp_to_front)
 	{
 
-	  City *target_city = Citylist::getInstance()->getObjectAt(dest);
-	  debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because it's too far away from an enemy city!\n")
-	    c->setVectoring(Vector<int>(-1,-1));
+	  //City *target_city = Citylist::getInstance()->getObjectAt(dest);
+	  //debug("stopping vectoring from " << c->getName() <<" to " << target_city->getName() << " because it's too far away from an enemy city!\n")
+	  c->setVectoring(Vector<int>(-1,-1));
 	  continue;
 	}
     }
 
   for (Citylist::iterator cit = cl->begin(); cit != cl->end(); ++cit)
     {
-      City *c = &*cit;
+      City *c = *cit;
       if (c->getOwner() != this || c->isBurnt())
 	continue;
       City *enemy_city = cl->getNearestEnemyCity(c->getPos());
@@ -2980,15 +2903,19 @@ bool Player::cityProducesArmy(City *city)
 {
   Action_Produce *item = new Action_Produce();
   const Army *army = doCityProducesArmy(city);
-  const ArmyProdBase *source_army = city->getActiveProductionBase();
-  if (city->getVectoring() == Vector<int>(-1, -1))
-    item->fillData(source_army, city, false);
-  else
-    item->fillData(source_army, city, true);
-  addAction(item);
+  if (army)
+    {
+      const ArmyProdBase *source_army;
+      source_army = city->getProductionBaseBelongingTo(army);
+      if (city->getVectoring() == Vector<int>(-1, -1))
+	item->fillData(source_army, city, false);
+      else
+	item->fillData(source_army, city, true);
+      addAction(item);
+    }
   return true;
 }
-	
+
 Army* Player::doVectoredUnitArrives(VectoredUnit *unit)
 {
   Army *army = unit->armyArrives();
@@ -3003,8 +2930,8 @@ bool Player::vectoredUnitArrives(VectoredUnit *unit)
   Army *army = doVectoredUnitArrives(unit);
   if (!army)
     {
-    printf("whooops... this vectored unit failed to show up.\n");
-    exit (1);
+      printf("whooops... this vectored unit failed to show up.\n");
+      exit (1);
     }
 
   return true;
@@ -3050,7 +2977,7 @@ void Player::pruneActionlist(std::list<Action*> actions)
       if ((*ait)->getType() != Action::CITY_PROD)
 	continue;
       //if this city isn't already in the keepers list, then add it.
-  
+
       Action_Production *action = static_cast<Action_Production*>(*ait);
       bool found = false;
       std::list<Action_Production*>::const_iterator it;
@@ -3083,7 +3010,7 @@ void Player::pruneActionlist(std::list<Action*> actions)
 	}
     }
   //if (total)
-    //printf ("pruned %d city production actions.\n", total);
+  //printf ("pruned %d city production actions.\n", total);
 
 }
 
@@ -3124,20 +3051,20 @@ Player::Type Player::playerTypeFromString(const std::string str)
 
 bool Player::hasAlreadyInitializedTurn() const
 {
-    for (list<Action*>::const_iterator it = d_actions.begin();
-        it != d_actions.end(); it++)
-      if ((*it)->getType() == Action::INIT_TURN)
-	return true;
-    return false;
+  for (list<Action*>::const_iterator it = d_actions.begin();
+       it != d_actions.end(); it++)
+    if ((*it)->getType() == Action::INIT_TURN)
+      return true;
+  return false;
 }
 
 bool Player::hasAlreadyEndedTurn() const
 {
-    for (list<Action*>::const_iterator it = d_actions.begin();
-        it != d_actions.end(); it++)
-      if ((*it)->getType() == Action::END_TURN)
-	return true;
-    return false;
+  for (list<Action*>::const_iterator it = d_actions.begin();
+       it != d_actions.end(); it++)
+    if ((*it)->getType() == Action::END_TURN)
+      return true;
+  return false;
 }
 
 std::list<History*> Player::getHistoryForThisTurn() const
