@@ -35,8 +35,7 @@
 #include "vector.h"
 #include "fight.h"
 #include "army.h"
-#include "armyproto.h"
-#include "reward.h"
+#include "defs.h"
 
 class Stacklist;
 class XML_Helper;
@@ -57,6 +56,9 @@ class Fight;
 class Reward;
 class Signpost;
 class VectoredUnit;
+class ArmyProto;
+class Item;
+class Triumphs;
 
 //! The abstract player class.
 /** 
@@ -114,6 +116,9 @@ class VectoredUnit;
 class Player: public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         //! The available player types.
         enum Type {
 	  //! Local human player.  See the RealPlayer class.
@@ -152,20 +157,6 @@ class Player: public sigc::trackable
 	  PROPOSE_WAR = 3 
 	};
 
-	//! Every player keeps a tally of frags.
-        enum TriumphType {
-	  //! Kills we've made of an opponent's Hero army units.
-	  TALLY_HERO = 0, 
-	  //! Kills we've made of an opponent's awardable Army units.
-	  TALLY_SPECIAL = 1, 
-	  //! Kills we've made of an opponents other Army units.
-	  TALLY_NORMAL = 2, 
-	  //! Kills we've made of an opponent's Army units on the water.
-	  TALLY_SHIP = 3, 
-	  //! Kills we've made of opponent's Heroes who carry a standard Item.
-	  TALLY_FLAG = 4
-	};
-
         /** 
 	 * Make a new player.  
 	 * @note AI_Fast, AI_Dummy, AI_Smart and RealPlayer use this 
@@ -420,20 +411,6 @@ class Player: public sigc::trackable
 	//! Returns the player's current score.
         Uint32 getScore();
 
-	/**
-	 * The player's triumphs are tallied as opponent's armies die.
-	 * This method gets a tally for certain kind of triumph.  
-	 * See TriumphsDialog for a caller of this method.
-	 *
-	 * @param player      The player to obtain a tally for.
-	 * @param type        The kind of kills to tally (Player::TriumphType).
-	 *
-	 * @return Zero or more number of armies killed.
-	 */
-	//! Returns a number of armies killed.
-	Uint32 getTriumphTally(Player *player, TriumphType type) const
-	  {return d_triumph[player->getId()][type];}
-
         //! Returns the list of stacks (Stacklist) owned by the player.
         Stacklist* getStacklist() const {return d_stacklist;}
 
@@ -443,6 +420,9 @@ class Player: public sigc::trackable
         //! Get the FogMap of the player.
         FogMap* getFogMap() const {return d_fogmap;}
 
+        //! Get the Triumphs of the player.
+        Triumphs* getTriumphs() const {return d_triumphs;}
+
         //! Get the fight order of the player.
 	std::list<Uint32> getFightOrder() const {return d_fight_order;}
 
@@ -499,6 +479,8 @@ class Player: public sigc::trackable
 	//! Callback to start a Player's turn.
         virtual bool startTurn() = 0;
 
+        virtual void abortTurn() = 0;
+
         /** 
 	 * This function is called before a player's turn starts.
          * The idea here is that it happens before heroes are recruited,
@@ -1288,6 +1270,9 @@ class Player: public sigc::trackable
         //! Player would like to end the turn.
         sigc::signal<void> ending_turn;
 
+        //! Player has confirmed to abort the turn.
+        sigc::signal<void> aborted_turn;
+
         sigc::signal<void, int> hero_arrives_with_allies;
 
         sigc::signal<void, NetworkAction *> acting;
@@ -1349,16 +1334,15 @@ class Player: public sigc::trackable
 	//! What the player can see on the hidden map.
         FogMap* d_fogmap;
 
+	//! A tally of the kills that this player has made
+        Triumphs* d_triumphs;
+
 	//! The order in which this Player's army types fight in battle.
 	/**
 	 * @note This value is related to the Player's ArmySet.
 	 */
 	std::list<Uint32> d_fight_order; 
 
-	//! A set of statistics for this Player.
-	// 5 is max TriumphType + 1
-	Uint32 d_triumph[MAX_PLAYERS][5]; 
-
 	//! How many gold pieces the Player paid out in the last turn.
 	Uint32 d_upkeep;
 
@@ -1516,7 +1500,6 @@ class Player: public sigc::trackable
         // return how much gold we got out
         int lootCity(City *city);
         void takeCityInPossession(City* c);
-	void tallyTriumph(Player *p, TriumphType type);
 };
 
 extern sigc::signal<void, Player::Type>  sendingTurn;
