@@ -20,6 +20,7 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
 //  02110-1301, USA.
 
+#include "config.h"
 #include <sstream>
 #include <algorithm>
 #include <sigc++/functors/mem_fun.h>
@@ -30,7 +31,6 @@
 #include "citylist.h"
 #include "ruinlist.h"
 #include "stacklist.h"
-#include "defs.h"
 #include "xmlhelper.h"
 #include "history.h"
 #include "citylist.h"
@@ -39,6 +39,7 @@
 #include "real_player.h"
 #include "ai_smart.h"
 #include "ai_fast.h"
+#include "ai_dummy.h"
 #include "network_player.h"
 #include "GameMap.h"
 
@@ -47,6 +48,7 @@ using namespace std;
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
+std::string Playerlist::d_tag = "playerlist";
 Playerlist* Playerlist::s_instance = 0;
 Player* Playerlist::d_activeplayer = 0;
 bool Playerlist::s_finish = false;
@@ -92,10 +94,10 @@ Playerlist::Playerlist(XML_Helper* helper)
     //load data. This consists currently of two values: size (for checking
     //the size; we don't use it yet) and active(which player is active)
     //we do it by calling load with playerlist as string
-    load("playerlist", helper);
+    load(Playerlist::d_tag, helper);
     s_finish = false;
 
-    helper->registerTag("player", sigc::mem_fun(this, &Playerlist::load));
+    helper->registerTag(Player::d_tag, sigc::mem_fun(this, &Playerlist::load));
 }
 
 Playerlist::~Playerlist()
@@ -222,7 +224,14 @@ Uint32 Playerlist::getNoOfPlayers() const
 Player* Playerlist::getFirstLiving() const
 {
     for (const_iterator it = begin(); ; it++)
-        if (!(*it)->isDead())
+        if (!(*it)->isDead() && *it != d_neutral)
+            return (*it);
+}
+
+Player* Playerlist::getFirstHuman() const
+{
+    for (const_iterator it = begin(); ; it++)
+        if (!(*it)->isDead() && (*it)->getType() == Player::HUMAN)
             return (*it);
 }
 
@@ -234,7 +243,7 @@ bool Playerlist::save(XML_Helper* helper) const
 
     bool retval = true;
 
-    retval &= helper->openTag("playerlist");
+    retval &= helper->openTag(Playerlist::d_tag);
     retval &= helper->saveData("active", d_activeplayer->getId());
     retval &= helper->saveData("neutral", d_neutral->getId());
 
@@ -251,17 +260,16 @@ bool Playerlist::load(string tag, XML_Helper* helper)
     static Uint32 active = 0;
     static Uint32 neutral = 0;
 
-    if (tag == "playerlist") //only called in the constructor
+    if (tag == Playerlist::d_tag) //only called in the constructor
     {
         helper->getData(active, "active");
         helper->getData(neutral, "neutral");
         return true;
     }
 
-    if (tag != "player")
+    if (tag != Player::d_tag)
         return false;
 
-    //else tag == "player"
     Player* p = Player::loadPlayer(helper);
     if(p == 0)
         return false;
@@ -728,6 +736,16 @@ void Playerlist::turnHumansInto(Player::Type type, int number_of_players)
 	{
 	  switch (type)
 	    {
+	    case Player::AI_DUMMY:
+		{
+		  AI_Dummy *new_p = new AI_Dummy(**i);
+		  swap((*i), new_p);
+		  //delete *i; fixme
+		  i = begin();
+		  count++;
+		  continue;
+		}
+	      break;
 	    case Player::AI_FAST:
 		{
 		  AI_Fast *new_p = new AI_Fast(**i);
