@@ -42,6 +42,9 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
 {
     public:
 
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         //! Gets the singleton instance or creates a new one.
         static Playerlist* getInstance();
 
@@ -125,6 +128,8 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
 	//! Return the first living Player in the list.
         Player* getFirstLiving() const;
 
+	Player* getFirstHuman() const;
+
 	/** 
 	 * Swap out a player from the list and replace it with a new one.
 	 * Specical care is taken to remove all references to the original
