@@ -45,6 +45,9 @@ class Reward;
 class Ruin : public NamedLocation, public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
 	//! The kind of ruin.
         enum Type {
 	  //! A normal ruin.
