@@ -23,7 +23,6 @@
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 
-#include "defs.h"
 #include "shieldstyle.h"
 
 class Player;
@@ -38,6 +37,9 @@ class Shield : public std::list<ShieldStyle*>, public sigc::trackable
 {
     public:
 
+	//! The xml tag of this object in a shieldset configuration file.
+	static std::string d_tag; 
+
 	//! The notional player that the Shield goes with.
 	enum ShieldColour {WHITE = 0, GREEN = 1, YELLOW = 2, LIGHT_BLUE = 3,
 	RED = 4, DARK_BLUE = 5, ORANGE = 6, BLACK = 7, NEUTRAL = 8};
