@@ -83,7 +83,7 @@ std::list<std::string> Shieldsetlist::getNames()
 
 bool Shieldsetlist::load(std::string tag, XML_Helper *helper)
 {
-  if (tag == "shieldset")
+  if (tag == Shieldset::d_tag)
     {
       Shieldset *shieldset = new Shieldset(helper);
       push_back(shieldset); 
@@ -97,7 +97,7 @@ bool Shieldsetlist::loadShieldset(std::string name)
 
   XML_Helper helper(File::getShieldset(name), ios::in, false);
 
-  helper.registerTag("shieldset", sigc::mem_fun((*this), &Shieldsetlist::load));
+  helper.registerTag(Shieldset::d_tag, sigc::mem_fun((*this), &Shieldsetlist::load));
 
   if (!helper.parse())
     {
@@ -115,9 +115,7 @@ SDL_Color Shieldsetlist::getColor(std::string shieldset, Uint32 owner)
   if (!s)
     {
       SDL_Color def;
-      def.r = 0;
-      def.g = 0;
-      def.b = 0;
+      memset (&def, 0, sizeof (def));
       return def;
     }
   return s->getColor(owner);
@@ -129,9 +127,7 @@ SDL_Color Shieldsetlist::getMaskColor(std::string shieldset, Uint32 owner)
   if (!s)
     {
       SDL_Color def;
-      def.r = 0;
-      def.g = 0;
-      def.b = 0;
+      memset (&def, 0, sizeof (def));
       return def;
     }
   return s->getMaskColor(owner);
