@@ -28,9 +28,12 @@
  * is implemented as a singleton because many classes use it for looking up
  * signposts.
  */
-class Signpostlist : public LocationList<Signpost>, public sigc::trackable
+class Signpostlist : public LocationList<Signpost*>, public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         //! Return the singleton instance.  Create a new one if needed.
         static Signpostlist* getInstance();
 
