@@ -27,6 +27,7 @@
 
 #include "vector.h"
 
+#include "GameScenarioOptions.h"
 #include "smallmap.h"
 #include "sdl-draw.h"
 #include "timing.h"
@@ -36,6 +37,8 @@
 SmallMap::SmallMap()
 {
     input_locked = false;
+    view.pos = Vector<int>(0, 0);
+    view.dim = Vector<int>(3, 3);
 }
 
 void SmallMap::set_view(Rectangle new_view)
@@ -96,7 +99,7 @@ void SmallMap::center_view_on_pixel(Vector<int> pos, bool slide)
     slide_view(Rectangle(pos.x, pos.y, view.w, view.h));
   else
     set_view(Rectangle(pos.x, pos.y, view.w, view.h));
-	  
+
   view_changed.emit(view);
 }
 
@@ -109,6 +112,12 @@ void SmallMap::after_draw()
       draw_cities(false);
       draw_selection();
     }
+  //for the editor...
+  if (GameScenarioOptions::s_round == 0)
+    {
+      draw_cities(false);
+      draw_selection();
+    }
   map_changed.emit(get_surface());
 }
 
