@@ -40,8 +40,12 @@
 #include "FogMap.h"
 #include "player.h"
 #include "portlist.h"
+#include "bridgelist.h"
+#include "bridge.h"
 #include "port.h"
+#include "Backpack.h"
 
+std::string Stack::d_tag = "stack";
 using namespace std;
 
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
@@ -91,9 +95,9 @@ Stack::Stack(XML_Helper* helper)
   helper->getData(d_defending, "defending");
   helper->getData(d_parked, "parked");
 
-  helper->registerTag("path", sigc::mem_fun((*this), &Stack::load));
-  helper->registerTag("army", sigc::mem_fun((*this), &Stack::load));
-  helper->registerTag("hero", sigc::mem_fun((*this), &Stack::load));
+  helper->registerTag(Path::d_tag, sigc::mem_fun((*this), &Stack::load));
+  helper->registerTag(Army::d_tag, sigc::mem_fun((*this), &Stack::load));
+  helper->registerTag(Hero::d_tag, sigc::mem_fun((*this), &Stack::load));
 }
 
 Stack::~Stack()
@@ -133,6 +137,7 @@ void Stack::moveToDest(Vector<int> dest)
   City* to_city = Citylist::getInstance()->getObjectAt(dest.x, dest.y);
   City* on_city = Citylist::getInstance()->getObjectAt(pos.x, pos.y);
   Port* on_port = Portlist::getInstance()->getObjectAt(pos.x, pos.y);
+  Bridge* on_bridge= Bridgelist::getInstance()->getObjectAt(pos.x, pos.y);
   bool on_water = (GameMap::getInstance()->getTile(pos.x,pos.y)->getMaptileType() == Tile::WATER);
   bool to_water = (GameMap::getInstance()->getTile(dest.x,dest.y)->getMaptileType() == Tile::WATER);
   bool ship_load_unload = false;
@@ -140,8 +145,8 @@ void Stack::moveToDest(Vector<int> dest)
   if (!isFlying())
     {
       if ((on_water && to_city) || 
-	  (on_water && on_port && !to_water) ||
-	  ((on_city || on_port) && to_water))
+	  (on_water && (on_port || on_bridge) && !to_water) ||
+	  ((on_city || on_port || on_bridge) && to_water))
 	{
 	  ship_load_unload = true;
 	  for (Stack::iterator it = begin(); it != end(); it++)
@@ -185,7 +190,14 @@ void Stack::moveToDest(Vector<int> dest)
   setParked(false);
 
   //update fogmap
-  getOwner()->getFogMap()->alterFogRadius(dest, getMaxSight(), FogMap::OPEN);
+  deFog();
+}
+
+void Stack::deFog()
+{
+  getOwner()->getFogMap()->alterFogRadius(getPos(), getMaxSight(), 
+					  FogMap::OPEN);
+  return;
 }
 
 bool Stack::isGrouped()
@@ -289,7 +301,7 @@ Army* Stack::getStrongestArmy(bool hero) const
 
   for (const_iterator it = begin(); it != end(); ++it)
     {
-      if ((*it)->isHero() && hero || !hero)
+      if (((*it)->isHero() && hero) || !hero)
 	{
 	  if ((*it)->getStat(Army::STRENGTH) > highest_strength)
 	    {
@@ -457,13 +469,10 @@ void Stack::nextTurn()
   for (const_iterator it = begin(); it != end(); it++)
     if ((*it)->isHero())
       {
-	std::list<Item*> backpack = dynamic_cast<Hero*>((*it))->getBackpack();
-	std::list<Item*>::const_iterator item;
-	for (item = backpack.begin(); item != backpack.end(); item++)
-	  {
-	    if ((*item)->getBonus(Item::DOUBLEMOVESTACK))
-	      movement_multiplier*=2;
-	  }
+	Hero *hero = dynamic_cast<Hero*>(*it);
+	Uint32 bonus = hero->getBackpack()->countMovementDoublers();
+	for (Uint32 i = 0; i < bonus; i++)
+	  movement_multiplier*=2;
       }
 
   //set the multipler on all armies in the stack
@@ -488,7 +497,7 @@ bool Stack::save(XML_Helper* helper) const
 {
   bool retval = true;
 
-  retval &= helper->openTag("stack");
+  retval &= helper->openTag(Stack::d_tag);
   retval &= helper->saveData("id", d_id);
   retval &= helper->saveData("x", getPos().x);
   retval &= helper->saveData("y", getPos().y);
@@ -514,14 +523,14 @@ bool Stack::save(XML_Helper* helper) const
 
 bool Stack::load(std::string tag, XML_Helper* helper)
 {
-  if (tag == "path")
+  if (tag == Path::d_tag)
     {
       d_path = new Path(helper);
 
       return true;
     }
 
-  if (tag == "army")
+  if (tag == Army::d_tag)
     {
       Army* a = new Army(helper);
       a->setOwner(d_owner);
@@ -530,7 +539,7 @@ bool Stack::load(std::string tag, XML_Helper* helper)
       return true;
     }
 
-  if (tag == "hero")
+  if (tag == Hero::d_tag)
     {
       Hero* h = new Hero(helper);
       h->setOwner(d_owner);
@@ -567,9 +576,10 @@ Uint32 Stack::calculateMoveBonus() const
   int num_landedother = 0;
   if (size() == 0)
     return 0;
+  bool grouped = countGroupedArmies() > 0;
   for (const_iterator it = this->begin(); it != this->end(); it++)
     {
-      if ((*it)->isGrouped() == false)
+      if ((*it)->isGrouped() == false && grouped)
 	continue;
       bonus = (*it)->getStat(Army::MOVE_BONUS);
       if (bonus == Tile::GRASS || (bonus & Tile::WATER) == 0 || 
@@ -590,8 +600,7 @@ Uint32 Stack::calculateMoveBonus() const
   if (landed == false ||
       (num_landedother == 0 && num_landedhero <= num_flyer)) 
     {
-      d_bonus = Tile::GRASS | Tile::WATER | Tile::FOREST | Tile::HILLS |
-	Tile::MOUNTAIN | Tile::SWAMP;
+      d_bonus = Tile::isFlying();
       return d_bonus;
     }
 
@@ -601,16 +610,10 @@ Uint32 Stack::calculateMoveBonus() const
       if ((*it)->isHero())
 	{
 	  Hero *h = dynamic_cast<Hero*>(*it);
-	  std::list<Item*> backpack = h->getBackpack();
-	  std::list<Item*>::const_iterator item;
-	  for (item = backpack.begin(); item != backpack.end(); item++)
+	  if (h->getBackpack()->countStackFlightGivers() > 0)
 	    {
-	      if ((*item)->getBonus(Item::FLYSTACK))
-		{
-		  d_bonus = Tile::GRASS | Tile::WATER | Tile::FOREST | 
-		    Tile::HILLS | Tile::MOUNTAIN | Tile::SWAMP;
-		  return d_bonus;
-		}
+	      d_bonus = Tile::isFlying();
+	      return d_bonus;
 	    }
 	}
     }
@@ -632,8 +635,7 @@ Uint32 Stack::calculateMoveBonus() const
 bool Stack::isFlying () const
 {
   Uint32 d_bonus = calculateMoveBonus();
-  if (d_bonus == (Tile::GRASS | Tile::WATER | Tile::FOREST | Tile::HILLS |
-		  Tile::MOUNTAIN | Tile::SWAMP))
+  if (d_bonus == Tile::isFlying())
     return true;
   else
     return false;
