@@ -52,6 +52,9 @@ class Temple;
 class Stack : public ::UniquelyIdentified, public Movable, public Ownable, public std::list<Army*>, public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         /** 
 	 * Make a new stack.
          * 
@@ -153,6 +156,9 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	//! Returns true if all Army units in the stack are grouped.
 	bool isGrouped();
 
+	//! Uncovers some of the hidden map around this stack.
+	void deFog();
+
 	/**
 	 * Scan all adjacent tiles relative to the stack's position and 
 	 * see how much a move would cost in terms of movement points.
