@@ -20,8 +20,10 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
 //  02110-1301, USA.
 
+#include "config.h"
 #include <sigc++/functors/mem_fun.h>
 #include <assert.h>
+#include <algorithm>
 
 #include "stacklist.h"
 #include "stack.h"
@@ -29,10 +31,11 @@
 #include "path.h"
 #include "playerlist.h"
 #include "xmlhelper.h"
-#include <algorithm>
 #include "Item.h"
 #include "hero.h"
+#include "Backpack.h"
 
+std::string Stacklist::d_tag = "stacklist";
 using namespace std;
 
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
@@ -194,9 +197,9 @@ Stacklist::Stacklist(Stacklist *stacklist)
 Stacklist::Stacklist(XML_Helper* helper)
     :d_activestack(0)
 {
-    helper->registerTag("stack", sigc::mem_fun((*this), &Stacklist::load));
+    helper->registerTag(Stack::d_tag, sigc::mem_fun((*this), &Stacklist::load));
 
-    load("stacklist", helper);
+    load(Stacklist::d_tag, helper);
 }
 
 Stacklist::~Stacklist()
@@ -293,7 +296,6 @@ bool Stacklist::flRemove(Stack* object)
         if (d_activestack == object)
             d_activestack = 0;
 	assert (object->getId() == (*stackit)->getId());
-	printf ("about to delete stack with id %d\n", object->getId());
         delete object;
         erase(stackit);
         return true;
@@ -305,15 +307,11 @@ bool Stacklist::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("stacklist");
+    retval &= helper->openTag(Stacklist::d_tag);
     if (d_activestack)
-    {
-        retval &= helper->saveData("active", d_activestack->getId());
-    }
+      retval &= helper->saveData("active", d_activestack->getId());
     else
-    {
-        retval &= helper->saveData("active", 0);
-    }
+      retval &= helper->saveData("active", 0);
 
     //save stacks
     for (const_iterator it = begin(); it != end(); it++)
@@ -340,13 +338,13 @@ bool Stacklist::load(string tag, XML_Helper* helper)
 {
     static Uint32 active = 0;
     
-    if (tag == "stacklist")
+    if (tag == Stacklist::d_tag)
     {
         helper->getData(active, "active");
         return true;
     }
 
-    if (tag == "stack")
+    if (tag == Stack::d_tag)
     {
         Stack* s = new Stack(helper);
         if ((active != 0) && (s->getId() == active))
@@ -369,6 +367,46 @@ Stack* Stacklist::getOwnObjectAt(int x, int y)
   return 0;
 }
 
+std::list<Hero*> Stacklist::getTopHeroes(int num)
+{
+  std::list<Hero*> result;
+  std::vector<Uint32> hero_ids;
+
+  if (num == 0)
+    return result;
+
+  //load up a stack with all the heroes we have
+  Stack *stack = Stack::createNonUniqueStack(NULL, Vector<int>(1,1));
+  if (!stack)
+    return result;
+
+  getHeroes(hero_ids);
+  for (std::vector<Uint32>::iterator it = hero_ids.begin(); 
+       it != hero_ids.end(); it++)
+    {
+      Stack *hero_stack = getArmyStackById(*it);
+      Hero *hero = dynamic_cast<Hero*>(hero_stack->getArmyById(*it));
+      stack->push_back(new Hero(*hero));
+    }
+  //now we yank out the top NUM heroes and put them in our list.
+  if (num == -1)
+    num = hero_ids.size();
+  for (int i = 0 ; i < num; i++)
+    {
+      Hero *hero = dynamic_cast<Hero*>(stack->getStrongestHero());
+      if (hero)
+	{
+	  result.push_back(hero);
+	  stack->erase(find (stack->begin(), stack->end(), hero));
+	  if (stack->size() == 0)
+	    break;
+	}
+    }
+  stack->flClear();
+  delete stack;
+  return result;
+}
+
 void Stacklist::getHeroes(std::vector<Uint32>& dst)
 {
   for (Stacklist::iterator it = begin(); it != end(); it++)
@@ -387,19 +425,8 @@ void Stacklist::collectTaxes(Player *p, Uint32 num_cities)
       Stack *stack = getArmyStackById(*it);
       Army *army = stack->getArmyById(*it);
       Hero *hero = static_cast<Hero*>(army);
-      std::list<Item*> backpack = hero->getBackpack();
-      std::list<Item*>::const_iterator item;
-      for (item = backpack.begin(); item != backpack.end(); item++)
-	{
-	  if ((*item)->getBonus(Item::ADD2GOLDPERCITY))
-	    p->addGold(2 * num_cities);
-	    if ((*item)->getBonus(Item::ADD3GOLDPERCITY))
-	      p->addGold(3 * num_cities);
-	    if ((*item)->getBonus(Item::ADD4GOLDPERCITY))
-	      p->addGold(4 * num_cities);
-	    if ((*item)->getBonus(Item::ADD5GOLDPERCITY))
-	      p->addGold(5 * num_cities);
-	  }
+      Uint32 bonus = hero->getBackpack()->countGoldBonuses();
+      p->addGold(bonus * num_cities);
     }
 }
 
