@@ -24,19 +24,31 @@
 #include "QuestsManager.h"
 #include "stack.h"
 
+std::string Temple::d_tag = "temple";
+
 Temple::Temple(Vector<int> pos, std::string name, int type)
-  :NamedLocation(pos, name),d_type(type)
+  :NamedLocation(pos, TEMPLE_TILE_WIDTH, name),d_type(type)
 {
     //mark the location on the game map as occupied by a temple
-    GameMap::getInstance()->getTile(getPos())->setBuilding(Maptile::TEMPLE);
+    for (unsigned int i = 0; i < getSize(); i++)
+      for (unsigned int j = 0; j < getSize(); j++)
+	{
+	  Vector<int> pos = getPos() + Vector<int>(i, j);
+	  GameMap::getInstance()->getTile(pos)->setBuilding(Maptile::TEMPLE);
+	}
 }
 
 Temple::Temple(XML_Helper* helper)
-    :NamedLocation(helper)
+    :NamedLocation(helper, TEMPLE_TILE_WIDTH)
 {
     //mark the location on the game map as occupied by a temple
     helper->getData(d_type, "type");
-    GameMap::getInstance()->getTile(getPos())->setBuilding(Maptile::TEMPLE);
+    for (unsigned int i = 0; i < getSize(); i++)
+      for (unsigned int j = 0; j < getSize(); j++)
+	{
+	  Vector<int> pos = getPos() + Vector<int>(i, j);
+	  GameMap::getInstance()->getTile(pos)->setBuilding(Maptile::TEMPLE);
+	}
 }
 
 Temple::Temple(const Temple& t)
@@ -52,7 +64,7 @@ bool Temple::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("temple");
+    retval &= helper->openTag(Temple::d_tag);
     retval &= helper->saveData("id", d_id);
     retval &= helper->saveData("x", getPos().x);
     retval &= helper->saveData("y", getPos().y);
