@@ -27,6 +27,7 @@
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
+std::string Templelist::d_tag = "templelist";
 Templelist* Templelist::s_instance=0;
 
 Templelist* Templelist::getInstance()
@@ -60,17 +61,17 @@ Templelist::Templelist()
 
 Templelist::Templelist(XML_Helper* helper)
 {
-    helper->registerTag("temple", sigc::mem_fun(this, &Templelist::load));
+    helper->registerTag(Temple::d_tag, sigc::mem_fun(this, &Templelist::load));
 }
 
 bool Templelist::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("templelist");
+    retval &= helper->openTag(Templelist::d_tag);
 
     for (const_iterator it = begin(); it != end(); it++)
-        retval &= (*it).save(helper);
+        retval &= (*it)->save(helper);
     
     retval &= helper->closeTag();
 
@@ -79,12 +80,11 @@ bool Templelist::save(XML_Helper* helper) const
 
 bool Templelist::load(std::string tag, XML_Helper* helper)
 {
-    if (tag != "temple")    
+    if (tag != Temple::d_tag)    
     //what has happened?
         return false;
     
-    Temple t(helper);
-    push_back(t);
+    push_back(new Temple(helper));
 
     return true;
 }
@@ -110,7 +110,7 @@ Temple* Templelist::getNearestVisibleAndUsefulTemple(Stack *s,
 
   for (iterator it = begin(); it != end(); ++it)
     {
-      Temple *temple = &*it;
+      Temple *temple = *it;
       if (isFogged(temple))
 	continue;
 
@@ -118,7 +118,7 @@ Temple* Templelist::getNearestVisibleAndUsefulTemple(Stack *s,
 	  < (double)s->size() * (percent_can_be_blessed / 100.0))
 	continue;
 
-      Vector<int> p = (*it).getPos();
+      Vector<int> p = (*it)->getPos();
       int delta = abs(p.x - pos.x);
       if (delta < abs(p.y - pos.y))
 	delta = abs(p.y - pos.y);
@@ -131,7 +131,7 @@ Temple* Templelist::getNearestVisibleAndUsefulTemple(Stack *s,
     }
 
   if (diff == -1) return 0;
-  return &(*diffit);
+  return (*diffit);
 
 }
 
