@@ -31,9 +31,12 @@ class Stack;
  * is implemented as a singleton because many classes use it for looking 
  * up temples.
  */
-class Templelist : public LocationList<Temple>, public sigc::trackable
+class Templelist : public LocationList<Temple*>, public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         //! Return the singleton instance.  Create a new one if needed.
         static Templelist* getInstance();
 
