@@ -21,7 +21,9 @@
 
 #include "tileset.h"
 
+#include "defs.h"
 #include "File.h"
+#include "SmallTile.h"
 #include "xmlhelper.h"
 
 using namespace std;
@@ -32,6 +34,8 @@ using namespace std;
 
 #define DEFAULT_TILE_SIZE 40
 	
+std::string Tileset::d_tag = "tileset";
+
 Tileset::Tileset(std::string name)
 	: d_name(name), d_tileSize(DEFAULT_TILE_SIZE), d_dir("")
 {
@@ -47,10 +51,10 @@ Tileset::Tileset(XML_Helper *helper)
     helper->getData(d_tileSize, "tilesize");
     helper->getData(d_large_selector, "large_selector");
     helper->getData(d_small_selector, "small_selector");
-    helper->registerTag("tile", sigc::mem_fun((*this), &Tileset::loadTile));
-    helper->registerTag("smallmap", sigc::mem_fun((*this), &Tileset::loadTile));
-    helper->registerTag("tilestyle", sigc::mem_fun((*this), &Tileset::loadTile));
-    helper->registerTag("tilestyleset", sigc::mem_fun((*this), &Tileset::loadTile));
+    helper->registerTag(Tile::d_tag, sigc::mem_fun((*this), &Tileset::loadTile));
+    helper->registerTag(SmallTile::d_tag, sigc::mem_fun((*this), &Tileset::loadTile));
+    helper->registerTag(TileStyle::d_tag, sigc::mem_fun((*this), &Tileset::loadTile));
+    helper->registerTag(TileStyleSet::d_tag, sigc::mem_fun((*this), &Tileset::loadTile));
 }
 
 Tileset::~Tileset()
@@ -73,7 +77,7 @@ bool Tileset::loadTile(string tag, XML_Helper* helper)
 {
     debug("loadTile()")
 
-    if (tag == "tile")
+    if (tag == Tile::d_tag)
       {
 	// create a new tile with the information we got
 	Tile* tile = new Tile(helper);
@@ -82,39 +86,15 @@ bool Tileset::loadTile(string tag, XML_Helper* helper)
 	return true;
       }
 
-    if (tag == "smallmap")
+    if (tag == SmallTile::d_tag)
       {
-	Uint32 i;
-	SDL_Color color;
-	color.unused = 0;
 	Tile *tile = this->back();
-	helper->getData(i, "red");      color.r = i;
-	helper->getData(i, "green");    color.g = i;
-	helper->getData(i, "blue");     color.b = i;
-	tile->setColor(color);
-
-	helper->getData(i, "pattern");
-	Tile::Pattern pattern = static_cast<Tile::Pattern>(i);
-	tile->setPattern(pattern);
-    
-	if (pattern != Tile::SOLID)
-	  {
-	    helper->getData(i, "2nd_red");      color.r = i;
-	    helper->getData(i, "2nd_green");    color.g = i;
-	    helper->getData(i, "2nd_blue");     color.b = i;
-	    tile->setSecondColor(color);
-	    if (pattern != Tile::STIPPLED && pattern != Tile::SUNKEN)
-	      {
-		helper->getData(i, "3rd_red");      color.r = i;
-		helper->getData(i, "3rd_green");    color.g = i;
-		helper->getData(i, "3rd_blue");     color.b = i;
-		tile->setThirdColor(color);
-	      }
-	  }
+	SmallTile* smalltile = new SmallTile(helper);
+	tile->setSmallTile(smalltile);
 	return true;
       }
 
-    if (tag == "tilestyle")
+    if (tag == TileStyle::d_tag)
       {
 	Tile *tile = this->back();
 	TileStyleSet *tilestyleset = tile->back();
@@ -127,7 +107,7 @@ bool Tileset::loadTile(string tag, XML_Helper* helper)
 	return true;
       }
 
-    if (tag == "tilestyleset")
+    if (tag == TileStyleSet::d_tag)
       {
 	Tile *tile = this->back();
 	// create a new tile style set with the information we got
@@ -154,7 +134,7 @@ bool Tileset::save(XML_Helper *helper)
 {
   bool retval = true;
 
-  retval &= helper->openTag("tileset");
+  retval &= helper->openTag(d_tag);
   retval &= helper->saveData("name", d_name);
   retval &= helper->saveData("info", d_info);
   retval &= helper->saveData("tilesize", d_tileSize);
@@ -177,7 +157,7 @@ Tile *Tileset::lookupTileByName(std::string name)
 	
 int Tileset::getFreeTileStyleId()
 {
-  int ids[256];
+  int ids[65535];
   memset (ids, 0, sizeof (ids));
   for (Tileset::iterator i = begin(); i != end(); ++i)
     {
@@ -189,8 +169,8 @@ int Tileset::getFreeTileStyleId()
 	    }
 	}
     }
-  //these ids range from 0 to 255.
-  for (unsigned int i = 0; i < 256; i++)
+  //these ids range from 0 to 65535.
+  for (unsigned int i = 0; i <= 65535; i++)
     {
       if (ids[i] == 0)
 	return i;
@@ -198,6 +178,23 @@ int Tileset::getFreeTileStyleId()
   return -1;
 }
 
+int Tileset::getLargestTileStyleId()
+{
+  unsigned int largest = 0;
+  for (Tileset::iterator i = begin(); i != end(); ++i)
+    {
+      for (std::list<TileStyleSet*>::iterator j = (*i)->begin(); j != (*i)->end(); j++)
+	{
+	  for (std::vector<TileStyle*>::iterator k = (*j)->begin(); k != (*j)->end(); k++)
+	    {
+	      if ((*k)->getId() > largest)
+		largest = (*k)->getId();
+	    }
+	}
+    }
+  return largest;
+}
+
 void Tileset::setSubDir(std::string dir)
 {
   d_dir = dir;
@@ -205,4 +202,25 @@ void Tileset::setSubDir(std::string dir)
     for (Tile::iterator j = (*i)->begin(); j != (*i)->end(); j++)
       (*j)->setSubDir(dir);
 }
+
+Uint32 Tileset::getDefaultTileSize()
+{
+  return DEFAULT_TILE_SIZE;
+}
+
+bool Tileset::validate()
+{
+  if (size() == 0)
+    return false;
+  for (Tileset::iterator i = begin(); i != end(); i++)
+    {
+      if ((*i)->validate() == false)
+	{
+	  fprintf (stderr, _("`%s' fails validation\n"), 
+		   (*i)->getName().c_str());
+	  return false;
+	}
+    }
+  return true;
+}
 // End of file
