@@ -48,6 +48,12 @@ class XML_Helper;
 class Tileset : public sigc::trackable, public std::vector<Tile*>
 {
     public:
+	//! The xml tag of this object in a tileset configuration file.
+	static std::string d_tag; 
+
+	//! Return the default height and width of a tile in the tileset.
+	static Uint32 getDefaultTileSize();
+
 	//! Default constructor.
 	/**
 	 * Make a new Tileset.
@@ -134,6 +140,9 @@ class Tileset : public sigc::trackable, public std::vector<Tile*>
 
 	int getFreeTileStyleId();
 
+	int getLargestTileStyleId();
+
+	bool validate();
     private:
         //! Callback to load Tile objects into the Tileset.
         bool loadTile(std::string, XML_Helper* helper);
