@@ -16,10 +16,12 @@
 //  02110-1301, USA.
 
 #include <iostream>
+#include <algorithm>
 #include <expat.h>
 #include <SDL_image.h>
 #include <SDL.h>
 #include "rectangle.h"
+#include "ucompose.hpp"
 #include <sigc++/functors/mem_fun.h>
 
 #include "tilesetlist.h"
@@ -57,12 +59,24 @@ Tilesetlist::Tilesetlist()
     for (std::list<std::string>::const_iterator i = tilesets.begin(); 
 	 i != tilesets.end(); i++)
       {
-        loadTileset(*i);
-	iterator it = end();
-	it--;
-	(*it)->setSubDir(*i);
-	d_dirs[(*it)->getName()] = *i;
-	d_tilesets[*i] = *it;
+        if (loadTileset(*i) == true)
+	  {
+	    iterator it = end();
+	    it--;
+	    (*it)->setSubDir(*i);
+	    d_dirs[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = *i;
+	    d_tilesets[*i] = *it;
+	  }
+	else
+	  {
+	    //we failed validation
+	    iterator it = end();
+	    it--;
+	    fprintf (stderr, "tileset `%s' fails validation. skipping.\n",
+		     (*it)->getName().c_str());
+	    delete *it;
+	    erase (it);
+	  }
       }
 }
 
@@ -72,6 +86,15 @@ Tilesetlist::~Tilesetlist()
     delete (*it);
 }
 
+void Tilesetlist::getSizes(std::list<Uint32> &sizes)
+{
+  for (iterator i = begin(); i != end(); i++)
+    {
+      if (find (sizes.begin(), sizes.end(), (*i)->getTileSize()) == sizes.end())
+	sizes.push_back((*i)->getTileSize());
+    }
+}
+
 std::list<std::string> Tilesetlist::getNames()
 {
   std::list<std::string> names;
@@ -80,12 +103,21 @@ std::list<std::string> Tilesetlist::getNames()
   return names;
 }
 
+std::list<std::string> Tilesetlist::getNames(Uint32 tilesize)
+{
+  std::list<std::string> names;
+  for (iterator it = begin(); it != end(); it++)
+    if ((*it)->getTileSize() == tilesize)
+      names.push_back((*it)->getName());
+  return names;
+}
+
 bool Tilesetlist::load(std::string tag, XML_Helper *helper)
 {
-  if (tag == "tileset")
+  if (tag == Tileset::d_tag)
     {
       Tileset *tileset = new Tileset(helper);
-      push_back(tileset); 
+	push_back(tileset); 
     }
   return true;
 }
@@ -96,7 +128,7 @@ bool Tilesetlist::loadTileset(std::string name)
 
   XML_Helper helper(File::getTileset(name), ios::in, false);
 
-  helper.registerTag("tileset", sigc::mem_fun((*this), &Tilesetlist::load));
+  helper.registerTag(Tileset::d_tag, sigc::mem_fun((*this), &Tilesetlist::load));
 
   if (!helper.parse())
     {
@@ -105,5 +137,15 @@ bool Tilesetlist::loadTileset(std::string name)
       exit(-1);
     }
 
+  iterator it = end();
+  it--;
+  if ((*it)->validate() == false)
+    return false;
+
   return true;
 }
+
+std::string Tilesetlist::getTilesetDir(std::string name, Uint32 tilesize)
+{
+  return d_dirs[String::ucompose("%1 %2", name, tilesize)];
+}
